program drop _all

* INPUT: PLEASE ADD THIS DATA
/* Data used: Name and Storage location (replace `country_name' with e.g. Malawi and `country_initial' with e.g. MWI')

A. Remote_Sensed Datasets (All CSV files)
1) Grid Information: ./Input_Data/Remote_Sensed/SSA/gadm_admin_urg005_mapping/`country_initial'_gadm_admin_urg005_mapping.csv
2) Keys to merge crop cycle data: ./Input_Data/Remote_Sensed/SSA/country_mapping/`country_initial'_gaul1_asap_urg005_mapping.csv
3) JRC crop cycle data: ./Input_Data/Remote_Sensed/SSA/merge_variable_data/crop_calendar_gaul1.csv
4) Dataset to merge GADM admin IDs: ./Input_Data/Remote_Sensed/SSA/merge_variable_data/gadm_admin_geodata.csv 
5) Crop Cover Dataset: ./Input_Data/Remote_Sensed/SSA/crop_coverage/country_mapping/`country_initial'_CROPCOV19_mapping.csv 
6) WRSI: ./Input_Data/Remote_Sensed/SSA/WRSI/`country_initial'_WRSI_do_dekad_ALL.csv (these may need to be saved and renamed,depends on region folder)
7) WRSI Second Season: ./Input_Data/Remote_Sensed/SSA/WRSI/Second_Season/`country_initial'_wrsi2_do_dekad_ALL.csv (these may need to be saved and renamed,depends on region folder)
8) CHIRPS: ./Input_Data/Remote_Sensed/SSA/CHIRPS/CHIRPS_country_dekadal_xy_output/`country_initial'_CHIRPS_dekad.csv
9) NDVI: ./Input_Data/Remote_Sensed/SSA/NDVI/MODIS13C2_output_xyz/`country_initial'_NDVI_monthly.csv
10) SPEI:  ./Input_Data/Remote_Sensed/SSA/SPEI3/`country_initial'_SPEI03_dekad.csv
11) SWI: ./Input_Data/Remote_Sensed/SSA/SWI/`country_initial'_SWI10_040_dekad.csv
12) AEZ : ./Input_Data/Remote_Sensed/SSA/agro_ecological_zone/country_mapping/`country_initial'_aez_urg005_mapping.csv
13) Time to market: ./Input_Data/Remote_Sensed/SSA/time_to_market/country_mapping/`country_initial'_ttm_urg005_mapping.csv
14) Livelihood Zones: ./Input_Data/Remote_Sensed/SSA/livelihood_zone/country_mapping/`country_initial'_livelihood_urg005_db.csv
15) TEMPERATURE: ./Input_Data/Remote_Sensed/SSA/temper/`country_initial'_ERA5_monthly_temp.csv

B. Stata Household Survey and user created admin level merge key csv file (not needed if only using locations and not admin areas for the merges)
1) Household Survey: ./Input_Data/Data_Integration/Country/`country_name'/`survey'.dta
2) CSV file with name of admin level in the survey data and corresponding admin level name in the remote-sensed data (not needed if using HH coordinates)
*/

* OUTPUT: After running this Do file (takes 30-60 minutes for hh data and less for cluster data) you should see this merged dataset appear here:

******** Please enter the main directory in which the Drought_Welfare_SSA folder is stored (replace C:/ with your directory) ************
*****************************************************************************************************************************************

************ Enter the COUNTRY-SPECIFIC information here ******************************************* *********** 
local int_month 			int_month 
local int_year 				year  

local country_name 			Ethiopia
local country_initial 		ETH 

local hh_loc_available 		No // Yes if the survey has latitudes and longitudes for the hh, No (or anything else) if it doesn't
local hh_admin_available 	Yes
local survey_merge 			coordinates2 // name of the csv file that has the names of the admin level variable in the survey and remote_merge_admin in the remote-sensed grid
local admin_level 			district // The relevant admin level name in the hh survey (perhaps the lowest, but representativeness may be a concern for some uses) 
local remote_merge_admin 	cc_3   // corresponding admin name in the remote sensed data (with new surveys users need to create a csv file that are merge keys used to link remote-sensed and survey data)  //THIS IS A STRING VARIABLE in coordinates2
local survey_data 			basic_11_16 // stored in: Input_Data/Data_Integration/Country/`country_name'/HH_Survey. You can call this anything but please change the local name as well (this line)
local hhid 					hhid  // Household Identifier
local hh_lat 				NA // latitude name in the household survey, make sure that these are not strings, if not available put NA and it won't be used
local hh_lon 				NA // longitude name in the household survey, make sure that these are not strings, if not available put NA and it won't be used
**********************************************************************************************************************************
*************** USER CHOICES *****************************************************************************************************
local crop_cover_filter = -1
local radius  "0"		//0 if using admin boundaries

********************************************************************************************************************************
****************** REMOTE-SENSED HAZARD DATA AVAILABILITY **********************************************************************
*** Yes if available, No (or anything else if not)
local ndvi_available Yes
local wrsi_available No
local wrsi2_available No
local spei3_available No
local chirps_available No
local swi_available No
local temper_available No

local rainy_season_available Yes


********************************************************************************************************************************
******Hazard and contextual variables from spatial data that will be used ******************************************************

*name of program specifically for country if applicaple
*do Do_Files/Country/

** list of hazard variables that need to be ranemed with radius
local var_radii 	""anomaly_ndvi_`admin_level' anomaly_rs_ndvi_`admin_level' anomaly_rs2_ndvi_`admin_level'""

*list of other covariates that need to be renamed with radius
local var_const 		""ttm_020 ttm_050 ttm_100 ttm_250 ttm_500 aez_band aez_class lev_1_2016 lev1_des""

local survey_data2 		`country_name'_cons_merged 

local spatial			loc		//keep as loc for consumption pooled dataset, but should be admin if using admin


*******************************************************************************************************************************
*******************************************************************************************************************************
*************** WHAT IS BELOW NEED NOT BE CHANGED ******************************************************************************
******************************************************************************************************************************** 
********************************************************************************************************************************

local wrsi wrsi
local wrsi2 wrsi2
local chirps chirps
local ndvi ndvi
local spei3 spei3
local swi swi
local temper temper
local location location
local national national
local rainy rainy

local filter "`crop_cover_filter'"
local rad "`radius'"

* Load programs
do Do_Files/General/Programs/Data_Integration/load_programs

load_data `country_name' `country_initial' `survey_data' `hhid' `int_month' `int_year' `crop_cover_filter' ///
           `hh_lat' `hh_lon' `hh_loc_available' `hh_admin_available' `admin_level' `remote_merge_admin' `survey_merge' ///
		   `ndvi_available' `wrsi_available' `wrsi2_available' `spei3_available'  `chirps_available' `swi_available' `temper_available' `rainy_season_available'
		   
********** This code computes local hazard anomalies when hh-level coordinates are available ********************
if ("`hh_loc_available'" == "Yes")  {
* Use the hh_distance command to match a collection of grids to each household [only runs if hh geolocations are available]
* arguments/parameters are : i) country ii) household id iii) segment variable iv) latitude v) longitude vi) maximum distance between hh and grid centroid (km)
hh_distance `country_name' `survey_data'  `hh_lat' `hh_lon' `radius'  `wrsi' `wrsi2' `chirps' `ndvi' `spei3' `swi' `temper' `ndvi_available' `wrsi_available' `wrsi2_available' `spei3_available'  `chirps_available' `swi_available' `temper_available' `rainy_season_available' 

* Construct a local spatial average time series (with the buffer specified by the user above) for every household in the survey 
hh_local_spatial_average `country_name' `wrsi' `wrsi2' `chirps' `ndvi' `spei3' `swi' `temper' `ndvi_available' `wrsi_available' `wrsi2_available' `spei3_available'  `chirps_available' `swi_available' `temper_available'
hh_chirps_time_series `country_name' `location' `chirps_available' 
hh_chirps_rs_time_series `country_name' `location' `chirps_available' `rainy_season_available'
hh_ndvi_time_series `country_name'  `location' `ndvi_available'
hh_ndvi_rs_time_series `country_name'  `location' `ndvi_available' `rainy_season_available' 
hh_wrsi_time_series `country_name' `location'  `wrsi_available'
hh_wrsi2_time_series `country_name' `location'  `wrsi2_available'
hh_spei3_time_series `country_name'  `location' `spei3_available'
hh_swi_time_series `country_name'  `location' `swi_available'
hh_swi_rs_time_series `country_name'  `location' `swi_available' `rainy_season_available' 
hh_temper_time_series `country_name'  `location' `temper_available'
}

*****************************************************************************************************************************************************
if ("`hh_admin_available'" == "Yes")  {

* Construct an admin level spatial average time series 
hh_admin_spatial_average `country_name' `wrsi' `wrsi2' `chirps' `ndvi' `spei3' `swi' `temper' `admin_level' `ndvi_available' `wrsi_available' `wrsi2_available'  `spei3_available'  `chirps_available' `swi_available' `temper_available'  `rainy_season_available'

* Use the spatially averaged time series to create hazard anomalies: Rainfall (CHIRPS) (with reference to the 20 year historical record for the relevant spatial average)
* Constructs the standardized anomalies for the cumulative CHIRPS rainfall measure after the first 3 months of the growing season
* Constructs the cumulative growing season CHIRPS rainfall percentile  
hh_chirps_time_series `country_name' `admin_level' `chirps_available' `radius' 

hh_chirps_rs_time_series `country_name' `admin_level' `chirps_available' `rainy_season_available' `radius' 

* Use the spatially averaged time series to create hazard anomalies: NDVI
* Constructs the standardized anomalies for the cumulative NDVI Index after the first 3 months of the growing season
hh_ndvi_time_series `country_name'  `admin_level' `ndvi_available' `radius' 
*/
hh_ndvi_rs_time_series `country_name'  `admin_level' `ndvi_available' `rainy_season_available'  `radius' 


* Use the spatially averaged time series to create hazard anomalies: WRSI (with reference to the 20 year historical record for the relevant spatial average)
* Constructs the WRSI anomaly: WRSI*100/median 
* Constructs the WRSI level time series
hh_wrsi_time_series `country_name'  `admin_level' `wrsi_available' `radius' 


* Use the spatially averaged time series to create hazard anomalies: SPEI3  
* Constructs the standardized anomalies for the 3 month SPEI after the first 3 months of the growing season
hh_spei3_time_series `country_name'  `admin_level'  `spei3_available' `radius' 

* Use the spatially averaged time series to create hazard anomalies: Soil Moisture
* Constructs the standardized anomalies for the 3 month SPEI after the first 3 months of the growing season
hh_swi_time_series `country_name'  `admin_level'  `swi_available' `radius' 

hh_swi_rs_time_series `country_name'  `admin_level' `swi_available' `rainy_season_available'  `radius' 

* Use the spatially averaged time series to create hazard anomalies: Temperature  
* Constructs the standardized anomalies what is the measure???????
*hh_temper_time_series `country_name'  `admin_level'  `temper_available'

}


* Contruct national-level hazard anomalies 
/*
* National spatial average of pixels with significant are under cultivation (above 25 percent) and favorable aez (moderate/good soils and not dry)
hh_national_spatial_average `country_name' `wrsi' `wrsi2' `chirps' `ndvi' `spei3' `swi' `temper' `ndvi_available' `wrsi_available' `wrsi2_available'  `spei3_available'  `chirps_available' `swi_available' `temper_available'
 
* Constructs the National WRSI level time series
hh_wrsi_time_series `country_name'  `national' `wrsi_available' 

* Constructs the National WRSI level time series
hh_wrsi2_time_series `country_name'  `national' `wrsi2_available' 

* Constructs the standardized anomalies for the 3 month SPEI after the first 3 months of the growing season
hh_spei3_time_series `country_name'  `national'  `spei3_available'

* Constructs national chirps time series
hh_chirps_time_series `country_name'  `national'  `chirps_available'

* Constructs national ndvi time series
hh_ndvi_time_series `country_name'  `national'  `ndvi_available'

* Constructs national soil moisture time series
hh_swi_time_series `country_name'  `national'  `swi_available'

* Constructs national temperature time series
hh_temper_time_series `country_name'  `national'  `temper_available'
*/
* Merge the original survey data with the constructed hazard events
merge_hh_hazard_data `country_name' `country_initial' `survey_data' `int_month' `int_year' `hh_lat' `hh_lon' `hh_loc_available' `hh_admin_available' `admin_level' `ndvi_available' `wrsi_available' `wrsi2_available' `spei3_available'  `chirps_available' `swi_available' `temper_available' `rainy_season_available'

cap drop if `hhid'==""

save "./Input_Data/Household_Survey/`country_name'/`country_name'_cons_merged_hazard_`int_year'_`rad'r_filter`filter'.dta", replace

hh_cons_merge_all_hazard_adm `country_name' `country_initial' `survey_data2' `hhid' `int_year' `radius' `spatial' `var_radii' `var_const' `filter' `admin_level' `year'

