#delimit ;

loc d1 			"./Input_Data/Household_Survey/Malawi/Dataprep";
loc d3 			"./Input_Data/Household_Survey/Malawi/Dataprep/IHS3";
loc d4 			"./Input_Data/Household_Survey/Malawi/Dataprep/IHS4";
loc d5 			"./Input_Data/Household_Survey/Malawi/Dataprep/IHS5";


	*********************************
	*HOUSING CHARACTERISTICS ROUND 3
	*********************************;

use "`d3'\hh_mod_f.dta", clear;

keep case_id hh_f01 hh_f05 hh_f06 hh_f07 hh_f08 hh_f09 hh_f10 hh_f11 hh_f12 hh_f19 hh_f27 hh_f31 hh_f34 hh_f36 hh_f41 hh_f42 hh_f44;


recode hh_f01 (1/2=1) (3/6=0), gen(asset_house_own);
recode hh_f05 (0/4=1) (5/9=2) (10/14=3) (15/19=4) (20/1000=5), gen(asset_house_age);
rename hh_f06 asset_house_type;

/*;
g08: walls
           1 Grass/Palm leaves
           2 Mud
           3 Compacted earth
           4 Mud brick
           5 Burnt bricks
           6 Concrete
           7 Wood
           8 Iron sheets
           9 Other

g09: roof
           1 Grass/Palm leaves
           2 Iron sheets
           3 Clay tiles
           4 Concrete
           5 Plastic sheeting
           6 Other

g10: floor
           1 Sand
           2 Smoothed mud
           3 Smooth cement
           4 Wood
           5 Tile
           6 Other	   
*/;

gen asset_house_wall=hh_f07;
gen asset_house_roof=hh_f08;
gen asset_house_floor=hh_f09;
recode hh_f07 (1 3=1) (2/3 8=2) (4/7=3), gen(asset_house_wall_cat);  
recode hh_f08 (1 6=1) (5=2) (2/4=3), gen(asset_house_roof_cat);
recode hh_f09 (1/2 6=1) (3/5=3), gen(asset_house_floor_cat);
gen asset_house_rooms=hh_f10;

/*;
g12: main source of lighting fuel
           1 collected firewood/grass
           2 Puchased firewood
           3 Grass
           4 Parafin/diseal
           5 Electricity
           6 Gas
           7 Battery/dry cell
           8 Candles
           9 Other
          10 Matches
*/;
recode hh_f11 (1/3=1) (4=2) (5=3) (7=4) (6 8/10=5), gen(asset_light_fuel);

/*;
g13: cooking fuel
           1 Collected firewood
           2 Puchased firewood
           3 Paraffin
           4 Electricity
           5 Gas
           6 Charcoal
           7 Crop residue
           8 Saw dust
           9 Animal waste
          10 Other
*/;
recode hh_f12 (1/2=1) (3 6/10 14=2) (4/5=3), gen(asset_cooking_fuel);

recode hh_f19 (2=0), gen(asset_electricity);

gen comm_elect= asset_electricity;
replace comm_elect=1 if hh_f27==1;

recode hh_f31 (2=0), gen(asset_landline);
recode hh_f34 (2/20=1), gen(asset_mobile);
/*;
HH_F36: drinking water
           1 Piped into dwelling
           2 Piped into yard/plot
           3 Communal standpipe
           4 Open well in yard/plot
           5 Open public well
           6 Protected well in yard/plot
           7 Protected public well
           8 Borehole
           9 Spring
          10 River/stream
          11 Pond/lake
          12 Dam
          13 Rainwater
          14 Tanker truck/bowser
          15 Bottled water
          16 Other (specify)

*/;
recode hh_f36 (1/2=1) (3 6/8 13=2) (4/5 9/12 14/15 16=3), gen(asset_water);

/*;
g36:
           1 Flush toilet
           2 VIP latrine
           3 Traditional latrine with roof
           4 Latrine without roof
           5 None
           6 Other

g37:
           1 Household members only
           2 Other households also

*/;

gen asset_toilet=1 if (hh_f41==1 | hh_f41==2) & hh_f42==1;
replace asset_toilet=2 if (hh_f41==3) & (hh_f42==1);
replace asset_toilet=3 if (hh_f41==1 | hh_f41==2 | hh_f41==3) & inrange(hh_f42,2,6);
replace asset_toilet=4 if (hh_f41==4 | hh_f41==5 | hh_f41==6);

recode hh_f44 (2=0) (4=1), gen(asset_nets);

label var asset_house_own "Household owns (or in process of buying) dwelling residing in";
label var asset_house_age "Age of dwelling occuping, 1=0/4 yrs, 2=5/9 yrs, 3=10/14 yrs, 4=15/19 yrs, 5=20+yrs";
label var asset_house_type "Type of house 1= permanent, 2=semi-permanet, 3=traditional";
label var asset_house_wall "Wall construction material";
label var asset_house_roof "Roof construction material";
label var asset_house_floor "Floor construction material";
label var asset_house_wall_cat "Wall construction material (category)";
label var asset_house_roof_cat "Roof construction material (category)";
label var asset_house_floor_cat "Floor construction material (category)";
label var asset_house_rooms "Number of separate rooms";
label var asset_light_fuel "Fuel source for lighting (category) cat 3=clean";
label var asset_cooking_fuel "Fuel source for cooking (category) cat 3=clean";
label var asset_electricity "Household has electricity to dwelling";
label var comm_elect "Electricity within 100m of dwelling, even if none in dwelling";
label var asset_landline "Household has a landline";
label var asset_mobile "Household has at least one mobile";
label var asset_water "Water source for drinking: 1 piped, 2 other improved, 3 unimproved";
label var asset_toilet "Sanitation: 1 flush/VIP unshared, 2 latrine w/roof unshared, 3 flus/VIP/latrine w/roof & shared, 4 unimproved";
label var asset_nets "Household has mosquito nets";

drop hh*;
sort case_id;
gen round=3;

save "`d1'\hh_housing_3.dta", replace;

	*********************************
	*HOUSING CHARACTERISTICS ROUND 4
	*********************************;

	use "`d4'\hh_mod_f.dta", clear;

keep case_id hh_f01 hh_f05 hh_f06 hh_f07 hh_f08 hh_f09 hh_f10 hh_f11 hh_f12 hh_f19 hh_f27 hh_f31 hh_f34 hh_f36 hh_f41 hh_f42 hh_f44;


recode hh_f01 (1/2=1) (3/6=0), gen(asset_house_own);
recode hh_f05 (0/4=1) (5/9=2) (10/14=3) (15/19=4) (20/2000=5), gen(asset_house_age);
rename hh_f06 asset_house_type;

/*;
g08: walls
           1 Grass/Palm leaves
           2 Mud
           3 Compacted earth
           4 Mud brick
           5 Burnt bricks
           6 Concrete
           7 Wood
           8 Iron sheets
           9 Other

g09: roof
           1 Grass/Palm leaves
           2 Iron sheets
           3 Clay tiles
           4 Concrete
           5 Plastic sheeting
           6 Other

g10: floor
           1 Sand
           2 Smoothed mud
           3 Smooth cement
           4 Wood
           5 Tile
           6 Other	   
*/;

gen asset_house_wall=hh_f07;
gen asset_house_roof=hh_f08;
gen asset_house_floor=hh_f09;
recode hh_f07 (1 3=1) (2/3 8=2) (4/7=3), gen(asset_house_wall_cat);  
recode hh_f08 (1 6=1) (5=2) (2/4=3), gen(asset_house_roof_cat);
recode hh_f09 (1/2 6=1) (3/5=3), gen(asset_house_floor_cat);
gen asset_house_rooms=hh_f10;

/*;
g12: main source of lighting fuel
           1 collected firewood/grass
           2 Puchased firewood
           3 Grass
           4 Parafin/diseal
           5 Electricity
           6 Gas
           7 Battery/dry cell
           8 Candles
           9 Other
          10 Matches
*/;
recode hh_f11 (1/3=1) (4=2) (5=3) (7=4) (6 8/10=5), gen(asset_light_fuel);

/*;
g13: cooking fuel
           1 Collected firewood
           2 Puchased firewood
           3 Paraffin
           4 Electricity
           5 Gas
           6 Charcoal
           7 Crop residue
           8 Saw dust
           9 Animal waste
          10 Other
*/;
recode hh_f12 (1/2=1) (3 6/10 14=2) (4/5=3), gen(asset_cooking_fuel);

recode hh_f19 (2=0), gen(asset_electricity);

gen comm_elect= asset_electricity;
replace comm_elect=1 if hh_f27==1;

recode hh_f31 (2=0), gen(asset_landline);
recode hh_f34 (2/20=1), gen(asset_mobile);
/*;
HH_F36: drinking water
           1 Piped into dwelling
           2 Piped into yard/plot
           3 Communal standpipe
           4 Open well in yard/plot
           5 Open public well
           6 Protected well in yard/plot
           7 Protected public well
           8 Borehole
           9 Spring
          10 River/stream
          11 Pond/lake
          12 Dam
          13 Rainwater
          14 Tanker truck/bowser
          15 Bottled water
          16 Other (specify)

*/;
recode hh_f36 (1/2=1) (3 6/8 13=2) (4/5 9/12 14/15 16=3), gen(asset_water);

/*;
g36:
           1 Flush toilet
           2 VIP latrine
           3 Traditional latrine with roof
           4 Latrine without roof
           5 None
           6 Other

g37:
           1 Household members only
           2 Other households also

*/;

gen asset_toilet=1 if (hh_f41==1 | hh_f41==2) & hh_f42==1;
replace asset_toilet=2 if (hh_f41==3) & (hh_f42==1);
replace asset_toilet=3 if (hh_f41==1 | hh_f41==2 | hh_f41==3) & inrange(hh_f42,2,6);
replace asset_toilet=4 if (hh_f41==4 | hh_f41==5 | hh_f41==6);

recode hh_f44 (2=0) (4=1), gen(asset_nets);

label var asset_house_own "Household owns (or in process of buying) dwelling residing in";
label var asset_house_age "Age of dwelling occuping, 1=0/4 yrs, 2=5/9 yrs, 3=10/14 yrs, 4=15/19 yrs, 5=20+yrs";
label var asset_house_type "Type of house 1= permanent, 2=semi-permanet, 3=traditional";
label var asset_house_wall "Wall construction material";
label var asset_house_roof "Roof construction material";
label var asset_house_floor "Floor construction material";
label var asset_house_wall_cat "Wall construction material (category)";
label var asset_house_roof_cat "Roof construction material (category)";
label var asset_house_floor_cat "Floor construction material (category)";
label var asset_house_rooms "Number of separate rooms";
label var asset_light_fuel "Fuel source for lighting (category) cat 3=clean";
label var asset_cooking_fuel "Fuel source for cooking (category) cat 3=clean";
label var asset_electricity "Household has electricity to dwelling";
label var comm_elect "Electricity within 100m of dwelling, even if none in dwelling";
label var asset_landline "Household has a landline";
label var asset_mobile "Household has at least one mobile";
label var asset_water "Water source for drinking: 1 piped, 2 other improved, 3 unimproved";
label var asset_toilet "Sanitation: 1 flush/VIP unshared, 2 latrine w/roof unshared, 3 flus/VIP/latrine w/roof & shared, 4 unimproved";
label var asset_nets "Household has mosquito nets";

drop hh*;
sort case_id;
gen round=4;

save "`d1'\hh_housing_4.dta", replace;

	*********************************
	*HOUSING CHARACTERISTICS ROUND 5
	*********************************;
	
	use "`d5'\HH_MOD_F.dta", clear;

keep case_id hh_f01 hh_f05 hh_f06 hh_f07 hh_f08 hh_f09 hh_f10 hh_f11 hh_f12 hh_f19 hh_f27 hh_f31 hh_f34 hh_f36 hh_f41 hh_f41_4 hh_f44;

recode hh_f01 (1/2=1) (3/6=0), gen(asset_house_own);
recode hh_f05 (0/4=1) (5/9 2011=2) (10/14=3) (15/19=4) (20/999=5), gen(asset_house_age);
rename hh_f06 asset_house_type;

/*;
g08: walls
           1 Grass/Palm leaves
           2 Mud
           3 Compacted earth
           4 Mud brick
           5 Burnt bricks
           6 Concrete
           7 Wood
           8 Iron sheets
           9 Other

g09: roof
           1 Grass/Palm leaves
           2 Iron sheets
           3 Clay tiles
           4 Concrete
           5 Plastic sheeting
           6 Other

g10: floor
           1 Sand
           2 Smoothed mud
           3 Smooth cement
           4 Wood
           5 Tile
           6 Other	   
*/;

gen asset_house_wall=hh_f07;
gen asset_house_roof=hh_f08;
gen asset_house_floor=hh_f09;
recode hh_f07 (1 3=1) (2/3 8=2) (4/7=3), gen(asset_house_wall_cat);  
recode hh_f08 (1 6=1) (5=2) (2/4=3), gen(asset_house_roof_cat);
recode hh_f09 (1/2 6=1) (3/5=3), gen(asset_house_floor_cat);
gen asset_house_rooms=hh_f10;

/*;
g12: main source of lighting fuel
           1 collected firewood/grass
           2 Puchased firewood
           3 Grass
           4 Parafin/diseal
           5 Electricity
           6 Gas
           7 Battery/dry cell
           8 Candles
           9 Other
          10 Matches
*/;
recode hh_f11 (1/3=1) (4=2) (5=3) (7=4) (6 8/10=5), gen(asset_light_fuel);

/*;
g13: cooking fuel
           1 Collected firewood
           2 Puchased firewood
           3 Paraffin
           4 Electricity
           5 Gas
           6 Charcoal
           7 Crop residue
           8 Saw dust
           9 Animal waste
          10 Other
*/;
recode hh_f12 (1/2=1) (3 6/10 14=2) (4/5=3), gen(asset_cooking_fuel);

recode hh_f19 (2=0), gen(asset_electricity);

gen comm_elect= asset_electricity;
replace comm_elect=1 if hh_f27==1;

recode hh_f31 (2=0), gen(asset_landline);
recode hh_f34 (2/20=1), gen(asset_mobile);
/*;
HH_F36: drinking water
           1 PIPED INTO DWELLING
           2 PIPED INTO YARD/PLOT
           3 COMMUNAL STANDPIPE
           4 OPEN WELL IN YARD/PLOT
           5 OPEN PUBLIC WELL
           6 PROTECTED WELL IN YARD/PLOT
           7 PROTECTED PUBLIC WELL
           8 BOREHOLE
           9 PROTECTED SPRING
          10 RIVER/STREAM
          11 POND/LAKE
          12 DAM
          13 RAINWATER
          14 TANKER TRUCK/BOWSER
          15 BOTTLED WATER
          16 OTHER (SPECIFY)
          17 PIPED TO NEIGHBOR
          18 UNPROTECTED SPRING

*/;
recode hh_f36 (1/2 17=1) (3 6/8 13=2) (4/5 9/12 14/15 16 18=3), gen(asset_water);

/*;
g36:

           1 Flush to piped sewer system
           2 Flush to septic tank
           3 Flush to pit latrine
           4 Flush to open drain
           5 Flush to DK where
           6 Ventilated Improved Pit latrine
           7 Pit latrine with slab
           8 Pit latrine without slab /Open pit
           9 Composting toilet
          10 Bucket
          11 Hanging toilet / Hanging latrine
          12 No facility / Bush / Field
          13 Other (specify)


g37:
           1 Household members only
           2 Other households also

*/;

gen asset_toilet=1 if (hh_f41==1 | hh_f41==2| hh_f41==3) & hh_f41_4==2;
replace asset_toilet=2 if (hh_f41==6 | hh_f41==7  | hh_f41==9) & hh_f41_4==2;
replace asset_toilet=3 if (hh_f41==1 | hh_f41==2 | hh_f41==3 | hh_f41==6 | hh_f41==7  | hh_f41==9) & hh_f41_4==1;
replace asset_toilet=4 if (hh_f41==4 | hh_f41==5 | hh_f41==8 | hh_f41==10 | hh_f41==11 | hh_f41==12 | hh_f41==13);

recode hh_f44 (2=0) (4=1), gen(asset_nets);

label var asset_house_own "Household owns (or in process of buying) dwelling residing in";
label var asset_house_age "Age of dwelling occuping, 1=0/4 yrs, 2=5/9 yrs, 3=10/14 yrs, 4=15/19 yrs, 5=20+yrs";
label var asset_house_type "Type of house 1= permanent, 2=semi-permanet, 3=traditional";
label var asset_house_wall "Wall construction material";
label var asset_house_roof "Roof construction material";
label var asset_house_floor "Floor construction material";
label var asset_house_wall_cat "Wall construction material (category)";
label var asset_house_roof_cat "Roof construction material (category)";
label var asset_house_floor_cat "Floor construction material (category)";
label var asset_house_rooms "Number of separate rooms";
label var asset_light_fuel "Fuel source for lighting (category) cat 3=clean";
label var asset_cooking_fuel "Fuel source for cooking (category) cat 3=clean";
label var asset_electricity "Household has electricity to dwelling";
label var comm_elect "Electricity within 100m of dwelling, even if none in dwelling";
label var asset_landline "Household has a landline";
label var asset_mobile "Household has at least one mobile";
label var asset_water "Water source for drinking: 1 piped, 2 other improved, 3 unimproved";
label var asset_toilet "Sanitation: 1 flush/VIP unshared, 2 latrine w/roof unshared, 3 flush/VIP/latrine w/roof & shared, 4 unimproved";
label var asset_nets "Household has mosquito nets";

drop hh*;
sort case_id;
gen round=5;

save "`d1'\hh_housing_5.dta", replace;

*********************************
***  geographic location vars *
*********************************

*****************;
***  IHS 3 ******;
*****************;
loc round			3;
loc data_in			"`d3'\householdgeovariables.dta";	  //input data;
loc data_geo`round'		"`d1'\geo_`round'.dta";

use `data_in', clear;

keep case_id lat_modified lon_modified;

gen round=3;
sort case_id;

save `data_geo`round'', replace;

*****************;
***  IHS 4 ******;
*****************;
loc round			4;
loc data_in			"`d4'\HouseholdGeovariablesIHS4.dta";	  //input data;
loc data_geo`round'		"`d1'\geo_`round'.dta";

use `data_in', clear;


keep case_id lat_modified lon_modified;

gen round=4;

sort case_id;

save `data_geo`round'', replace;

*****************;
***  IHS 5 ******;
*****************;
loc round			5;
loc data_in			"`d5'\MWI_HouseholdGeovars_IHS5.dta";	  //input data;
loc data_geo`round'		"`d1'\geo_`round'.dta";

use `data_in', clear;

rename ea_lat_mod lat_modified;
rename ea_lon_mod lon_modified;

replace lon_modified=. if lon_modified==0;
replace lat_modified=. if lat_modified==0;

keep case_id lat_modified lon_modified;

gen round=5;

sort case_id;

save `data_geo`round'', replace;


******************************
** interview data ***********
****************************

*****************;
***  IHS 3 ******;
*****************;
loc round			3;
loc data_in			"`d3'/hh_mod_a_filt.dta";			//input data;

use `data_in', clear;

keep case_id qx_type hh_a23_1 hh_a23a_1 hh_a23b_1 hh_a23c_1 hh_a23_2 hh_a23a_2 hh_a23b_2 hh_a23c_2;

rename hh_a23_1 int_date_1;
rename hh_a23a_1 int_day_1;
rename hh_a23b_1 int_month_1;
rename hh_a23c_1 int_year_1;
rename hh_a23_2 int_date_2;
rename hh_a23a_2 int_day_2;
rename hh_a23b_2 int_month_2;
rename hh_a23c_2 int_year_2;

label var int_day_1 "Interview day, first visit";
label var int_month_1 "Interview month, first visit";
label var int_year_1 "Interview year, first visit";
label var int_date_1 "Interview date in mdy, first visit";

label var int_day_2 "Interview day, second visit";
label var int_month_2 "Interview month, second visit";
label var int_year_2 "Interview year, second visit";
label var int_date_2 "Interview date in mdy, second visit";

foreach var in int_day int_month int_year int_date{;
	gen `var'=`var'_1 if qx_type=="Cross-Section" | qx_type=="Panel A";
	replace `var'=`var'_2 if qx_type=="Panel B";
};

format int_date %dD_m_Y  ;

label var int_day "Interview day";
label var int_month "Interview month";
label var int_year "Interview year";
label var int_date "Interview date in mdy";

gen round=3;

save "`d1'\int_date_3.dta", replace;	

*****************;
***  IHS 4 ******;
*****************;
loc round			4;
loc data_in			"`d4'/HH_METADATA.dta";			//input data;

use `data_in', clear;

keep case_id  moduleB_start_date moduleG_start_date moduleH_start_date moduleI_start_date moduleJ_start_date moduleK_start_date moduleR_start_date moduleU_start_date;

gen diffGH=1 if moduleG_start_date ~= moduleH_start_date; 
gen diffGI=1 if moduleG_start_date ~= moduleI_start_date;
gen diffGJ=1 if moduleG_start_date ~= moduleJ_start_date;  
gen diffGK=1 if moduleG_start_date ~= moduleK_start_date; 
gen diffGU=1 if moduleG_start_date ~= moduleU_start_date;
 
summ diff*;

gen int_date = date(moduleG_start_date, "YMD");
format int_date %dD_m_Y;

gen int_day = day(int_date);
gen int_month = month(int_date);
gen int_year = year(int_date);

label var int_day "Interview day";
label var int_month "Interview month";
label var int_year "Interview year";
label var int_date "Interview date in mdy";

gen round=4;

save "`d1'\int_date_4.dta", replace;	



