
#delimit ;

loc d1 			"./Input_Data/Household_Survey/Malawi/Dataprep";
loc d2 			"./Input_Data/Household_Survey/Malawi/Dataprep/IHS5";


*********************************
*HOUSEHOLD IDENTIFIER
*********************************;

*Getting household ID, EA ID, and household weight;

use "`d2'\HH_MOD_A_withearlyhhwts.dta", clear;

gen HHID_temp=HHID;
drop HHID;
gen HHID=case_id;
sort case_id ea_id;
* Location & Survey Design variables;
	*Urban/Rural;
rename reside urban	;						//Urban/rural Identifier;
label var urban "Urban/rural";
	*Region;
label define region_l 1 North 2 Central 3 South;
label val region region_l;
	*Urban/Rural by Region;
gen 	urban_region = .	;				//Rura/Urban by Region;
replace urban_region = 1 if urban==1;
replace urban_region = 2 if urban==2 & region==1;
replace urban_region = 3 if urban==2 & region==2;
replace urban_region = 4 if urban==2 & region==3;
label var urban_region "Rural/Urban division by region";

label define urban_region_l 1 "Urban" 2 "Rural North" 3 "Rural Centre" 4 "Rural South";
label val urban_region urban_region_l;

 *District;  
label var district "District";
tab district, m;

 *Traditional Authority ;
d hh_a02a;
gen TA = hh_a02a;
label var TA "Traditional Authority";

		*Survey Time;
split interviewDate,p(-) ;					//Spliting Survey time variable into date, monty and year;
rename interviewDate1 syear;
rename interviewDate2 smonth;
rename interviewDate3 sdate;
label var sdate "Day of month for interview";
label var smonth "Month of interview";
label var syear "Year of interview";
destring sdate smonth syear,replace;
foreach v in date month year{	;			//Apply EA survey time for missing HHs;
egen c_s`v'=max(s`v'), by(ea_id);
replace s`v'=c_s`v' if s`v'==.;
} ;
tab smonth syear, m	;						//Cross-tab survey month and year;

label define month_l 1 January 2 February 3 March 
	4 April 5 May 6 June 7 July 8 August  9 September 
	10 October 11 November 12 December;
label val smonth month_l;

*local variables HHID case_id ea_id district TA region 
	urban_region urban sdate smonth 
	syear  hh_wgt; 
*NOTE: need to update when have weight!!!!!!;	
local variables HHID HHID_temp case_id ea_id district TA region 
	urban_region urban sdate smonth 
	syear Prel_hh_weight; 
	
keep  `variables';
order `variables';
compress;
sort HHID;
save "`d2'\c_HH_MOD_A_FILT", replace;


	*********************************
	*HH CHARACTERISTICS
	*********************************;
use "`d2'\HH_MOD_B", clear;
drop HHID;
gen HHID=case_id;
sort case_id PID ;
merge 1:1 case_id PID using "`d2'\HH_MOD_C.dta";

****Adult Equivalence (AE);
inspect hh_b05a;								//Inspect the age variable for unexpected figure;
gen age = hh_b05a;
gen 	factorAE = .;						//Create AE variable to accompany HH size;
replace factorAE = 0.33 if age<1;
replace factorAE = 0.47 if inrange(age,1,2);
replace factorAE = 0.55 if inrange(age,2.01,3);
replace factorAE = 0.63 if inrange(age,3.01,5);
replace factorAE = 0.73 if inrange(age,5.01,7);
replace factorAE = 0.79 if inrange(age,7.01,10);
replace factorAE = 0.84 if inrange(age,10.01,12);
replace factorAE = 0.91 if inrange(age,12.01,14);
replace factorAE = 0.97 if inrange(age,14.01,16);
sum age;
replace factorAE = 1.00 if inrange(age,16.01,r(max));
label var factorAE "Adult Equivalent factor";
egen hhsize = sum(1), by(HHID);
egen nchild = sum(1) if age<15, by(HHID);
egen nelder = sum(1) if age>65 & age~=., by(HHID);
egen nworker= sum(1) if age>=15 & age<=65, by(HHID);
gen head_female=hh_b03 if hh_b04==1;
gen spouse_female=hh_b03 if hh_b04==2;
egen spouse_female2=max(spouse_female),  by(HHID);
replace head_female=1 if hh_b04==1 & head_female~=. & spouse_female2==2;	//Apply opposit gender, if head gender is missing;
replace head_female=2 if hh_b04==1 & head_female~=. & spouse_female2==1;	//Apply opposit gender, if head gender is missing;
drop spouse_female*;
recode head_female (2=1) (1=0);
gen head_age=hh_b05a if hh_b04==1;
gen head_literate=hh_c06 if hh_b04==1;
recode head_literate (2=0);

//change from habtamu's code in that form 5 and 6 are assinged 12 yrs of edu i form5 or 6 of secondary;
g years_edu=.;								//Years of education; 
replace years_edu=hh_c08 if hh_c08<=12;
replace years_edu=12 if hh_c08==13 | hh_c08==14;
replace years_edu=13 if hh_c08==15 | hh_c08==20;
replace years_edu=14 if hh_c08==16 | hh_c08==21;
replace years_edu=15 if hh_c08==17 | hh_c08==22;
replace years_edu=16 if hh_c08==18 | hh_c08==23;
replace years_edu=17 if hh_c08==19;
replace years_edu=0 if hh_c06==2;

/* End up not doing anything;
replace years_edu=17 if years_edu==. & (hh_c09==8 | hh_c09==9);
replace years_edu=14 if years_edu==. & (hh_c09==4 | hh_c09==5 | hh_c09==6| hh_c09==7);
replace years_edu=10 if years_edu==. & (hh_c09==3);
replace years_edu=8 if years_edu==. & (hh_c09==2);
*/;
gen head_educ=years_edu if hh_b04==1;
gen spouse_educ=years_edu if hh_b04==2;
egen adult_av_educ=mean(years_edu) if age>=15, by(HHID);
rename hh_b23 head_relgion ;
replace head_relgion=. if hh_b04!=1;
rename hh_b24 head_marital; 
replace head_marital=. if hh_b04!=1;
gen head_rChichewa=0 if hh_b04==1;
replace head_rChichewa=1 if (hh_c05_2a==1 | hh_c05_2b==1) & hh_b04==1;
gen head_rEnglish=0 if hh_b04==1;
replace head_rEnglish=1 if (hh_c05_2a==14 | hh_c05_2b==14) &  hh_b04==1;
preserve;

keep case_id PID hh_b04 age years_edu; 
save "`d2'\cc_ind_mod_b", replace	;		//Save individual level info;
restore;
 
local first hhsize nchild nelder nworker head_female head_age 
	head_literate head_educ 
	spouse_educ adult_av_educ head_relgion head_rChichewa 
	head_rEnglish;
local sumv factorAE;

collapse (firstnm) `first' (sum) `sumv' , by(HHID); 
foreach j in nchild nelder nworker{;
replace `j'=0 if `j'==.;
};
gen dratio=(nchild +nelder)/nworker;		//Total dependency ratio;
gen cdratio=nchild/nworker;				//Child dependency ratio;	
gen odratio=nelder/nworker;				//Old age dependency ratio;
qui sum dratio, det;
foreach d in dratio cdratio odratio{;
replace  `d'=r(p99) if nworker==0;		//No worker, assum high dep ratio;
};
label define gender 0 "Male" 1 "Female" ; 
label values head_female gender;
label define yesno 0 "No" 1 "Yes", replace;  
label values head_literate head_rChichewa head_rEnglish yesno;
rename factorAE adulteq;
summ hhsize adulteq, d;
compare hhsize adulteq	;					//Comparative statistics;
label var adulteq "Adult equivalence" ;
label var hhsize "Household size";
label var nchild "Number of children under age of 15";
label var nelder "Number elder members above 65 years of age";
label var nworker "Number of working age members (15-65)";
label var dratio "(Total) Dependence ratio";
label var cdratio "Child dependence ratio";
label var odratio "Old age dependence ratio";
label var head_female "=1 if  the household head is female";
label var head_age "Age of household head in years"; 
label var head_literate "Is the hh head literature (been to school), 1=Yes";
label var head_educ "Years of education of the HH head";
label var spouse_educ "Years of education of the head's spouse";
label var adult_av_educ "Average years of education for adult members (>15 years of age)";
label var head_relgion "Head's religion";
label var head_rChichewa "Head can read in Chichewa"; 
label var head_rEnglish "Head can read in English";
sort HHID;
order HHID adulteq `first';  
save "`d2'\c_hh_mod_b", replace;

/*
	*********************************
	*LABOR/TIME USE
	*********************************;
use "`d1'\Data\IHS5\Household\HH_MOD_E", clear;
merge 1:1 case_id PID  using "`d2'\Household\Temp\cc_hh_mod_b", nogen keep(3);		//Bring age;
drop HHID;
rename case_id HHID;

keep if age>=15;										//Adult members only;
local act hh_e07a hh_e07b hh_e07c hh_e08 hh_e09 hh_e10 hh_e11 hh_e12;
egen act_any=rowtotal(`act');						//Engaged in any economic activity;
egen act_ag=rowtotal(hh_e07a hh_e07b hh_e07c);			//Engaged in agricultural activities;
egen act_enterp=rowtotal(hh_e08- hh_e09);			//Engaged in non-agricultural activities;
gen act_ganyu=hh_e10;								//Engaged in casual job/ganyu;
gen act_wage=hh_e11;									//Engaged in wage employment;	
gen act_unpaid=hh_e11;								//Engaged in unpaid internship;

gen emplyd7_d=(act_any>1);							//Empoyed in any activity (at leat 1 hour);	
gen emplyd7_ag=(act_ag>0);							//Empoyed in family agricultural activities;
gen emplyd7_enterp=(act_enterp>0);					//Empoyed in non-farm enterprise;
gen emplyd7_wage=(act_wage>0);						//Empoyed for wage;
gen emplyd7_ganyu=(act_ganyu>0);					//Empoyed as ganyu/casual labor;
foreach v in d ag enterp wage ganyu{;
gen head_emplyd7_`v'=emplyd7_`v' if hh_b04==1;		//Head engaged in the activities listed;
};

	*Industry of wage employment (TBD);
	
	*Wage income, TBD;

local firstnm head_emplyd7_*;
local meanv  emplyd7_*; 
collapse (mean) `meanv' (firstnm) `firstnm', by(HHID);
label var emplyd7_d "Share of adult members employed in any activity (ag, enterprise, wage, hh chores etc.), past 7 days";
label var emplyd7_ag "Share of adult members engaged in family agriculture, past 7 days";
label var emplyd7_enterp  "Share of adult members engaged family non-agriculture enterprise, past 7 days";
label var emplyd7_wage "Share of adult members engaged inwage employment, past 7 days";
label var emplyd7_ganyu "Share of adult members engaged in ganyu/casual jobs, past 7 days";
	
label var head_emplyd7_d "Is the head employed in any activity (ag, enterprise, wage, hh chores etc.), past 7 days";
label var head_emplyd7_ag "Is the head engaged in family agriculture, past 7 days";
label var head_emplyd7_enterp  "Is the head engaged family non-agriculture enterprise, past 7 days";
label var head_emplyd7_wage "Is the head engaged inwage employment, past 7 days";
label var head_emplyd7_ganyu "Is the head engaged in ganyu/casual jobs, past 7 days";
label define yesno 0 "No" 1 "Yes", replace;  
label values head_emplyd7_* yesno;
save "`d2'\Household\Temp\c_hh_mod_e", replace;

	*********************************
	*FOOD INSECURITY
	*********************************;
use "`d1'\Data\IHS5\Household\HH_MOD_H", clear;
drop HHID;
gen HHID=case_id;
rename hh_h01 food_insecure7;				//Food insecurity in the past 7 days;
rename hh_h04 food_insecure12;				//Food insecurity in the past 12 months;
label var food_insecure7 "HH reported food insecurity in the past 7 days";
label var food_insecure12 "HH reported food insecurity in the past 12 months";

/*EXTRACT COPPING MECHANISM AND MONTHS OF FOOD INSECURITY:
forvalues j=10/11{
rename hh_h05a_`j' hh_h05a_`=`j'+2'
}
qui foreach v of varlist hh_h05*_*  {
replace `v'="1" if `v'=="x" | `v'=="X"
destring `v', replace force
}
qui forvalues j=1/9{
egen finsecur12_m0`j'=rowtotal(hh_h05*_0`j')
}
qui forvalues j=10/12{
egen finsecur12_m`j'=rowtotal(hh_h05*_`j')
}
gen finsecure_month=1 if 
*/
keep HHID food_*;
save "`d2'\Household\Temp\c_hh_mod_h", replace;

	*********************************
	*INPUT PRICE SHOCKS
	*********************************;
use "`d1'\Data\IHS5\Household\HH_MOD_U.dta", clear;
keep if hh_u0a==107;
g inputprshock=hh_u01==1 ;
keep case_id inputprshock;
rename case_id HHID;
label var inputprshock "HH faced input price shocks";
save "`d2'\Household\Temp\c_hh_mod_u.dta", replace;

/*;
*/;
*/;
*/
	*********************************
	*CONSUMPTION AGGREGATES
	*********************************;
use "`d2'\tconsumption_ihs5.dta";

rename HHID HHID_temp;

loc consum "rexp_cat021- rexp_cat12 price_indexL rexpagg";

foreach var of varlist `consum'{;
	rename `var' `var'_r19;
};

save "`d2'\c_tcons", replace;
*/
***************************
***************************
***************************

********************B) Section II: Agriculture

	*********************************
	*Module a: Filter
	*********************************;

use "`d2'\AG_MOD_R1.dta", clear;
drop HHID;
rename case_id HHID;
rename ag_r00 hh_livestock;
recode  hh_livestock (2=0);
collapse (max)hh_livestock, by(HHID);
label var hh_livestock "Does the hh own any livestock, past 12 months?";
save "`d2'\cc_ag_mod_r1", replace;

	*Module C & D: Plot level information
	*********************************;
	
use "`d2'\AG_MOD_D.dta", clear;
duplicates	drop case_id gardenid plotid, force;
egen PLID=concat(case_id gardenid plotid);
save "`d2'\c_ag_mod_d", replace;

use "`d2'\AG_MOD_C.dta", clear;
duplicates	drop case_id gardenid plotid, force;
egen PLID=concat( case_id gardenid plotid);
merge 1:1 PLID using "`d2'\c_ag_mod_d.dta", nogen keep(3)	;	//Combine module c & d;
	*Cultivated land ;
drop HHID;
rename case_id HHID;
replace ag_c04a=ag_c04a*2.471 if ag_c04b==2	;		//Hectare to acre;
replace ag_c04a=ag_c04a*2.471/1000 if ag_c04b==3;	//Meter square to acre;
compare ag_c04a ag_c04c	;							//Compare reported and GPS measure areas of plots;
replace ag_c04c=ag_c04a if ag_c05e~=.	;			//Update GPS area by reported area if not GPS measured;
replace ag_c04c=ag_c04a if ag_c04c==. & ag_c04a!=.;	//Update GPS area by reported area if it is missing;
qui sum ag_c04c, det;
replace ag_c04c=ag_c04a if ag_c04c>r(p99) & ag_c04c!=.;	//Update extreme values of GPS measured by self-reported;
qui sum ag_c04a, det;
replace ag_c04a=ag_c04c if ag_c04a>r(p99) & ag_c04a!=.;	//Update extreme values of self reported by GPS measured area;
egen cult_land_r=sum(ag_c04a), by(HHID)	;			//Cultivated land, reported by HH;
egen cult_land_gps=sum(ag_c04c), by(HHID);			//Cultivated land, GPS measured;

/*
	*Land allocated to each crop (Main crop);
egen land_mcmaize=sum(ag_c04c)  if ag_d20a<=4, by(HHID);
egen land_mctobacco=sum(ag_c04c)if inrange(land_, 5,10), by(HHID);
egen land_mcnuts=sum(ag_c04c) 	if inrange(ag_d20a,11,16), by(HHID);
egen land_mcrice=sum(ag_c04c) 	if inrange(ag_d20a,17,26), by(HHID);
egen land_mcpotato=sum(ag_c04c) if inrange(ag_d20a,28,29), by(HHID);
egen land_mcothercrops=sum(ag_c04c) if ag_d20a==27 | inrange(ag_d20a,30,48), by(HHID);
tabstat land_*, by(ag_d20a)	;						//Check label vs. land;


	*Land allocated to each crop (pure stand only);
sum ag_d20a-ag_d20e;
gen crop_ps=1;										//Plot is pure stand (not mixed);
replace crop_ps=0 if ag_d20b~=. | ag_d20c~=. | ag_d20d~=. | ag_d20e~=.  ;
label var crop_ps "Plot is pure stand (not mixed)";
egen land_psmaize=sum(ag_c04c)  if crop_ps==1 & ag_d20a<=4, by(HHID);
egen land_pstobacco=sum(ag_c04c)if crop_ps==1 & inrange(ag_d20a, 5,10), by(HHID);
egen land_psnuts=sum(ag_c04c) 	if crop_ps==1 & inrange(ag_d20a,11,16), by(HHID);
egen land_psrice=sum(ag_c04c) 	if crop_ps==1 & inrange(ag_d20a,17,26), by(HHID);
egen land_pspotato=sum(ag_c04c) if crop_ps==1 & inrange(ag_d20a,28,29), by(HHID);
egen land_psothercrops=sum(ag_c04c) if crop_ps==1 & ag_d20a==27 | inrange(ag_d20a,30,48), by(HHID);
	*Land allocated to each crop (Mixed planting only);
egen land_msmaize=sum(ag_c04c)  if crop_ps==0 & ag_d20a<=4, by(HHID);
egen land_mstobacco=sum(ag_c04c)if crop_ps==0 & inrange(ag_d20a, 5,10), by(HHID);
egen land_msnuts=sum(ag_c04c) 	if crop_ps==0 & inrange(ag_d20a,11,16), by(HHID);
egen land_msrice=sum(ag_c04c) 	if crop_ps==0 & inrange(ag_d20a,17,26), by(HHID);
egen land_mspotato=sum(ag_c04c) if crop_ps==0 & inrange(ag_d20a,28,29), by(HHID);
egen land_msothercrops=sum(ag_c04c) if crop_ps==0 & ag_d20a==27 | inrange(ag_d20a,30,48), by(HHID);
	*Land rental/sales value (total);
/*Note: These variables (d03-d13) were removed in IHS4.*/
*egen salev_land=sum(ag_d05), by(HHID)				//Sales value of land owned by HH
*egen rentalv_land=sum(ag_d06), by(HHID)				//Rental value of land owned by HH
	*Fertilizer application dummy;
gen fert_d=(ag_d38==1)	;							//Fertilizer applied to the plot;
egen fert_nplot=sum(fert_d), by(HHID)	;			//Number plots treated with fertilizer;
*/
egen nplot=sum(1), by(HHID)		;					//Number of plot the HH owns;
/*
gen fert_snplot=fert_nplot/nplot;					//Share of plots (count) treated with fertilizer;
egen fert_aplot=sum(ag_c04c) if fert_d==1, by(HHID); //Total area of cultivated land treated with fertilizer;
egen fert_maizeplot=sum(ag_c04c) if fert_d==1
	& ag_d20a<=4, by(HHID);							//Maize plot area of cultivated land treated with fertilizer
	*Fertilizer quantity;
*1st application;
gen ag_d39bkg=ag_d39b if ag_d39c==2;				//Converting subsidized inputs into KG ;
replace ag_d39bkg=ag_d39b*0.001 if ag_d39c==1;
replace ag_d39bkg=ag_d39b*3 if ag_d39c==4;
replace ag_d39bkg=ag_d39b*5 if ag_d39c==5;
replace ag_d39bkg=ag_d39b*10 if ag_d39c==6;
replace ag_d39bkg=ag_d39b*50 if ag_d39c==7;
sum ag_d39bkg,d;
compare ag_d39bkg ag_d39d;						//Mostly equa: Reported by HH in different vs. KG quant reported by enumerator;
replace ag_d39bkg=ag_d39d if ag_d39bkg==. ;		//Update using kg reported by enumerator if HH reported value is missing (other) *2nd application;
gen ag_d39hkg=ag_d39h if ag_d39i==2	;			//Converting subsidized inputs into KG ;
replace ag_d39hkg=ag_d39h*0.001 if ag_d39i==1;
replace ag_d39hkg=ag_d39h*3 if ag_d39i==4;
replace ag_d39hkg=ag_d39h*5 if ag_d39i==5;
replace ag_d39hkg=ag_d39h*10 if ag_d39i==6;
replace ag_d39hkg=ag_d39h*50 if ag_d39i==7;
sum ag_d39hkg,d;
compare ag_d39hkg ag_d39h;						//Mostly equa: Reported by HH in different vs. KG quant reported by enumerator;
replace ag_d39hkg=ag_d39i if ag_d39bkg==. ;		//Update using kg reported by enumerator if HH reported value is missing (other)
*Total application;
egen qfert_plot=rowtotal(ag_d39bkg ag_d39hkg);	//Total quantity of fertilizer on each plot (1st & 2nd application);
rename ag_d39hkg ag_d39gkg;						//To make it consistent with IHS3.; 
gen qfert_peracre=qfert_plot/ag_c04c;
egen fert_kgacre=mean(qfert_peracre), by(HHID);	//Intensity of fertilizer (kg/acre), all crops;
*egen fert_kgacre_maize=mean(qfert_peracre) if  g_d20a<=4, by(HHID);						//Intensity of fertilizer application(kg/acre) on Maize plot ;
	*Pesticide;
gen pesticide=(ag_d40==1)	;					//Pesticide on any plot;
	*Labor TBD;
	*Land;
foreach v in maize tobacco nuts rice potato othercrops{;
replace land_mc`v'=0 if land_mc`v'==.;
label var land_mc`v' "Cultivated land(acre) allocated to `v' (main crop), both mixed & pure stand";
replace land_ps`v'=0 if land_ps`v'==.;
label var land_ps`v' "Cultivated land(acre) allocated to `v' (pure stand only)";
replace land_ms`v'=0 if land_ms`v'==.;
label var land_ms`v' "Cultivated land(acre) allocated to `v' (mixed crop only)";
};
foreach v in sale rental{;
*label var `v'v_land "The `v' value of land owned by HH (MWK)";
};
label var fert_kgacre "Fertilizer application intensity, kg/acre (all crops)";
*label var fert_kgacre_maize "Fertilizer application intensity, kg/acre (maize)";
label var pesticide "Has the HH applied pesticide on any plot for any crop?";
label var nplot "Number plots owned by the HH";
label var fert_nplot "Number plots treated with fertilizer";
label var fert_snplot "Proportion of plots (count) treated with fertilizer";
*/
save "`d2'\cc_ag_mod_c-d.dta", replace;			//Save it at plot level;

local firstnm cult_land_*  nplot; //*v_land ;

collapse (firstnm) `firstnm', by(HHID);

label var cult_land_r "Total area of cultivated land (acre), reported by hh";
label var cult_land_gps "Total area of cultivated land (acre), GPS measured";
label var nplot "Number plots owned by the HH";

sort HHID;
save "`d2'\c_ag_mod_c-d.dta", replace; 		//Save it at HH level;


***************************************
*GEN household level dataset to merge *;
***************************************;

use "`d2'\c_HH_MOD_A_FILT", clear;

sort HHID_temp;

merge 1:1 HHID_temp using "`d2'\c_tcons";

gen round=5;

sort HHID;
drop _merge;

merge 1:1 HHID using "`d2'\c_hh_mod_b";

sort HHID;

drop _merge;


merge 1:1 HHID using "`d2'\c_ag_mod_c-d.dta";
drop _merge;

sort HHID;


save "`d1'\IHS5_hh", replace;


erase "`d2'\c_HH_MOD_A_FILT.dta";
erase "`d2'\cc_ind_mod_b.dta";
erase "`d2'\c_hh_mod_b.dta";
erase "`d2'\c_tcons.dta";
erase "`d2'\cc_ag_mod_r1.dta";
erase "`d2'\c_ag_mod_d.dta";
erase "`d2'\cc_ag_mod_c-d.dta";
erase "`d2'\c_ag_mod_c-d.dta";