#delimit ;

loc d1 			"./Input_Data/Household_Survey/Malawi/Dataprep";


loc pline_4		137428;				//pline in round 4 to normalize by;

loc ppp_16		526.2;				//poverty line based on 1.9ppp per day per person in 2016 MK (not sure which month though);

loc cpi_imf_0416	295.75;			//used to convert from April 2016 prices (rounds 2-4) to April 2019 price (round 5);
loc cpi_imf_0419	405.86;


*************************************************
*** Round 5 data *******
**************************************************;

do Do_Files/Country/Malawi/IHS5_data.do;
do Do_Files/Country/Malawi/IHS25_add.do;


*************************************************
*** Adding  round 5 and additional data from all rounds *******
**************************************************;

use "`d1'\c_IHS2&3&4.dta", clear;

gen round=2 if syear==.;
replace round=3 if syear==2010 | syear==2011;
replace round=4 if syear==2016 | syear==2017;

drop if round==2;

drop if case_id=="";
cap drop _merge;

sort round case_id;


*********************************
** merge with round 5 base data *
*********************************;

append using "`d1'\IHS5_hh.dta";

*******************
**  housing  *
*******************;


merge 1:1 round case_id using "`d1'\hh_housing_3.dta", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\hh_housing_4.dta", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\hh_housing_5.dta", update;

tab _merge;
drop _merge;


sort round case_id;


*******************
**  geo codes *
*******************;

*not collected for round 2;

merge 1:1 round case_id using "`d1'\geo_3", update;

tab _merge;
drop _merge;

sort round case_id;
merge 1:1 round case_id using "`d1'\geo_4", update;

tab _merge;
drop _merge;

sort round case_id;
merge 1:1 round case_id using "`d1'\geo_5", update;

tab _merge;
drop _merge;

/*
**********************
*** community access *
**********************;
merge m:1 round ea_id using "`d1'\Dataprep\IHS5/comm_access_5", update;

tab _merge;
drop _merge;

merge m:1 round ea_id using "`d1'\Dataprep\IHS4/comm_access_4", update;

tab _merge;
drop _merge;

merge m:1 round ea_id using "`d1'\Dataprep\IHS3/comm_access_3", update;

tab _merge;
drop _merge;

merge m:1 round dist ta ea using "`d1'\Dataprep\IHS2/comm_access_2", update;

tab _merge;
drop _merge;


sort round case_id;
*******************
**  food security *
*******************;

merge 1:1 round case_id using "`d1'\Dataprep\IHS2/fs_2", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Dataprep\IHS3/fs_3", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Dataprep\IHS4/fs_4", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Dataprep\IHS5/fs_5", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Dataprep\IHS3/fs2_3", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Dataprep\IHS4/fs2_4", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Dataprep\IHS5/fs2_5", update;

tab _merge;
drop _merge;

label var fcs "Food consumption score (slightly modified)";

*******************
**  FEIS *
*******************;
merge 1:1 round case_id using "`d1'\Dataprep\IHS4/hh_feis_4", update;

tab _merge;
drop _merge;

/*
merge 1:1 round case_id using "`d1'\Data\IHS5/hh_feis_5", update;

tab _merge;
drop _merge;
*/;

*******************
**  safety nets *
*******************;

merge 1:1 round case_id using "`d1'\Dataprep\IHS2/safety_2", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Dataprep\IHS3/safety_3", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Dataprep\IHS4/safety_4", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Dataprep\IHS5/safety_5", update;

tab _merge;
drop _merge;

*******************
**  shocks and coping *
*******************;

merge 1:1 round case_id using "`d1'\Dataprep\IHS2/shocks_2", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Dataprep\IHS3/shocks_3", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Dataprep\IHS4/shocks_4", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Dataprep\IHS5/shocks_5", update;

tab _merge;
drop _merge;
*/
*******************
**  interview date  *
*******************;

merge 1:1 round case_id using "`d1'\int_date_3", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\int_date_4", update;

tab _merge;
drop _merge;

replace int_day = sdate if round==5;
replace int_month = smonth if round==5;
replace int_year = syear if round==5;

replace int_date=mdy(int_month,int_day,int_year) if round==5;
*/
/*
merge 1:1 round case_id using "`d1'\int_date_5", update;

tab _merge;
drop _merge;
*/;

********************
** UPDATES TO DATA *
**************************;

gen rural=0;
replace rural=1 if urban==2 & (round==3 | round==4 |round==5);
replace rural=1 if urban==1 & round==2;

label var rural 	"Rural household";

drop urban;
bysort round: tab rural;

tab distr if rural==0;


*************************
** converting to real 16 *
**************************;

*For round 3 there is for some reason an additional step needed in order to get the real survey specific values;

merge 1:1 round case_id using "`d1'\IHS3\rexp_ratio.dta";

tab _merge;
drop _merge;

*save "`d1'/IHS2345_app.dta", replace;


 *******************************
 ** merge with free maize data **
 *******************************;
/*
use "`d1'/Dataprep\IHS2345_app.dta", clear;

merge 1:1 case_id round using "`d1'\Dataprep\IHS3\market_3.dta", update;

tab _merge;
drop _merge;

merge 1:1 case_id round using "`d1'\Dataprep\IHS4\market_4.dta", update;

tab _merge;
drop _merge;

save "`d1'/Dataprep\IHS2345_app.dta", replace;

 *******************************
 ** merge with zone info**
 *******************************;

use "`d1'/Dataprep\IHS2345_app.dta", clear;

sort district;

merge m:1 district using "`d1'\Dataprep\zones1.dta", update;

tab _merge;
*list district round if _merge==1;

drop _merge;

save "`d1'/Dataprep\IHS2345_app.dta", replace;
*/
 *******************************
 ** merge with CPI **
 *******************************;

*use "`d1'/IHS2345_app.dta", clear;

sort int_year int_month;

merge m:1 int_year int_month using "`d1'\cpi_imf.dta", update;

tab _merge;
*list district round if _merge==1;

drop if _merge==2;

drop _merge;

*** gen deflator for 2016;
gen deflator16= rexpagg/expagg if round==4;
gen deflator19= rexpagg_r19/expagg if round==5;

*** gen total expeditures (from pc expenditures);
gen rexpagg16_total= rexpaggpc16 * hhsize;
label var rexpagg16_total "Total expenditures in real 2016 MK";


gen expagg_cpi_total=expagg/cpi_imf;

replace rexpagg_r19=rexpagg16_total*(`cpi_imf_0419'/`cpi_imf_0416') if inrange(round, 2, 4);

gen rexpagg_pc_r19=rexpaggpc16*(`cpi_imf_0419'/`cpi_imf_0416');
replace rexpagg_pc_r19=rexpagg_r19/hhsize if round==5;

gen rexpfood_pc_r19=rexp_cat01_r19/hhsize if round==5;
replace rexpfood_pc_r19= rexpfood * 8.5015775 * (`cpi_imf_0419'/`cpi_imf_0416')/hhsize if round==2;
replace rexpfood_pc_r19= rexp_cat01 * 3.7141016 * (`cpi_imf_0419'/`cpi_imf_0416')/hhsize if round==3;
replace rexpfood_pc_r19= rexp_cat01 * (`cpi_imf_0419'/`cpi_imf_0416')/hhsize if round==4;

label var rexpagg_pc_r19 "Total expenditures per capita in April 2019 MK";
label var rexpfood_pc_r19 "Total food expenditures per capita in April 2019 MK";

bysort round: summ rexpagg_pc_r19 rexpfood_pc_r19 [aw=hh_wgt], detail;

*order round rexpagg_pc_r19 hhsize rexpagg16_total rexpagg_pc_r19 rexpagg16pc;
sort rexpagg_pc_r19;
/*
sort district ;
merge m:1 district using  "`d1'\Dataprep\shocks\district_rf_merge";
keep if _m==3;
drop _m ;
*/
/*
replace gid_1 = trim(gid_1) ;
recast str9 gid_1;
format gid_1 %9s;
label var gid_1 "GADM Level 1";
*/
recast float int_month;
label var int_month "Interview Month";
 
recast float int_year;
label var int_year "Interview Year";


gen ln_size = ln(hhsize);

*gen ln_fcs = ln(fcs);
*gen ln_hdds = ln(hdds);

gen urban_area = (urban_region==1);

replace hh_wgt = Prel_hh_weight if hh_wgt ==.;

gen case_id_2 = "r3"+case_id if round==3;
replace case_id_2 = "r4"+case_id if round==4;
replace case_id_2 = "r2"+case_id if round==2;
replace case_id_2 = "r5"+case_id if round==5;

drop if case_id=="";
/*
merge m:1 gid_1 using "C:\Users\Katja\Documents\CONSULTING\Malawi\Data\MWI_centroids.dta";

drop _merge;
*/

*save "`d1'/IHS2345_all.dta", replace;

keep  HHID rexpagg_pc_r19 rexpfood_pc_r19 district lat_modified lon_modified ea_id hh_wgt pline_2016 int_year int_month  asset_house_roof  head_educ head_age head_female hhsize dratio rural Prel_hh_weight cult_land_gps poor round;

*gen fcs_secure=0 if fcs~=.;
*replace fcs_secure=1 if fcs>35 & fcs~=.;

replace poor=0 if rexpagg_pc_r19<188591 & round==5 & poor==. & rexpagg_pc_r19~=.;
replace poor=1 if rexpagg_pc_r19<188591 & round==5 & poor==. & rexpagg_pc_r19~=.;

gen rexpagg_pc_r19_ln=ln(rexpagg_pc_r19);
gen rexpfood_pc_r19_ln=ln(rexpfood_pc_r19);

gen rexpnfood_pc_r19=rexpagg_pc_r19-rexpfood_pc_r19;
gen rexpnfood_pc_r19_ln=ln(rexpnfood_pc_r19) ;

recode asset_house_roof (1=1) (2/6=0), gen(primitive_roof);
recode head_educ (0/5=0) (6/17=1), gen(educated);

summ cult_land_gps if cult_land_gps~=0, detail;

scalar med_land=r(p50);
scalar max_land=r(max);
scalar min_land=r(min);

gen land_cat=1 if cult_land_gps==. | cult_land_gps==0;
replace land_cat=2 if cult_land_gps>=min_land & cult_land_gps<med_land;
replace land_cat=3 if cult_land_gps>=med_land & cult_land_gps<=max_land;


save "./Input_Data/Data_Integration/Country/Malawi/IHS2345_app", replace;
save "./Input_Data/Household_Survey/Malawi/IHS2345_app", replace;

#delimit cr
