* Do not use without consent by: Katja Vinha, kvinha@gmail.com;
* Based on code provided by Habtamu Fuje for IHS round 4 data cleaning fro MPAIGA;
************************************************************************************
** This do file 
** 1. generates a dataset for IHS Malawi Round 5 compatable with the pooled dataset
**
** OUTPUTS
** 1. 
*************************************************************************************

** DATE MODIFIED:  October 26, 2020;


*NOTE:  Take care of NOTES before finalizing, missing weights etc that are in the code;


cap log close
set more off
clear all
set mem 100m
#delimit ;

loc d1 			"C:\Users\Katja\Documents\CONSULTING/Malawi";
loc d2 			"`d1'/Data/IHS5";

/*
cap erase "`d1'\Results\logs\ihs5.smcl";
log using "`d1'\Results\logs\ihs5.smcl";



	*********************************
	*HOUSEHOLD IDENTIFIER
	*********************************;

*Getting household ID, EA ID, and household weight;
*use "`d2'\Household\HH_MOD_A_FILT.dta", clear;
use "`d2'\Household\HH_MOD_A_withearlyhhwts.dta", clear;

gen HHID_temp=HHID;
drop HHID;
gen HHID=case_id;
sort case_id ea_id;
* Location & Survey Design variables;
	*Urban/Rural;
rename reside urban	;						//Urban/rural Identifier;
label var urban "Urban/rural";
	*Region;
label define region_l 1 North 2 Central 3 South;
label val region region_l;
	*Urban/Rural by Region;
gen 	urban_region = .	;				//Rura/Urban by Region;
replace urban_region = 1 if urban==1;
replace urban_region = 2 if urban==2 & region==1;
replace urban_region = 3 if urban==2 & region==2;
replace urban_region = 4 if urban==2 & region==3;
label var urban_region "Rural/Urban division by region";

label define urban_region_l 1 "Urban" 2 "Rural North" 3 "Rural Centre" 4 "Rural South";
label val urban_region urban_region_l;

 *District;  
label var district "District";
tab district, m;

 *Traditional Authority ;
d hh_a02a;
gen TA = hh_a02a;
label var TA "Traditional Authority";

		*Survey Time;
split interviewDate,p(-) ;					//Spliting Survey time variable into date, monty and year;
rename interviewDate1 syear;
rename interviewDate2 smonth;
rename interviewDate3 sdate;
label var sdate "Day of month for interview";
label var smonth "Month of interview";
label var syear "Year of interview";
destring sdate smonth syear,replace;
foreach v in date month year{	;			//Apply EA survey time for missing HHs;
egen c_s`v'=max(s`v'), by(ea_id);
replace s`v'=c_s`v' if s`v'==.;
} ;
tab smonth syear, m	;						//Cross-tab survey month and year;

label define month_l 1 January 2 February 3 March 
	4 April 5 May 6 June 7 July 8 August  9 September 
	10 October 11 November 12 December;
label val smonth month_l;

*local variables HHID case_id ea_id district TA region 
	urban_region urban sdate smonth 
	syear  hh_wgt; 
*NOTE: need to update when have weight!!!!!!;	
local variables HHID HHID_temp case_id ea_id district TA region 
	urban_region urban sdate smonth 
	syear Prel_hh_weight; 
	
keep  `variables';
order `variables';
compress;
sort HHID;
save "`d2'\Household\Temp\c_HH_MOD_A_FILT", replace;


	*********************************
	*HH CHARACTERISTICS
	*********************************;
use "`d2'\Household\HH_MOD_B", clear;
drop HHID;
gen HHID=case_id;
sort case_id PID ;
merge 1:1 case_id PID using "`d2'\Household\HH_MOD_C.dta";

****Adult Equivalence (AE);
inspect hh_b05a;								//Inspect the age variable for unexpected figure;
gen age = hh_b05a;
gen 	factorAE = .;						//Create AE variable to accompany HH size;
replace factorAE = 0.33 if age<1;
replace factorAE = 0.47 if inrange(age,1,2);
replace factorAE = 0.55 if inrange(age,2.01,3);
replace factorAE = 0.63 if inrange(age,3.01,5);
replace factorAE = 0.73 if inrange(age,5.01,7);
replace factorAE = 0.79 if inrange(age,7.01,10);
replace factorAE = 0.84 if inrange(age,10.01,12);
replace factorAE = 0.91 if inrange(age,12.01,14);
replace factorAE = 0.97 if inrange(age,14.01,16);
sum age;
replace factorAE = 1.00 if inrange(age,16.01,r(max));
label var factorAE "Adult Equivalent factor";
egen hhsize = sum(1), by(HHID);
egen nchild = sum(1) if age<15, by(HHID);
egen nelder = sum(1) if age>65 & age~=., by(HHID);
egen nworker= sum(1) if age>=15 & age<=65, by(HHID);
gen head_female=hh_b03 if hh_b04==1;
gen spouse_female=hh_b03 if hh_b04==2;
egen spouse_female2=max(spouse_female),  by(HHID);
replace head_female=1 if hh_b04==1 & head_female~=. & spouse_female2==2;	//Apply opposit gender, if head gender is missing;
replace head_female=2 if hh_b04==1 & head_female~=. & spouse_female2==1;	//Apply opposit gender, if head gender is missing;
drop spouse_female*;
recode head_female (2=1) (1=0);
gen head_age=hh_b05a if hh_b04==1;
gen head_literate=hh_c06 if hh_b04==1;
recode head_literate (2=0);

//change from habtamu's code in that form 5 and 6 are assinged 12 yrs of edu i form5 or 6 of secondary;
g years_edu=.;								//Years of education; 
replace years_edu=hh_c08 if hh_c08<=12;
replace years_edu=12 if hh_c08==13 | hh_c08==14;
replace years_edu=13 if hh_c08==15 | hh_c08==20;
replace years_edu=14 if hh_c08==16 | hh_c08==21;
replace years_edu=15 if hh_c08==17 | hh_c08==22;
replace years_edu=16 if hh_c08==18 | hh_c08==23;
replace years_edu=17 if hh_c08==19;
replace years_edu=0 if hh_c06==2;

/* End up not doing anything;
replace years_edu=17 if years_edu==. & (hh_c09==8 | hh_c09==9);
replace years_edu=14 if years_edu==. & (hh_c09==4 | hh_c09==5 | hh_c09==6| hh_c09==7);
replace years_edu=10 if years_edu==. & (hh_c09==3);
replace years_edu=8 if years_edu==. & (hh_c09==2);
*/;
gen head_educ=years_edu if hh_b04==1;
gen spouse_educ=years_edu if hh_b04==2;
egen adult_av_educ=mean(years_edu) if age>=15, by(HHID);
rename hh_b23 head_relgion ;
replace head_relgion=. if hh_b04!=1;
rename hh_b24 head_marital; 
replace head_marital=. if hh_b04!=1;
gen head_rChichewa=0 if hh_b04==1;
replace head_rChichewa=1 if (hh_c05_2a==1 | hh_c05_2b==1) & hh_b04==1;
gen head_rEnglish=0 if hh_b04==1;
replace head_rEnglish=1 if (hh_c05_2a==14 | hh_c05_2b==14) &  hh_b04==1;
preserve;

keep case_id PID hh_b04 age years_edu; 
save "`d2'\Household\Temp\cc_ind_mod_b", replace	;		//Save individual level info;
restore;
 
local first hhsize nchild nelder nworker head_female head_age 
	head_literate head_educ 
	spouse_educ adult_av_educ head_relgion head_rChichewa 
	head_rEnglish;
local sumv factorAE;

collapse (firstnm) `first' (sum) `sumv' , by(HHID); 
foreach j in nchild nelder nworker{;
replace `j'=0 if `j'==.;
};
gen dratio=(nchild +nelder)/nworker;		//Total dependency ratio;
gen cdratio=nchild/nworker;				//Child dependency ratio;	
gen odratio=nelder/nworker;				//Old age dependency ratio;
qui sum dratio, det;
foreach d in dratio cdratio odratio{;
replace  `d'=r(p99) if nworker==0;		//No worker, assum high dep ratio;
};
label define gender 0 "Male" 1 "Female" ; 
label values head_female gender;
label define yesno 0 "No" 1 "Yes", replace;  
label values head_literate head_rChichewa head_rEnglish yesno;
rename factorAE adulteq;
summ hhsize adulteq, d;
compare hhsize adulteq	;					//Comparative statistics;
label var adulteq "Adult equivalence" ;
label var hhsize "Household size";
label var nchild "Number of children under age of 15";
label var nelder "Number elder members above 65 years of age";
label var nworker "Number of working age members (15-65)";
label var dratio "(Total) Dependence ratio";
label var cdratio "Child dependence ratio";
label var odratio "Old age dependence ratio";
label var head_female "=1 if  the household head is female";
label var head_age "Age of household head in years"; 
label var head_literate "Is the hh head literature (been to school), 1=Yes";
label var head_educ "Years of education of the HH head";
label var spouse_educ "Years of education of the head's spouse";
label var adult_av_educ "Average years of education for adult members (>15 years of age)";
label var head_relgion "Head's religion";
label var head_rChichewa "Head can read in Chichewa"; 
label var head_rEnglish "Head can read in English";
sort HHID;
order HHID adulteq `first';  
save "`d2'\Household\Temp\c_hh_mod_b", replace;

	*********************************
	*LABOR/TIME USE
	*********************************;
use "`d1'\Data\IHS5\Household\HH_MOD_E", clear;
merge 1:1 case_id PID  using "`d2'\Household\Temp\cc_hh_mod_b", nogen keep(3);		//Bring age;
drop HHID;
rename case_id HHID;

keep if age>=15;										//Adult members only;
local act hh_e07a hh_e07b hh_e07c hh_e08 hh_e09 hh_e10 hh_e11 hh_e12;
egen act_any=rowtotal(`act');						//Engaged in any economic activity;
egen act_ag=rowtotal(hh_e07a hh_e07b hh_e07c);			//Engaged in agricultural activities;
egen act_enterp=rowtotal(hh_e08- hh_e09);			//Engaged in non-agricultural activities;
gen act_ganyu=hh_e10;								//Engaged in casual job/ganyu;
gen act_wage=hh_e11;									//Engaged in wage employment;	
gen act_unpaid=hh_e11;								//Engaged in unpaid internship;

gen emplyd7_d=(act_any>1);							//Empoyed in any activity (at leat 1 hour);	
gen emplyd7_ag=(act_ag>0);							//Empoyed in family agricultural activities;
gen emplyd7_enterp=(act_enterp>0);					//Empoyed in non-farm enterprise;
gen emplyd7_wage=(act_wage>0);						//Empoyed for wage;
gen emplyd7_ganyu=(act_ganyu>0);					//Empoyed as ganyu/casual labor;
foreach v in d ag enterp wage ganyu{;
gen head_emplyd7_`v'=emplyd7_`v' if hh_b04==1;		//Head engaged in the activities listed;
};

	*Industry of wage employment (TBD);
	
	*Wage income, TBD;

local firstnm head_emplyd7_*;
local meanv  emplyd7_*; 
collapse (mean) `meanv' (firstnm) `firstnm', by(HHID);
label var emplyd7_d "Share of adult members employed in any activity (ag, enterprise, wage, hh chores etc.), past 7 days";
label var emplyd7_ag "Share of adult members engaged in family agriculture, past 7 days";
label var emplyd7_enterp  "Share of adult members engaged family non-agriculture enterprise, past 7 days";
label var emplyd7_wage "Share of adult members engaged inwage employment, past 7 days";
label var emplyd7_ganyu "Share of adult members engaged in ganyu/casual jobs, past 7 days";
	
label var head_emplyd7_d "Is the head employed in any activity (ag, enterprise, wage, hh chores etc.), past 7 days";
label var head_emplyd7_ag "Is the head engaged in family agriculture, past 7 days";
label var head_emplyd7_enterp  "Is the head engaged family non-agriculture enterprise, past 7 days";
label var head_emplyd7_wage "Is the head engaged inwage employment, past 7 days";
label var head_emplyd7_ganyu "Is the head engaged in ganyu/casual jobs, past 7 days";
label define yesno 0 "No" 1 "Yes", replace;  
label values head_emplyd7_* yesno;
save "`d2'\Household\Temp\c_hh_mod_e", replace;

	*********************************
	*FOOD INSECURITY
	*********************************;
use "`d1'\Data\IHS5\Household\HH_MOD_H", clear;
drop HHID;
gen HHID=case_id;
rename hh_h01 food_insecure7;				//Food insecurity in the past 7 days;
rename hh_h04 food_insecure12;				//Food insecurity in the past 12 months;
label var food_insecure7 "HH reported food insecurity in the past 7 days";
label var food_insecure12 "HH reported food insecurity in the past 12 months";

/*EXTRACT COPPING MECHANISM AND MONTHS OF FOOD INSECURITY:
forvalues j=10/11{
rename hh_h05a_`j' hh_h05a_`=`j'+2'
}
qui foreach v of varlist hh_h05*_*  {
replace `v'="1" if `v'=="x" | `v'=="X"
destring `v', replace force
}
qui forvalues j=1/9{
egen finsecur12_m0`j'=rowtotal(hh_h05*_0`j')
}
qui forvalues j=10/12{
egen finsecur12_m`j'=rowtotal(hh_h05*_`j')
}
gen finsecure_month=1 if 
*/
keep HHID food_*;
save "`d2'\Household\Temp\c_hh_mod_h", replace;

	*********************************
	*INPUT PRICE SHOCKS
	*********************************;
use "`d1'\Data\IHS5\Household\HH_MOD_U.dta", clear;
keep if hh_u0a==107;
g inputprshock=hh_u01==1 ;
keep case_id inputprshock;
rename case_id HHID;
label var inputprshock "HH faced input price shocks";
save "`d2'\Household\Temp\c_hh_mod_u.dta", replace;

**DO NOT HAVE GOE VARS!!!!;
/*
	*********************************
	*GEO VARIABLES
	*********************************
use "$data\IHS4\Full_Sample\Geovariables\HouseholdGeovariablesIHS4.dta",clear 
keep case_id dist_road dist_popcenter dist_admarc dist_borderpost /*
 sphdist_lilongwe sphdist_blantyre sphdist_mzuzu sphdist_songwe sphdist_mwanza sphdist_liwonde*/
label var dist_road "Distance to nearest road in Km"
label var dist_popcenter "Distance to nearest population center (+20,000 people) in Km"
label var dist_admarc "Distance to nearest ADMARC outlet in Km"
label var dist_borderpost "Distance to nearest border post in Km"

//label var dist_agmrkt "Distance to nearest agricultural marekt in Km"
rename case_id HHID
save "$temp\c_householdgeovariables.dta", replace


*Combine HH Module
use "$temp\c_HH_MOD_A_FILT", clear
merge 1:1 HHID using "$temp\c_hh_mod_b", nogen
merge 1:1 HHID using "$temp\c_hh_mod_e", nogen
merge 1:1 HHID using "$temp\c_hh_mod_h", nogen
merge 1:1 HHID using "$temp\c_HH_MOD_U.dta", nogen
merge 1:1 HHID using "$temp\c_householdgeovariables.dta", nogen
save "$temp\HH_IHS4", replace

/*;
*/;
*/;

	*********************************
	*CONSUMPTION AGGREGATES
	*********************************;
use "`d2'\Household\tconsumption_ihs5.dta";

rename HHID HHID_temp;

loc consum "rexp_cat021- rexp_cat12 price_indexL rexpagg";

foreach var of varlist `consum'{;
	rename `var' `var'_r19;
};

save "`d2'\Household\Temp\c_tcons", replace;
*/
***************************
***************************
***************************

********************B) Section II: Agriculture

	*********************************
	*Module a: Filter
	*********************************;

use "`d2'\Agriculture\AG_MOD_R1.dta", clear;
drop HHID;
rename case_id HHID;
rename ag_r00 hh_livestock;
recode  hh_livestock (2=0);
collapse (max)hh_livestock, by(HHID);
label var hh_livestock "Does the hh own any livestock, past 12 months?";
save "`d2'\Agriculture\Temp\cc_ag_mod_r1", replace;

/*dont have mod A
use "`d2'\Agriculture\AG_MOD_A.dta", clear;
rename ag_b101b  hh_crop;
label var hh_crop "Has the HH plant any crops during the last rainy season?";
drop HHID;
rename case_id HHID;
merge 1:1 HHID using  "`d2'\Agriculture\Temp\cc_ag_mod_r1"
replace hh_livestock=0 if _merge==1 & hh_livestock==.
keep HHID hh_*
save "`d2'\Agriculture\Temp/c_ag_mod_a_filt.dta", replace
*/;
	*Module C & D: Plot level information
	*********************************;
	
use "`d2'\Agriculture\AG_MOD_D.dta", clear;
duplicates	drop case_id gardenid plotid, force;
egen PLID=concat(case_id gardenid plotid);
save "`d2'\Agriculture\Temp/c_ag_mod_d", replace;

use "`d2'\Agriculture\AG_MOD_C.dta", clear;
duplicates	drop case_id gardenid plotid, force;
egen PLID=concat( case_id gardenid plotid);
merge 1:1 PLID using "`d2'\Agriculture\Temp\c_ag_mod_d.dta", nogen keep(3)	;	//Combine module c & d;
	*Cultivated land ;
drop HHID;
rename case_id HHID;
replace ag_c04a=ag_c04a*2.471 if ag_c04b==2	;		//Hectare to acre;
replace ag_c04a=ag_c04a*2.471/1000 if ag_c04b==3;	//Meter square to acre;
compare ag_c04a ag_c04c	;							//Compare reported and GPS measure areas of plots;
replace ag_c04c=ag_c04a if ag_c05e~=.	;			//Update GPS area by reported area if not GPS measured;
replace ag_c04c=ag_c04a if ag_c04c==. & ag_c04a!=.;	//Update GPS area by reported area if it is missing;
qui sum ag_c04c, det;
replace ag_c04c=ag_c04a if ag_c04c>r(p99) & ag_c04c!=.;	//Update extreme values of GPS measured by self-reported;
qui sum ag_c04a, det;
replace ag_c04a=ag_c04c if ag_c04a>r(p99) & ag_c04a!=.;	//Update extreme values of self reported by GPS measured area;
egen cult_land_r=sum(ag_c04a), by(HHID)	;			//Cultivated land, reported by HH;
egen cult_land_gps=sum(ag_c04c), by(HHID);			//Cultivated land, GPS measured;
	*Land allocated to each crop (Main crop);
egen land_mcmaize=sum(ag_c04c)  if ag_d20a<=4, by(HHID);
egen land_mctobacco=sum(ag_c04c)if inrange(land_, 5,10), by(HHID);
egen land_mcnuts=sum(ag_c04c) 	if inrange(ag_d20a,11,16), by(HHID);
egen land_mcrice=sum(ag_c04c) 	if inrange(ag_d20a,17,26), by(HHID);
egen land_mcpotato=sum(ag_c04c) if inrange(ag_d20a,28,29), by(HHID);
egen land_mcothercrops=sum(ag_c04c) if ag_d20a==27 | inrange(ag_d20a,30,48), by(HHID);
tabstat land_*, by(ag_d20a)	;						//Check label vs. land;


	*Land allocated to each crop (pure stand only);
sum ag_d20a-ag_d20e;
gen crop_ps=1;										//Plot is pure stand (not mixed);
replace crop_ps=0 if ag_d20b~=. | ag_d20c~=. | ag_d20d~=. | ag_d20e~=.  ;
label var crop_ps "Plot is pure stand (not mixed)";
egen land_psmaize=sum(ag_c04c)  if crop_ps==1 & ag_d20a<=4, by(HHID);
egen land_pstobacco=sum(ag_c04c)if crop_ps==1 & inrange(ag_d20a, 5,10), by(HHID);
egen land_psnuts=sum(ag_c04c) 	if crop_ps==1 & inrange(ag_d20a,11,16), by(HHID);
egen land_psrice=sum(ag_c04c) 	if crop_ps==1 & inrange(ag_d20a,17,26), by(HHID);
egen land_pspotato=sum(ag_c04c) if crop_ps==1 & inrange(ag_d20a,28,29), by(HHID);
egen land_psothercrops=sum(ag_c04c) if crop_ps==1 & ag_d20a==27 | inrange(ag_d20a,30,48), by(HHID);
	*Land allocated to each crop (Mixed planting only);
egen land_msmaize=sum(ag_c04c)  if crop_ps==0 & ag_d20a<=4, by(HHID);
egen land_mstobacco=sum(ag_c04c)if crop_ps==0 & inrange(ag_d20a, 5,10), by(HHID);
egen land_msnuts=sum(ag_c04c) 	if crop_ps==0 & inrange(ag_d20a,11,16), by(HHID);
egen land_msrice=sum(ag_c04c) 	if crop_ps==0 & inrange(ag_d20a,17,26), by(HHID);
egen land_mspotato=sum(ag_c04c) if crop_ps==0 & inrange(ag_d20a,28,29), by(HHID);
egen land_msothercrops=sum(ag_c04c) if crop_ps==0 & ag_d20a==27 | inrange(ag_d20a,30,48), by(HHID);
	*Land rental/sales value (total);
/*Note: These variables (d03-d13) were removed in IHS4.*/
*egen salev_land=sum(ag_d05), by(HHID)				//Sales value of land owned by HH
*egen rentalv_land=sum(ag_d06), by(HHID)				//Rental value of land owned by HH
	*Fertilizer application dummy;
gen fert_d=(ag_d38==1)	;							//Fertilizer applied to the plot;
egen fert_nplot=sum(fert_d), by(HHID)	;			//Number plots treated with fertilizer;
egen nplot=sum(1), by(HHID)		;					//Number of plot the HH owns;
gen fert_snplot=fert_nplot/nplot;					//Share of plots (count) treated with fertilizer;
egen fert_aplot=sum(ag_c04c) if fert_d==1, by(HHID); //Total area of cultivated land treated with fertilizer;
egen fert_maizeplot=sum(ag_c04c) if fert_d==1
	& ag_d20a<=4, by(HHID);							//Maize plot area of cultivated land treated with fertilizer
	*Fertilizer quantity;
*1st application;
gen ag_d39bkg=ag_d39b if ag_d39c==2;				//Converting subsidized inputs into KG ;
replace ag_d39bkg=ag_d39b*0.001 if ag_d39c==1;
replace ag_d39bkg=ag_d39b*3 if ag_d39c==4;
replace ag_d39bkg=ag_d39b*5 if ag_d39c==5;
replace ag_d39bkg=ag_d39b*10 if ag_d39c==6;
replace ag_d39bkg=ag_d39b*50 if ag_d39c==7;
sum ag_d39bkg,d;
compare ag_d39bkg ag_d39d;						//Mostly equa: Reported by HH in different vs. KG quant reported by enumerator;
replace ag_d39bkg=ag_d39d if ag_d39bkg==. ;		//Update using kg reported by enumerator if HH reported value is missing (other) *2nd application;
gen ag_d39hkg=ag_d39h if ag_d39i==2	;			//Converting subsidized inputs into KG ;
replace ag_d39hkg=ag_d39h*0.001 if ag_d39i==1;
replace ag_d39hkg=ag_d39h*3 if ag_d39i==4;
replace ag_d39hkg=ag_d39h*5 if ag_d39i==5;
replace ag_d39hkg=ag_d39h*10 if ag_d39i==6;
replace ag_d39hkg=ag_d39h*50 if ag_d39i==7;
sum ag_d39hkg,d;
compare ag_d39hkg ag_d39h;						//Mostly equa: Reported by HH in different vs. KG quant reported by enumerator;
replace ag_d39hkg=ag_d39i if ag_d39bkg==. ;		//Update using kg reported by enumerator if HH reported value is missing (other)
*Total application;
egen qfert_plot=rowtotal(ag_d39bkg ag_d39hkg);	//Total quantity of fertilizer on each plot (1st & 2nd application);
rename ag_d39hkg ag_d39gkg;						//To make it consistent with IHS3.; 
gen qfert_peracre=qfert_plot/ag_c04c;
egen fert_kgacre=mean(qfert_peracre), by(HHID);	//Intensity of fertilizer (kg/acre), all crops;
*egen fert_kgacre_maize=mean(qfert_peracre) if  g_d20a<=4, by(HHID);						//Intensity of fertilizer application(kg/acre) on Maize plot ;
	*Pesticide;
gen pesticide=(ag_d40==1)	;					//Pesticide on any plot;
	*Labor TBD;
	*Land;
foreach v in maize tobacco nuts rice potato othercrops{;
replace land_mc`v'=0 if land_mc`v'==.;
label var land_mc`v' "Cultivated land(acre) allocated to `v' (main crop), both mixed & pure stand";
replace land_ps`v'=0 if land_ps`v'==.;
label var land_ps`v' "Cultivated land(acre) allocated to `v' (pure stand only)";
replace land_ms`v'=0 if land_ms`v'==.;
label var land_ms`v' "Cultivated land(acre) allocated to `v' (mixed crop only)";
};
foreach v in sale rental{;
*label var `v'v_land "The `v' value of land owned by HH (MWK)";
};
label var fert_kgacre "Fertilizer application intensity, kg/acre (all crops)";
*label var fert_kgacre_maize "Fertilizer application intensity, kg/acre (maize)";
label var pesticide "Has the HH applied pesticide on any plot for any crop?";
label var nplot "Number plots owned by the HH";
label var fert_nplot "Number plots treated with fertilizer";
label var fert_snplot "Proportion of plots (count) treated with fertilizer";
save "`d2'\Agriculture\Temp\cc_ag_mod_c-d.dta", replace;			//Save it at plot level;

local firstnm cult_land_* land_*  nplot fert_* qfert_peracre; //*v_land ;
local maxv pesticide;
collapse (firstnm) `firstnm' (max) `maxv', by(HHID);
label var cult_land_r "Total area of cultivated land (acre), reported by hh";
label var cult_land_gps "Total area of cultivated land (acre), GPS measured";
rename fert_d fert_anyplot;
label var nplot "Number plots owned by the HH";
label var fert_anyplot "Has the HH applied fertilizer to any of its plot? Yes=1";
label var fert_nplot "Number plots treated with fertilizer";
label var fert_snplot "Proportion of plots (count) treated with fertilizer";
replace fert_aplot=0 if fert_aplot==. & cult_land_gps~=0;
label var fert_aplot "Total area of cultivaed plots treated with fertilizer";
label var fert_maizeplot "Area of maize plots treated with fertilizer";
gen fert_saplot=fert_aplot/cult_land_gps;			//Share of land area treated with fertilizer;
replace fert_maizeplot=0 if fert_maizeplot==. & land_mcmaize~=0;
label var fert_saplot "Share of cultivated land area treated with fertilizer";
gen fert_smaizeplot=fert_maizeplot/land_mcmaize;		//Share of maize plot area treated with fertilizer;
label var fert_smaizeplot "Share of cultivated maize plot area treated with fertilizer";

foreach v in maize tobacco nuts rice potato othercrops{;
replace land_mc`v'=0 if land_mc`v'==.;
label var land_mc`v' "Cultivated land(acre) allocated to `v' (main crop), both mixed & pure stand";
replace land_ps`v'=0 if land_ps`v'==.;
label var land_ps`v' "Cultivated land(acre) allocated to `v' (pure stand only)";
replace land_ms`v'=0 if land_ms`v'==.;
label var land_ms`v' "Cultivated land(acre) allocated to `v' (mixed crop only)";
};
foreach v in sale rental{;
*label var `v'v_land "The `v' value of land owned by HH (MWK)";
};
label var fert_kgacre "Fertilizer application intensity, kg/acre (all crops)";
*label var fert_kgacre_maize "Fertilizer application intensity, kg/acre (maize)";
label var pesticide "Has the HH applied pesticide on any plot for any crop?";

sort HHID;
save "`d2'\Agriculture\Temp\c_ag_mod_c-d.dta", replace; 		//Save it at HH level;

/*
*********************************
	*SECTION E & F: FERTILIZER SUBSIDY AND PURCHASE
	*********************************
	
***Acqusition of subsidized fertilizer (KG), seed (KG), and cost(KW)
use "$data\IHS4\Full_Sample\Agriculture\AG_MOD_E2.dta", clear
duplicates drop HHID ag_e0g ag_e01_1, force
rename ag_e0g  ag_e0b
rename ag_e01_1 ag_e0c
merge 1:1 case_id ag_e0b ag_e0c using "$data\IHS4\Full_Sample\Agriculture\AG_MOD_E1.dta", nogen
drop HHID
gen HHID=case_id
replace ag_e08a=1 if ag_e08b==7 & ag_e08a==50	//Fix entry error, they mean 1 50 kg bag
replace ag_e08a=2 if ag_e08b==7 & ag_e08a==100	//Fix entry error, they probably mean mean 2 50 kg bags
gen ag_e08akg=ag_e08a if ag_e08b==2				//Converting subsidized inputs into KG 
replace ag_e08akg=ag_e08a*0.001 if ag_e08b==1
replace ag_e08akg=ag_e08a*3 if ag_e08b==4
replace ag_e08akg=ag_e08a*5 if ag_e08b==5
replace ag_e08akg=ag_e08a*10 if ag_e08b==6
replace ag_e08akg=ag_e08a*50 if ag_e08b==7
sum ag_e08akg,d
gen FISP_qfert=ag_e08akg if inrange(ag_e07,2,5)	//Subsidized fertilizer (kg)
bys HHID: egen FISP_cfert=total(ag_e15) ///
		if inrange(ag_e07,2,6) 					//Value of subsidized fertilizer (MKW)
gen FISP_qmaizes=ag_e08akg if ag_e07==12 		//Subsidized maize seed (kg)
bys HHID: egen FISP_cmaizes=total(ag_e15) ///
		if ag_e07==12							//Value of subsidized maize seed (MKW)
collapse (sum) FISP_qfert FISP_qmaizes ///
	(firstnm) FISP_cfert FISP_cmaizes, by(HHID)
label var FISP_qfert "Quantity of subsidized fertilizer acquired in KG"
label var FISP_qmaizes "Quantity of subsidized maize seed acquired in KG"
replace FISP_cfert=0 if  FISP_cfert==.
replace FISP_cmaizes=0 if FISP_cmaizes==.
gen FISP_fprice=FISP_cfert/FISP_qfert if FISP_cfert~=0
label var FISP_fprice "Unit value (price) of FISP inorganic fertilizer per KG (any type)"
label var FISP_cfert "Total value of subsidized fertilizer (MKW)"
label var FISP_cmaizes "Total value of subsidized maize seed (MKW)"
save "$temp\c_AG_MOD_E.dta", replace
/*???QUESTIONS 15-36 ARE MISSING, CHECK WITH TALIP:
****Commercial fertilizer acquisition data 
use "$data\IHS4\Full_Sample\Agriculture\AG_MOD_F.dta", clear
*1st source
replace ag_f16a=1 if ag_f16b==7 & ag_f16a==50 & ag_f0c>=2 & ag_f0c<=6	//Quantity 50 (50kg bag) likely mean 1 50kg bag
replace ag_f16a=2 if ag_f16b==7 & ag_f16a==100 & ag_f0c>=2 & ag_f0c<=6	//Quantity 100 (50kg bag) likely mean 2 50kg bag
gen ag_f16akg=ag_f16a if ag_f16b==2							//Converting commercial fertilizer acquisiton to KG 
replace ag_f16akg=ag_f16a*0.001 if ag_f16b==1
replace ag_f16akg=ag_f16a*2 if ag_f16b==3
replace ag_f16akg=ag_f16a*3 if ag_f16b==4
replace ag_f16akg=ag_f16a*5 if ag_f16b==5
replace ag_f16akg=ag_f16a*10 if ag_f16b==6
replace ag_f16akg=ag_f16a*50 if ag_f16b==7
sum ag_f16akg if ag_f0c>=2 & ag_f0c<=6,d
gen ag_f26akg=ag_f26a if ag_f26b==2
*2nd source
replace ag_f26akg=ag_f26a*0.001 if ag_f26b==1
replace ag_f26akg=ag_f26a*2 if ag_f26b==3
replace ag_f26akg=ag_f26a*3 if ag_f26b==4
replace ag_f26akg=ag_f26a*5 if ag_f26b==5
replace ag_f26akg=ag_f26a*10 if ag_f26b==6
replace ag_f26akg=ag_f26a*50 if ag_f26b==7
sum ag_f26akg if ag_f0c>=2 & ag_f0c<=6,d
replace ag_f26akg=0 if ag_f26akg==. & ag_f16akg!=. 
egen com_qfert=rowtotal(ag_f16akg ag_f26akg) if ag_f0c>2 & ag_f0c<=6	//Total quantity of inorganic fertilizer
egen com_cfert=rowtotal(ag_f19 ag_f29)	if ag_f0c>2 & ag_f0c<=6			//Cost of commercial fertilizer  
drop HHID
gen HHID=case_id
collapse (sum) com_qfert com_cfert, by(HHID)
gen comm_fprice=com_cfert/com_qfert if com_cfert~=0
qui sum comm_fprice, det
replace comm_fprice=`r(p95)' if comm_fprice>`r(p95)' & comm_fprice~=.	//Trim at 95th 
label var com_qfert "Quantity of commercial fertilizer acquired in KG"
label var com_cfert "Expenditure on commercially acquaried fertilizer in KG"
label var comm_fprice "Unit value (price/kg) of commercial inorganic fertilizer (any type)"
save "$temp\c_AG_MOD_F.dta", replace
*/	
	
	*********************************
	*SECTION G: CROP Roster
	*********************************
use "$data\IHS4\Full_Sample\Agriculture\ag_mod_g.dta", clear
rename crop_code ag_g0d
duplicates drop case_id gardenid plotid ag_g0d, force		//Unique: HH*Plot*Crop
egen PLID=concat(case_id  gardenid plotid)					//Unique Plot ID
drop HHID
rename case_id HHID
merge m:1 PLID using "$temp\cc_ag_mod_c-d.dta", keep(3) nogen //Add plot level data from section c-d
/*Note: Only 68 had crop info "tab ag_g0d if _merge~=3 "*/
	*Declare Pure Stand vs. Mixed Crop
rename crop_ps crop_ps_imp							//Plot is pure stand based on crop listed in each plot
recode ag_g01 (2/5=0)
rename ag_g01 crop_ps_stated						//Plot is stated as pure stand 
compare crop_ps_imp crop_ps_stated
replace crop_ps_imp=crop_ps_stated if ag_d20a==.	//Take stated if first crop was not listed
#delimit ;
replace crop_ps_stated=1 if ag_d20a~=. & ag_d20b==.  
	& ag_d20c==. & ag_d20d==. & ag_d20e==. 
	& crop_ps_imp==1 & crop_ps_stated==0;			//Trust imputed if individual crop listed is more than one
replace crop_ps_stated=0 if ag_d20a~=. & (ag_d20b~=.  
	| ag_d20c~=.  | ag_d20d~=.  | ag_d20e~=. ) &  
	crop_ps_imp==0 & crop_ps_stated==1;				//Trust imputed if individual crop listed is more than one
#delimit cr
compare crop_ps_imp crop_ps_stated
drop crop_ps_stated
rename  crop_ps_imp pure_standp
label define pure 1 "Pure stand" 0 "Mixed crop"
label value  pure_standp pure
	*Seed 
replace ag_g04a=1 if ag_g04b==8 & ag_g04a==50	//Fix entry error, they mean 1 50 kg bag
replace ag_g04a=2 if ag_g04b==8 & ag_g04a==100	//Fix entry error, they probably mean mean 2 50 kg bags
gen seed_kg=ag_g04a  if ag_g04b==2				//Converting See into KG 
replace seed_kg=ag_g04a*0.001 if ag_g04b==1
replace seed_kg=ag_g04a*2 if ag_g04b==3
replace seed_kg=ag_g04a*3 if ag_g04b==4
replace seed_kg=ag_g04a*3.7 if ag_g04b==5
replace seed_kg=ag_g04a*5 if ag_g04b==6
replace seed_kg=ag_g04a*10 if ag_g04b==7
replace seed_kg=ag_g04a*50 if ag_g04b==8
egen seed_maize=sum(seed_kg) if ag_g0d<=4, by(HHID)
labe var seed_kg "How much seed did you plant for the [CROP] on this [PLOT] in kg"
labe var seed_maize "How much maize seed did you plant on any plot (in kg)"
	*Harvest
*???QUESTIONS 6-9 ARE MISSING. ASK TALIP	
gen harvested_d=(ag_g10~=.)						//Assume it is harvested if HH respond to area harvested question
*rename ag_g07 harvested_d						//Is the crop already harvested?
ta harvested_d, missing
*a)Bring conversion factors
preserve
import excel "$data\Conversion Factors\ConversionF.xlsx", sheet("Production_c") firstrow clear
destring c_factor, replace force
egen c_factor_national=mean(c_factor), by(crop_code unit_code condition_code)	//Average factor 
replace c_factor=c_factor_national if c_factor==. & c_factor_national~=. 	//Apply national mean factor if missing
drop c_factor_national
duplicates drop region crop_code unit_code condition_code, force
foreach v in region crop_code unit_code condition_code{
gen cf_`v'=`v'
} 
keep region crop_code unit_code  condition_code c_factor cf_*
save "$temp\c_conversionF", replace
restore

*b)Merge conversion factor
merge m:1 HHID using "$temp\c_HH_MOD_A_FILT", keep(3) nogen
*ta ag_g08b ag_g08c  if ag_g0d~=. & ag_g08c~=.			//Expected harvest: 3,888 crop*unit*cond combination must be matched
*ta ag_g09b ag_g09c  if ag_g0d~=. & ag_g09c~=.			//Actual harvest: 	3,052 crop*unit*cond combination must be matched
gen crop_code=ag_g0d 
gen unit_code=ag_g13b 
gen condition_code=ag_g13c 

merge m:1 region crop_code unit_code condition_code using "$temp\c_conversionF", keep(1 3)
replace c_factor=1 if unit_code==1							//Kg factor, 1
replace c_factor=50 if unit_code==2 & c_factor==.			//Apply the 50kg factor if missing, ignoring product and condition code
replace c_factor=90 if unit_code==3 & c_factor==.			//Apply the 90kg factor if missing, ignoring product and condition code
egen ac_factor=median(c_factor), by(unit_code)				//Generate national median factor, ignoring region, product and condition code
replace c_factor=ac_factor if c_factor==. & ac_factor~=.	//Apply national median factor

foreach j in  13{	//08 09
gen ag_g`j'akg=ag_g`j'a*c_factor							//convert production into kg
}  
gen yield_gps=ag_g13akg/ag_c04a								//Yield based on GPS measured land area				
gen yield_sr=ag_g13akg/ag_c04c								//Yield based on self-reported land area

tabstat yield_* if ag_g0d==1 & pure_standp ==1 [w=hh_wgt], stat(mean median)
tabstat yield_* if ag_g0d==3 & pure_standp ==1 [w=hh_wgt], stat(mean median)
label var yield_gps "Yield (kg/acre) of crop, land area measured using GPS"
label var yield_sr "Yield (kg/acre) of crop, land area is as reported by HHs"
egen yield_maize_gps=mean(yield_gps) if ag_g0d<=4, by(HHID)	//Maize yield, using GPS measured land
egen yield_maize_sr=mean(yield_sr) if ag_g0d<=4, by(HHID)	//Maize yield, using reported land area
label var yield_gps "Yield (kg/acre) of crop, land area measured using GPS"
label var yield_sr "Yield (kg/acre) of crop, land area is as reported by HHs"

save "$temp\cc_ag_mod_c-d-g.dta", replace					//Save plot level, Module c, d & g
egen cul_lnd=rowtotal(land_mc*)
foreach v in maize tobacco nuts rice potato othercrops{
gen share_lnd_`v'=land_mc`v'/cul_lnd					//Share of cultivted land on maize
replace share_lnd_`v'=0 if cul_lnd==0
}
drop cul_lnd
tabulate ag_g11a, gen(shock_a)
?
egen lharv_droughta=max(shock_a1), by(HHID) 			//Drought as a cause for any less harvested areas
egen lharv_insecta=max(shock_a3), by(HHID) 			    //Insect as a cause for any less harvested areas
egen lharv_diseasea=max(shock_a6), by(HHID) 			//Disease as a cause for any less harvested areas
egen lharv_rainsa=max(shock_a9), by(HHID)  			    //Irregular rains as a cause for any less harvested areas

tabulate ag_g11b, gen(shock_b)
egen lharv_droughtb=max(shock_b1), by(HHID) 			//Drought as a cause for any less harvested areas
egen lharv_insectb=max(shock_b3), by(HHID) 			    //Insect as a cause for any less harvested areas
egen lharv_diseaseb=max(shock_b6), by(HHID) 			//Disease as a cause for any less harvested areas
egen lharv_rainsb=max(shock_b9), by(HHID)  			    //Irregular rains as a cause for any less harvested areas

gen lharv_drought=(lharv_droughta==1 | lharv_droughtb==1)
gen lharv_insect=(lharv_insecta==1 | lharv_insectb==1)
gen lharv_disease=(lharv_diseasea==1 | lharv_diseaseb==1)
gen lharv_rains=(lharv_rainsa==1 | lharv_rainsb==1)

#delimit ;
drop lharv_drought? lharv_insect?
lharv_disease? lharv_rains? shock*;
gen crop_shock=lharv_drought==1 | lharv_insect==1 
| lharv_disease==1 | lharv_rains==1;                  //The HH is considered to have experienced crop shock if it faced production decrease due to disease, drought, insect, or irregular rains
#delimit cr
sum lharv* crop_shock, d

local firstnm share_lnd_*  yield_maize_* lharv_*

collapse (firstnm) `firstnm', by(HHID)
foreach v in maize tobacco nuts rice potato othercrops{
label var share_lnd_`v' "Share of cultivated land covered with `v'"
gen prod_lnd_`v'=(share_lnd_`v'>0 & share_lnd_`v'!=.)
label var prod_lnd_`v' "Share of cultivated land covered with `v'"
}
gen cropdiv_maize=(share_lnd_maize==1)						//Grow maize only
gen cropdiv_nomaize=(share_lnd_maize<0.05)					//No maize, <5% of land coverd with Maize 
label var cropdiv_maize "HH grows maize only"
label var cropdiv_nomaize "HH grows little or no maize, i.e. less than 5% of cultivaed land is coverd by maize"

foreach v in  drought rains insect disease{
replace lharv_`v'=0 if lharv_`v'==.
label var lharv_`v' "Due to `v' less than planted area harveste d (any crop)"
}
label var yield_maize_gps "Yield (kg/acre) of crop, land area measured using GPS"
label var yield_maize_sr "Yield (kg/acre) of crop, land area is as reported by HHs"
save "$temp\c_ag_mod_g.dta", replace			//Save HH level


	*********************************
	*SECTION T: EXTENSION
	*********************************
*Creating 'access to fertilizer advice' variable
use "$data\IHS4\Full_Sample\Agriculture\AG_MOD_T1.dta", clear
forvalues j=301/314{
gen adv_`j'=(ag_t01==1) if ag_t0a==`j'				//Received advice on j service
}
collapse (firstnm) adv_*, by(case_id)
rename adv_301 adv_seed
label var adv_seed "HH received advice on new variety of seeds"
rename adv_302 adv_pest
label var adv_pest "HH received advice on pest control"
rename adv_303 adv_fertilizer
label var adv_fertilizer "HH received advice on fertilizer application"
rename adv_305 adv_irrigation
label var adv_irrigation "HH received advice on irrigation"
rename adv_307 adv_cmarket
label var adv_cmarket "HH received advice on crop marketing"
rename adv_312 adv_livestock
label var adv_livestock "HH received advice on Animal Diseases / Vaccination"
rename case_id HHID
keep HHID adv_seed adv_pest adv_fertilizer adv_irrigation adv_cmarket adv_livestock
label define yesno 0 "No" 1 "Yes"  
label values adv_* yesno 
save "$temp/c_AG_MOD_T1", replace



	*********************************
	*LIVESTOCK VALUE
	*********************************
use "$data\IHS4\Full_Sample\Agriculture\AG_MOD_R1.dta", clear 
gen valuelivestock=ag_r02*ag_r04 
bys case_id: egen valuelivestock2=total(valuelivestock)
label var valuelivestock2 "Households valuation of their livestock assets in Kw"   
bys case_id:gen dup=cond(_N==1,0,_n)
drop if dup>1
drop dup
keep case_id valuelivestock2
rename case_id HHID
save "$temp\c_AG_MOD_R1", replace


	*********************************
	*SOCIAL NETWORK
	*********************************
/*??? NETWORK ROSTER IS MISSING, EVEN IF IHS4 HAS DATA
use "$data\IHS4\Full_Sample\Agriculture\AG_NETWORK.dta", clear
keep if  ag_nr03==1
g vheadauth=(ag_nr02==4 | ag_nr02==5)
bys case_id: egen vheadauth2= max(vheadauth)
label var vheadauth2 "=1 or Yes if household is networked with village headman or traditional authority"
bys case_id:gen dup=cond(_N==1,0,_n)
drop if dup>1
drop dup
keep  case_id vheadauth2
ren vheadauth2 vheadauth
drop HHID
rename case_id HHID
save "$temp\c_AG_NETWORK", replace

 */

***Combine Agriculture Module
use "$temp/c_ag_mod_a_filt.dta", clear
merge 1:1 HHID using "$temp\c_AG_MOD_c-d.dta", nogen	
merge 1:1 HHID using "$temp\c_AG_MOD_g.dta", 
qui foreach v of varlist  share_* lharv_* prod_lnd_* cropdiv_*{
replace `v'=0 if _merge==1 & hh_crop==1				//Apply zero if the HHs didn't show up in module G, but does crop production
}
drop _merge
merge 1:1 HHID using "$temp\c_AG_MOD_e.dta", nogen	
*merge 1:1 HHID using "$temp\c_AG_MOD_f.dta", nogen	//Bring in later
merge 1:1 HHID using "$temp\c_AG_MOD_t1.dta", nogen	
merge 1:1 HHID using "$temp\c_AG_MOD_R1", nogen	
*merge 1:1 HHID using "$temp\c_AG_NETWORK", nogen	//Bring in later
*replace vheadauth=0 if vheadauth==.
save "$temp\Ag_IHS4", replace




	*********************************
	*COMMUNITY DATA
	*********************************
*Getting community level data on distance to services
use "$data\IHS4\Full_Sample\Community\COM_CD.dta", clear
keep ea_id com_cd01 com_cd02* com_cd15 com_cd16* com_cd17  com_cd18*
d
rename com_cd01 road_type
gen dist_road_com=com_cd02a if com_cd02b==2				//Distance to TAR/ASPHALT road in km 
replace dist_road_com=com_cd02a/1000 if com_cd02b==1
replace dist_road_com=com_cd02a*1.61 if com_cd02b==3
replace dist_road_com=0 if road_type==1 & dist_road_com==.	//TAR/ASPHALT road exists in the community

gen dist_dmkt=com_cd16 if com_cd16b==2				//Creating distance to nearest daily market in km 
replace dist_dmkt=com_cd16/1000 if com_cd16b==1
replace dist_dmkt=com_cd16*1.61 if com_cd16b==3
replace dist_dmkt=0 if com_cd15==1	& dist_dmkt==. //Market exists within the community

gen dist_wmkt=com_cd18a if com_cd18b==2				//Creating distance to nearest weekly market in km
replace dist_wmkt=com_cd18a/1000 if com_cd18b==1
replace dist_wmkt=com_cd18a*1.61 if com_cd18b==3
replace dist_wmkt=0 if com_cd17==1 & dist_wmkt==.	//Market exists within the community
*Addressing missing values
replace dist_wmkt=dist_dmkt if dist_dmkt==. & dist_wmkt~=.	//Apply weekly, if daily is missing. 
foreach v in w d{
qui sum  dist_`v'mkt, det
replace dist_`v'mkt=r(p90) if road_type==4 & dist_`v'mkt==.	//Assume: Dirt road implies far from market
}
keep ea_id road_type dist_road_com dist_dmkt dist_wmkt 
sort ea_id
label var dist_road_com "Distance to nearest tar/ asphalt road in km"
label var dist_dmkt "Distance to nearest daily market in Km"
label var dist_wmkt "Distance to nearest weekly market in Km"
save "$temp\c_COM_CD.dta", replace


	*********************************
	*CREDIT ACCESS AT COMMUNITY LEVEL
	*********************************
use "$data\IHS4\Full_Sample\Community\COM_CJ.dta",clear
keep if com_cj0b==304
sort ea_id
ren com_cj01 creditcomm
replace creditcomm=0 if creditcomm==2
label var creditcomm "=1 or yes if credit organization is present in the village"
label define yesno 0 "No" 1 "Yes", replace
label values creditcomm yesno 
keep ea_id creditcomm
tempfile Credit_comm
save "$temp\c_COM_CJ.dta", replace
 
***Combine Community level data
use "$temp\c_COM_CJ.dta", clear
merge 1:1 ea_id using "$temp\c_COM_CD.dta", nogen
save "$temp\CM_IHS4", replace
	



	*********************************
	*CONSUMPTION AGGREGATES
	*********************************
use "$data\IHS4\Full_Sample\poverty_ihs4", clear
gen ihs=4
label var ihs "IHS round (2, 3, 4)"
drop HHID
gen HHID=case_id

#delimit ;
keep HHID ea_id district TA region urban_region urban 
	sdate smonth syear ihs hhsize adulteq hh_wgt  
	rexp_cat* price_indexP  expagg rexpagg 
	rexpaggpc cpi pline_2016 upline_2016 poor upoor gap_* gap2_*;
#delimit cr
gen pline=pline_2016 
gen upline=upline_2016 
label var pline "Poverty line in correponding IHS"
label var upline "Ultra-poverty line in correponding IHS"
rename price_indexP price_index
save "$data\IHS4\Full_Sample\temp\c_poverty_ihs4", replace

use "$temp\HH_IHS4", clear
merge 1:1 HHID using "$temp\Ag_IHS4", nogen
merge m:1 ea_id using "$temp\CM_IHS4", nogen
merge m:1 HHID using "$temp\c_poverty_ihs4", nogen
save "$data\c_IHS4", replace

use "$data\c_IHS4", clear
append using "$data\c_IHS3"
save "$data\c_IHS3&4", replace
*/;
*/;
*/;
*/;
*/;
***************************************
*GEN household level dataset to merge *;
***************************************;

use "`d2'\Household\Temp\c_HH_MOD_A_FILT", clear;

sort HHID_temp;

merge 1:1 HHID_temp using "`d2'\Household\Temp\c_tcons";

gen round=5;

*gen rexpaggpc/hhsize;
*rexp_cat125_r19
*rexpfood
*rexpnfd rexpaggpc16;


sort HHID;
drop _merge;

merge 1:1 HHID using "`d2'\Household\Temp\c_hh_mod_b";

sort HHID;

drop _merge;

merge 1:1 HHID using "`d2'\Household\Temp\c_hh_mod_e";

sort HHID;

drop _merge;

merge 1:1 HHID using "`d2'\Household\Temp\c_hh_mod_h";

sort HHID;

drop _merge;

merge 1:1 HHID using "`d2'\Household\Temp\c_hh_mod_u";

sort HHID;

drop _merge;

merge 1:1 HHID using "`d2'\Agriculture\Temp\c_ag_mod_c-d.dta";
drop _merge;

sort HHID;


save "`d2'\IHS5_hh", replace;
