** Do not use without consent by: Katja Vinha, kvinha@gmail.com;

************************************************************************************
** This do file 
** 1. generates a pooled dataset from round 2, 3, 4, an 5 of the IHS Malawi
**
** OUTPUTS
** 1. 
*************************************************************************************

** DATE MODIFIED:  October 26, 2020;

cap log close
set more off
clear all
set mem 100m
#delimit ;

loc d1 			"C:\Users\Katja\Documents\CONSULTING/Malawi";

cap erase "`d1'\Results\logs\ihs_pooled.smcl";
log using "`d1'\Results\logs\ihs_pooled.smcl";

loc data_in			"`d1'\Data\c_IHS2&3&4.dta";				//input data;


loc pline_4		137428;				//pline in round 4 to normalize by;

loc ppp_16		526.2;				//poverty line based on 1.9ppp per day per person in 2016 MK (not sure which month though);

loc cpi_imf_0416	295.75;			//used to convert from April 2016 prices (rounds 2-4) to April 2019 price (round 5);
loc cpi_imf_0419	405.86;



*************************************************
*** Adding  round 5 and additional data from all rounds *******
**************************************************;
use `data_in', clear;

gen round=2 if syear==.;
replace round=3 if syear==2010 | syear==2011;
replace round=4 if syear==2016 | syear==2017;

drop if case_id=="";
cap drop _merge;

sort round case_id;


*********************************
** merge with round 5 base data *
*********************************;

append using "`d1'\Data\IHS5\IHS5_hh.dta";

*******************
**  assets  *
*******************;

merge 1:1 round case_id using "`d1'\Data\IHS2/hh_housing_2.dta", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS2/hh_durables_2.dta", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS3/hh_housing_3.dta", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS3/hh_durables_3.dta", update;

tab _merge;
drop _merge;


merge 1:1 round case_id using "`d1'\Data\IHS4/hh_housing_4.dta", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS4/hh_durables_4.dta", update;

tab _merge;
drop _merge;


merge 1:1 round case_id using "`d1'\Data\IHS5/hh_housing_5.dta", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS5/hh_durables_5.dta", update;

tab _merge;
drop _merge;
*/;

sort round case_id;


*******************
**  geo codes *
*******************;

*not collected for round 2;

merge 1:1 round case_id using "`d1'\Data\IHS3/geo_3", update;

tab _merge;
drop _merge;

sort round case_id;
merge 1:1 round case_id using "`d1'\Data\IHS4/geo_4", update;

tab _merge;
drop _merge;

sort round case_id;
merge 1:1 round case_id using "`d1'\Data\IHS5/geo_5", update;

tab _merge;
drop _merge;


**********************
*** community access *
**********************;
merge m:1 round ea_id using "`d1'\Data\IHS5/comm_access_5", update;

tab _merge;
drop _merge;

merge m:1 round ea_id using "`d1'\Data\IHS4/comm_access_4", update;

tab _merge;
drop _merge;

merge m:1 round ea_id using "`d1'\Data\IHS3/comm_access_3", update;

tab _merge;
drop _merge;

merge m:1 round dist ta ea using "`d1'\Data\IHS2/comm_access_2", update;

tab _merge;
drop _merge;


sort round case_id;
*******************
**  food security *
*******************;

merge 1:1 round case_id using "`d1'\Data\IHS2/fs_2", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS3/fs_3", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS4/fs_4", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS5/fs_5", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS3/fs2_3", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS4/fs2_4", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS5/fs2_5", update;

tab _merge;
drop _merge;

label var fcs "Food consumption score (slightly modified)";

*******************
**  FEIS *
*******************;
merge 1:1 round case_id using "`d1'\Data\IHS4/hh_feis_4", update;

tab _merge;
drop _merge;

/*
merge 1:1 round case_id using "`d1'\Data\IHS5/hh_feis_5", update;

tab _merge;
drop _merge;
*/;

*******************
**  safety nets *
*******************;

merge 1:1 round case_id using "`d1'\Data\IHS2/safety_2", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS3/safety_3", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS4/safety_4", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS5/safety_5", update;

tab _merge;
drop _merge;

*******************
**  shocks and coping *
*******************;

merge 1:1 round case_id using "`d1'\Data\IHS2/shocks_2", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS3/shocks_3", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS4/shocks_4", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS5/shocks_5", update;

tab _merge;
drop _merge;

*******************
**  interview date  *
*******************;

merge 1:1 round case_id using "`d1'\Data\IHS2/int_date_2", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS3/int_date_3", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS4/int_date_4", update;

tab _merge;
drop _merge;

*PLACE HOLDER DATE*;

replace int_day = sdate if round==5;
replace int_month = smonth if round==5;
replace int_year = syear if round==5;

replace int_date=mdy(int_month,int_day,int_year) if round==5;

/*;
merge 1:1 round case_id using "`d1'\Data\IHS5/int_date_5", update;

tab _merge;
drop _merge;
*/;

***************
** crops *****;
**************;

merge 1:1 round case_id using "`d1'\Data\IHS3\crops_3", update;

tab _merge;
drop _merge;

merge 1:1 round case_id using "`d1'\Data\IHS4\crops_4", update;

tab _merge;
drop _merge;

foreach var of varlist crops_total crop_cassava-crop_veg{;
	replace `var'=0 if `var'==. & (round==3 | round==4);
};
/*
***************
**  crop TAs **
***************;

merge m:1 round district TA using  "`d1'\Data\crops_ta.dta";

tab _merge;
drop _merge;
*/;

*********************
**  crop Districts **
********************;

merge m:1 round district using  "`d1'\Data\crops_dist.dta";

tab _merge;
drop _merge;


****************************
** price of maize at survey *;
****************************;
merge 1:1 round case_id using "`d1'\Data\prices_all.dta";

tab _merge;
drop _merge;

********************
** UPDATES TO DATA *
**************************;

gen rural=0;
replace rural=1 if urban==2 & (round==3 | round==4 |round==5);
replace rural=1 if urban==1 & round==2;

label var rural 	"Rural household";

drop urban;
bysort round: tab rural;

tab distr if rural==0;


*************************
** converting to real 16 *
**************************;

*For round 3 there is for some reason an additional step needed in order to get the real survey specific values;

merge 1:1 round case_id using "`d1'\Data\IHS3\rexp_ratio.dta";

tab _merge;
drop _merge;

save "`d1'/Data\IHS2345_app.dta", replace;


 *******************************
 ** merge with free maize data **
 *******************************;

use "`d1'/Data\IHS2345_app.dta", clear;

merge 1:1 case_id round using "`d1'\Data\IHS3\market_3.dta", update;

tab _merge;
drop _merge;

merge 1:1 case_id round using "`d1'\Data\IHS4\market_4.dta", update;

tab _merge;
drop _merge;

save "`d1'/Data\IHS2345_app.dta", replace;

 *******************************
 ** merge with zone info**
 *******************************;

use "`d1'/Data\IHS2345_app.dta", clear;

sort district;

merge m:1 district using "`d1'\Data\zones1.dta", update;

tab _merge;
*list district round if _merge==1;

drop _merge;

save "`d1'/Data\IHS2345_app.dta", replace;

 *******************************
 ** merge with CPI **
 *******************************;

use "`d1'/Data\IHS2345_app.dta", clear;

sort int_year int_month;

merge m:1 int_year int_month using "`d1'\Data\cpi_imf.dta", update;

tab _merge;
*list district round if _merge==1;

drop if _merge==2;

drop _merge;

save "`d1'/Data\IHS2345_app_v1.dta", replace;

*/;
**************************
****  Whole dataset work *
**************************;

use "`d1'/Data\IHS2345_app_v1.dta", clear;
/*
merge 1:1 case_id round using "`d1'\Data\IHS2\rexp_total2.dta";

tab _merge;
drop _merge;
*/;
*** gen deflator for 2016;
gen deflator16= rexpagg/expagg if round==4;
gen deflator19= rexpagg_r19/expagg if round==5;

*** gen total expeditures (from pc expenditures);
gen rexpagg16_total= rexpaggpc16 * hhsize;
label var rexpagg16_total "Total expenditures in real 2016 MK";

**generate total amount in safety net transfers (w/o maize) for rounds 2, 3, 4;

gen sn_r16= sn2_total*100/price_index*8.5015775 if round==2;
replace sn_r16= sn3_total*100/price_index*ratio_rext*3.7141016 if round==3;
replace sn_r16=sn3_total*deflator16 if round==4;
label var sn_r16 "Value of social assistance (without free maize) in real 2016 MK";

**gen value of free maize received;
gen maize_r16=amt_maize*100/price_index*ratio_rext*3.7141016 if round==3;
replace maize_r16=amt_maize*deflator16 if round==4;
replace maize_r16=0 if maize_r16==.;
label var maize_r16 "Value of free maize received";

gen sn_total_r16=sn_r16+maize_r16;
label var sn_total_r16 "Total value of social assistance WITH free maize in 2016 MK";

gen rexpagg16_n=rexpagg16_total-sn_total_r16;
label var rexpagg16_n "Total household expenditures without social assistance incl. free maize";

gen rexpagg16pc_n=rexpagg16_n/hhsize;
label var rexpagg16pc_n "Per capita expenditures without social assistance including free maize";


gen expagg_cpi_total=expagg/cpi_imf;

replace rexpagg_r19=rexpagg16_total*(`cpi_imf_0419'/`cpi_imf_0416') if inrange(round, 2, 4);

gen rexpagg_pc_r19=rexpaggpc16*(`cpi_imf_0419'/`cpi_imf_0416');
replace rexpagg_pc_r19=rexpagg_r19/hhsize if round==5;

gen sn_r19=sn_r16 * (`cpi_imf_0419'/`cpi_imf_0416');
replace sn_r19= sn3_total*deflator19 if round==5;

gen rexpfood_pc_r19=rexp_cat01_r19/hhsize if round==5;
replace rexpfood_pc_r19= rexpfood * 8.5015775 * (`cpi_imf_0419'/`cpi_imf_0416')/hhsize if round==2;
replace rexpfood_pc_r19= rexp_cat01 * 3.7141016 * (`cpi_imf_0419'/`cpi_imf_0416')/hhsize if round==3;
replace rexpfood_pc_r19= rexp_cat01 * (`cpi_imf_0419'/`cpi_imf_0416')/hhsize if round==4;

label var rexpagg_pc_r19 "Total expenditures per capita in April 2019 MK";
label var rexpfood_pc_r19 "Total food expenditures per capita in April 2019 MK";
label var sn_r19 "Value of social assistance (without free maize) in April 2019 MK";

bysort round: summ rexpagg_pc_r19 rexpfood_pc_r19 [aw=hh_wgt], detail;

order round rexpagg_pc_r19 hhsize rexpagg16_total rexpagg_pc_r19 rexpagg16pc;
sort rexpagg_pc_r19;

sort district ;
merge m:1 district using  "`d1'\Data\shocks\district_rf_merge";
keep if _m==3;
drop _m ;

replace gid_1 = trim(gid_1) ;
recast str9 gid_1;
format gid_1 %9s;
label var gid_1 "GADM Level 1";


recast float int_month;
label var int_month "Interview Month";
 
recast float int_year;
label var int_year "Interview Year";


gen ln_size = ln(hhsize);

gen ln_fcs = ln(fcs);
gen ln_hdds = ln(hdds);

gen urban_area = (urban_region==1);

replace hh_wgt = Prel_hh_weight if hh_wgt ==.;

gen poor_access = (zone_conn ==2);

gen case_id_2 = "r3"+case_id if round==3;
replace case_id_2 = "r4"+case_id if round==4;
replace case_id_2 = "r2"+case_id if round==2;
replace case_id_2 = "r5"+case_id if round==5;

drop if case_id=="";

merge m:1 gid_1 using "C:\Users\Katja\Documents\CONSULTING\Malawi\Data\MWI_centroids.dta";

drop _merge;

drop sn_*;
drop sn2_*;
drop sn3_*;
drop sn4_*;
drop year;
drop month;

save "`d1'/Data\IHS2345_app.dta", replace;
save "C:/Drought_Welfare_SSA/Input_Data/Data_Integration/Country/Malawi/IHS2345_app", replace;
save "C:/Drought_Welfare_SSA/Input_Data/Household_Survey/Malawi/IHS2345_app", replace;

*/;

stop;

******************************
*************  Explorations **
******************************;
use "`d1'/Data\IHS2345_app.dta", clear;

*order round price_index deflator16 expagg rexpagg* sn3_total sn_total* district ta syear smonth;
/*

compare sn_total_r16 rexpagg16_total if round==2;
summ rexpagg16_n if round==2;

compare sn_total_r16 rexpagg16_total if round==3;
summ rexpagg16_n if round==3;

compare sn_total_r16 rexpagg16_total if round==4;
summ rexpagg16_n if round==4;

gen pct_fm_exp=maize_r16/rexpagg16_total;

bysort round: summ pct_fm_exp if pct_fm_exp~=0, detail;
*/;

compare rexpaggpc16 rexpagg16pc_n  if round==2;
summ rexpagg16pc_n if round==2;

count if rexpagg16pc_n<0 & round==2;

compare rexpaggpc16 rexpagg16pc_n  if round==3;
summ rexpagg16pc_n if round==3;

count if rexpagg16pc_n<0 & round==3;

compare rexpaggpc16 rexpagg16pc_n  if round==4;
summ rexpagg16pc_n if round==4;

count if rexpagg16pc_n<0 & round==4;


/*

sort round deflator;

replace poor=poor/100;

gen poor_ppp=0 if rexpagg16_total~=.;
replace poor_ppp=1 if rexpaggpc16/365<`ppp_16';

gen poor_rev=0 if rexpagg16pc_no_sn~=.;
replace poor_rev=1 if rexpagg16pc_no_sn<137428;

gen poor_ppp_r3=0 if rexp_total_summed~=. & round==3;
replace poor_ppp_r3 = 1 if rexp_total_summed*3.71410163/hhsize/365<`ppp_16';

gen hc_poor=poor*hhsize;
gen hc_poor_rev=poor_rev*hhsize;
gen hc_poor_ppp=poor_ppp*hhsize;
gen hc_poor_ppp_r3=poor_ppp_r3*hhsize;

bysort round: egen total_pop=sum(hhsize);
bysort round: egen total_pop_wt=sum(hhsize*hh_wgt);

bysort round: egen total_hc_poor_wt=sum(hc_poor*hh_wgt);
bysort round: egen total_hc_poor_rev_wt=sum(hc_poor_rev*hh_wgt);
bysort round: egen total_hc_poor_ppp_wt=sum(hc_poor_ppp*hh_wgt);
bysort round: egen total_hc_poor_ppp_r3_wt=sum(hc_poor_ppp_r3*hh_wgt);

gen poverty_hc_wt=total_hc_poor_wt/total_pop_wt;
gen poverty_hc_rev_wt=total_hc_poor_rev_wt/total_pop_wt;
gen poverty_hc_ppp_wt=total_hc_poor_ppp_wt/total_pop_wt;
gen poverty_hc_ppp_r3_wt=total_hc_poor_ppp_r3_wt/total_pop_wt;

bysort round: summ poor_ppp- poverty_hc_ppp_r3_wt;

factor sh3_101- sh3_121 if round==3 | round==4;
predict f1;

corr f1 sh3_total;
*/;
/*
foreach round in 2{;
histogram sh`round'_total if round==`round', percent
	addl addlabopts(mlabformat(%2.1f) mlabsize(large))
	xlabel(,labs(large))
	ylabel(,labs(large))
	xtitle(,size(large))
	ytitle(,size(large))
	barw(0.5);
graph save "`d1'\Graphs\sh`round'_total", replace;
};

foreach round in 3 4 {;
histogram sh`round'_total if round==`round', percent
	title("Total number of shocks, Round `round'", size(vlarge))
	addl addlabopts(mlabformat(%2.0f) mlabsize(large))
	xlabel(,labs(large))
	ylabel(,labs(large))
	xtitle("Number of shocks",size(large))
	ytitle(,size(large))
	barw(0.5);
graph save "`d1'\Graphs\sh`round'_total", replace;
};

foreach round in 3 4 5{;
histogram fcs if round==`round', percent
	title("Food Consumption Score, Round `round'", size(vlarge))
	xlabel(,labs(large))
	ylabel(,labs(large))
	xtitle("FCS, modified",size(large))
	ytitle(,size(large))
	addplot(pci 0 35 8 35)
	legend(off);
graph save "`d1'\Graphs\fcs_`round'", replace;
};

foreach round in 2 3 4 5{;
histogram hdds if round==`round', percent
	title("Household Dietary Diversity Score, Round `round'", size(vlarge))
	subtitle("7 day recall")
	addl addlabopts(mlabformat(%2.0f) mlabsize(large))
	xlabel(0(1)12,labs(large))
	ylabel(,labs(large))
	xtitle("HDDS",size(large))
	ytitle(,size(large))
	xscale(range(0 12))
	barw(0.5);
graph save "`d1'\Graphs\hdds_`round'", replace;
};
