* Do File version

* Inputs: 
* a) CSV file with JRC crop cycle data
* b) stata data file with grid information and merge variable
* Outputs: 
* 1) Sorted (by uniqid) stata datasets for the gridded location and hazard variables 

cap program define country_crop_cycles
args country_name country_initial 
 
*** Load the JRC crop cycle data *** 
insheet using "./Input_Data/Remote_Sensed/SSA/merge_variable_data/crop_calendar_gaul1.csv", clear delimit(";")

gen growing_starts_dekad = .
gen harvest_starts_dekad =.

gen growing_second_starts_dekad = .
gen harvest_second_starts_dekad =.

* Southern African unimodal maize countries 
gen unimodal_southern_africa = (name0_shr == "Malawi" | name0_shr == "Mozambique" | name0_shr == "Zimbabwe" | name0_shr == "Zambia" | name0_shr == "Namibia" | name0_shr == "Botswana" | name0_shr == "Swaziland" | name0_shr == "Angola" | name0_shr == "South Africa")

replace crop_name = "Maize" if crop_name == "Maize (East)"
replace crop_name = "Maize" if crop_name == "Maize (West)"

replace growing_starts_dekad = sos_s  if unimodal_southern_africa ==1 & crop_name =="Maize"
replace harvest_starts_dekad = eos_s  if unimodal_southern_africa ==1 & crop_name =="Maize"

*Angola both maize and millet

replace growing_starts_dekad = sos_s  if (name0_shr == "Angola") & (crop_name=="Millet") & (name1_shr=="Cunene" | name1_shr=="Namibe" | name1_shr=="Luanda")
replace harvest_starts_dekad = eos_s  if (name0_shr == "Angola") & (crop_name=="Millet") & (name1_shr=="Cunene" | name1_shr=="Namibe" | name1_shr=="Luanda")

* Unimodal Eritrea maize
replace growing_starts_dekad = sos_s  if (name0_shr == "Eritrea") & crop_name =="Maize"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Eritrea") & crop_name =="Maize"

* Unimodal Madagascar rice
replace crop_name = "Rice" if (name1_shr == "Vatovavy F.")
replace growing_starts_dekad = sos_s  if (name0_shr == "Madagascar") & crop_name =="Rice"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Madagascar") & crop_name =="Rice"

* Unimodal Chad Sorghum
replace growing_starts_dekad = sos_s  if (name0_shr == "Chad") & crop_name =="Sorghum"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Chad") & crop_name =="Sorghum"

* Unimodal Niger Millet 
replace growing_starts_dekad = sos_s  if (name0_shr == "Niger") & crop_name =="Millet"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Niger") & crop_name =="Millet"

* Unimodal Nigeria Maize
replace growing_starts_dekad = sos_s  if (name0_shr == "Nigeria") & crop_name =="Maize (South/Main)"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Nigeria") & crop_name =="Maize (South/Main)"
replace growing_starts_dekad = sos_s  if (name0_shr == "Nigeria") & (name1_shr == "Zamfara" | name1_shr == "Sokoto" | name1_shr == "Bauchi" | name1_shr == "Adamawa" | name1_shr == "Kano" | name1_shr == "Katsina" | name1_shr == "Kebbi" | name1_shr == "Yobe" | name1_shr == "Gombe" | name1_shr == "Borno" | name1_shr == "Jigawa" ) & crop_name =="Sorghum"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Nigeria") & (name1_shr == "Zamfara" | name1_shr == "Sokoto" | name1_shr == "Bauchi" | name1_shr == "Adamawa"  | name1_shr == "Kano" | name1_shr == "Katsina" | name1_shr == "Kebbi" | name1_shr == "Yobe" | name1_shr == "Gombe" | name1_shr == "Borno" | name1_shr == "Jigawa") & crop_name =="Sorghum"

* Unimodal Mali Millet 
replace growing_starts_dekad = sos_s  if (name0_shr == "Mali") & crop_name =="Millet"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Mali") & crop_name =="Millet"

* Unimodal Mauritania Millet 
replace growing_starts_dekad = sos_s  if (name0_shr == "Mauritania") & crop_name =="Millet"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Mauritania") & crop_name =="Millet"

* Unimodal Burkina Faso Millet 
replace growing_starts_dekad = sos_s  if (name0_shr == "Burkina Faso") & crop_name =="Millet"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Burkina Faso") & crop_name =="Millet"

* Unimodal Nigeria Millet 
replace growing_starts_dekad = sos_s  if (name0_shr == "Nigeria") & crop_name =="Millet"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Nigeria") & crop_name =="Millet"

* Unimodal Algeria Wheat
replace growing_starts_dekad = sos_s  if (name0_shr == "Algeria") & crop_name =="Wheat"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Algeria") & crop_name =="Wheat"

* Unimodal Libya Barley
replace growing_starts_dekad = sos_s  if (name0_shr == "Libya") & crop_name =="Barley"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Libya") & crop_name =="Barley"

* Unimodal CAR cassava
replace growing_starts_dekad = sos_s  if (name0_shr == "Central Africa") & crop_name =="Cassava"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Central Africa") & crop_name =="Cassava"

* Unimodal Sudan (millet and sorghum are the same for each area)
replace growing_starts_dekad = sos_s  if (name0_shr == "Sudan") & crop_name =="Millet"
replace harvest_starts_dekad = eos_s  if (name0_shr == "Sudan") & crop_name =="Millet"

* Unimodal South Sudan (maize)
replace growing_starts_dekad = sos_s  if (name0_shr == "South Sudan") & crop_name =="Maize (Unimodal)"
replace harvest_starts_dekad = eos_s  if (name0_shr == "South Sudan") & crop_name =="Maize (Unimodal)"

* Bimodal DRC 
replace crop_name = "Maize Second" if crop_name == "Maize (North/Second)" & (name0_shr == "D.R. Congo")
replace crop_name = "Maize Second" if crop_name == "Maize (South/Second)" & (name0_shr == "D.R. Congo")

bysort name1_shr: egen median_sos_s = median(sos_s) if (name0_shr == "D.R. Congo") & (crop_name == "Maize (Centre/Main)")  
bysort name1_shr: egen median_eos_s = median(eos_s) if (name0_shr == "D.R. Congo") & (crop_name == "Maize (Centre/Main)")  

replace growing_starts = median_sos_s if (name0_shr == "D.R. Congo") & (crop_name == "Maize (Centre/Main)")
replace harvest_starts = median_eos_s if (name0_shr == "D.R. Congo") & (crop_name == "Maize (Centre/Main)")
drop median_sos median_eos

replace growing_second_starts = sos_s if (name0_shr == "D.R. Congo") & crop_name == "Maize Second"
replace harvest_second_starts = eos_s if (name0_shr == "D.R. Congo") & crop_name == "Maize Second"

 * Bimodal (Uganda)
bysort name1_shr: egen median_sos_s = median(sos_s) if (name0_shr == "Uganda") & (crop_name == "Maize (South/Main)")  
bysort name1_shr: egen median_eos_s = median(eos_s) if (name0_shr == "Uganda") & (crop_name == "Maize (South/Main)")  

replace growing_starts = median_sos_s if (name0_shr == "Uganda") & (crop_name == "Maize (South/Main)")
replace harvest_starts = median_eos_s if (name0_shr == "Uganda") & (crop_name == "Maize (South/Main)")
drop median_sos median_eos

replace growing_second_starts = sos_s if (name0_shr == "Uganda") & crop_name == "Maize (South/Second)"
replace harvest_second_starts = eos_s if (name0_shr == "Uganda") & crop_name == "Maize (South/Second)"

 * Bimodal (Kenya) Used millet instead of maize because a) many places don't have maize long rains b) the growing season is similar, but the millet harvest starts earlier (so assuming that the lean season would end then)
bysort name1_shr: egen median_sos_s = median(sos_s) if (name0_shr == "Kenya") & (crop_name == "Millet (Long rains)")  
bysort name1_shr: egen median_eos_s = median(eos_s) if (name0_shr == "Kenya") & (crop_name == "Millet (Long rains)")  

replace growing_starts = median_sos_s if (name0_shr == "Kenya") & (crop_name == "Millet (Long rains)")
replace harvest_starts = median_eos_s if (name0_shr == "Kenya") & (crop_name == "Millet (Long rains)")
drop median_sos median_eos
replace growing_starts = sos_s if (name1_shr == "Uasin Gishu") & (crop_name == "Maize (Long rains)")
replace harvest_starts = eos_s if (name1_shr == "Uasin Gishu") & (crop_name == "Maize (Long rains)")

replace growing_second_starts = sos_s if (name0_shr == "Kenya") & crop_name == "Millet (Short rains)"
replace harvest_second_starts = eos_s if (name0_shr == "Kenya") & crop_name == "Millet (Short rains)"

 * Bimodal (Congo) 
bysort name1_shr: egen median_sos_s = median(sos_s) if (name0_shr == "Congo") & (crop_name == "Maize (Main)")  
bysort name1_shr: egen median_eos_s = median(eos_s) if (name0_shr == "Congo") & (crop_name == "Maize (Main)")  

replace growing_starts = median_sos_s if (name0_shr == "Congo") & (crop_name == "Maize (Main)")
replace harvest_starts = median_eos_s if (name0_shr == "Congo") & (crop_name == "Maize (Main)")
drop median_sos median_eos

replace growing_second_starts = sos_s if (name0_shr == "Congo") & crop_name == "Maize (Second)"
replace harvest_second_starts = eos_s if (name0_shr == "Congo") & crop_name == "Maize (Second)"

 * Bimodal (Rwanda) 
bysort name1_shr: egen median_sos_s = median(sos_s) if (name0_shr == "Rwanda") & (crop_name == "Maize (A season))")  
bysort name1_shr: egen median_eos_s = median(eos_s) if (name0_shr == "Rwanda") & (crop_name == "Maize (A season))")  

replace growing_starts = median_sos_s if (name0_shr == "Rwanda") & (crop_name == "Maize (A season))")
replace harvest_starts = median_eos_s if (name0_shr == "Rwanda") & (crop_name == "Maize (A season))")
drop median_sos median_eos

replace growing_second_starts = sos_s if (name0_shr == "Rwanda") & crop_name == "Maize (B season)"
replace harvest_second_starts = eos_s if (name0_shr == "Rwanda") & crop_name == "Maize (B season)"

 * Bimodal (Burundi) 
bysort name1_shr: egen median_sos_s = median(sos_s) if (name0_shr == "Burundi") & (crop_name == "Maize (A season))")  
bysort name1_shr: egen median_eos_s = median(eos_s) if (name0_shr == "Burundi") & (crop_name == "Maize (A season))")  

replace growing_starts = median_sos_s if (name0_shr == "Burundi") & (crop_name == "Maize (A season))")
replace harvest_starts = median_eos_s if (name0_shr == "Burundi") & (crop_name == "Maize (A season))")
drop median_sos median_eos

replace growing_second_starts = sos_s if (name0_shr == "Burundi") & crop_name == "Maize (B season)"
replace harvest_second_starts = eos_s if (name0_shr == "Burundi") & crop_name == "Maize (B season)"

 * Bimodal (Somalia) 
bysort name1_shr: egen median_sos_s = median(sos_s) if (name0_shr == "Somalia") & (crop_name == "Maize (Der)")  
bysort name1_shr: egen median_eos_s = median(eos_s) if (name0_shr == "Somalia") & (crop_name == "Maize (Der)")  

replace growing_starts = median_sos_s if (name0_shr == "Somalia") & (crop_name == "Maize (Der)")
replace harvest_starts = median_eos_s if (name0_shr == "Somalia") & (crop_name == "Maize (Der)")
drop median_sos median_eos

replace growing_second_starts = sos_s if (name0_shr == "Somalia") & crop_name == "Maize (Gu)"
replace harvest_second_starts = eos_s if (name0_shr == "Somalia") & crop_name == "Maize (Gu)"

* Unimodal Tanzania
* Arusha has a unimodal maize cycle listed but it is bimodal 
drop if (name1_shr == "Arusha" & crop_name == "Maize (Maimu/Unimodal)")
replace growing_starts = sos_s if (name0_shr == "Tanzania") & crop_name == "Maize (Maimu/Unimodal)"
replace harvest_starts = eos_s if (name0_shr == "Tanzania") & crop_name == "Maize (Maimu/Unimodal)"

 * Bimodal (Tanzania)
bysort name1_shr: egen median_sos_s = median(sos_s) if (name0_shr == "Tanzania") & (crop_name == "Maize (Maika/Bimodal)")  
bysort name1_shr: egen median_eos_s = median(eos_s) if (name0_shr == "Tanzania") & (crop_name == "Maize (Maika/Bimodal)")  

replace growing_starts = median_sos_s if (name0_shr == "Tanzania") & (crop_name == "Maize (Maika/Bimodal)")
replace harvest_starts = median_eos_s if (name0_shr == "Tanzania") & (crop_name == "Maize (Maika/Bimodal)")
drop median_sos median_eos

replace growing_second_starts = sos_s if (name0_shr == "Tanzania") & crop_name == "Maize (Vuli/Bimodal)"
replace harvest_second_starts = eos_s if (name0_shr == "Tanzania") & crop_name == "Maize (Vuli/Bimodal)"

* Unimodal and Bimodal (Ethiopia). These are done together in Ethiopia because unimodal crops are also labelled as Meher.
bysort name1_shr: egen median_sos_s = median(sos_s) if (name0_shr == "Ethiopia") & (crop_name == "Teff (Meher)" | crop_name == "Wheat (Meher)" | crop_name == "Maize (Meher)" | crop_name == "Millet (Meher)" | crop_name == "Sorghum (Meher)" | crop_name == "Oats (Meher)" | crop_name =="Barley (Meher)") 
bysort name1_shr: egen median_eos_s = median(eos_s) if (name0_shr == "Ethiopia") & (crop_name == "Teff (Meher)" | crop_name == "Wheat (Meher)" | crop_name == "Maize (Meher)" | crop_name == "Millet (Meher)" | crop_name == "Sorghum (Meher)" | crop_name == "Oats (Meher)" | crop_name =="Barley (Meher)") 

replace growing_starts = median_sos_s if (name0_shr == "Ethiopia") & (name0_shr == "Ethiopia") & (crop_name == "Teff (Meher)" | crop_name == "Wheat (Meher)" | crop_name == "Maize (Meher)" | crop_name == "Millet (Meher)" | crop_name == "Sorghum (Meher)" | crop_name == "Oats (Meher)" | crop_name =="Barley (Meher)") 
replace harvest_starts = median_eos_s if (name0_shr == "Ethiopia") & (name0_shr == "Ethiopia") & (crop_name == "Teff (Meher)" | crop_name == "Wheat (Meher)" | crop_name == "Maize (Meher)" | crop_name == "Millet (Meher)" | crop_name == "Sorghum (Meher)" | crop_name == "Oats (Meher)" | crop_name =="Barley (Meher)") 
drop median_sos median_eos

replace growing_second_starts = sos_s if (name0_shr == "Ethiopia") & crop_name == "Cereals all (Belg)"
replace harvest_second_starts = eos_s if (name0_shr == "Ethiopia") & crop_name == "Cereals all (Belg)"

*******************************************************
* Keep variables for later analysis
keep name0_shr name1_shr asap0_id asap1_id growing_* harvest_* 

bysort name0_shr name1_shr: egen harvest_start_dekad =max(harvest_starts)
bysort name0_shr name1_shr: egen growing_start_dekad =max(growing_starts)
bysort name0_shr name1_shr: egen harvest_second_start_dekad =max(harvest_second_starts_dekad)
bysort name0_shr name1_shr: egen growing_second_start_dekad =max(growing_second_starts_dekad)

drop harvest_starts_dekad growing_starts_dekad harvest_second_starts_dekad growing_second_starts_dekad 
duplicates drop name0_shr name1_shr harvest_start_dekad harvest_second_start_dekad growing_start_dekad growing_second_start_dekad,force

replace growing_start_dekad = growing_second_start_dekad if growing_start ==.  
replace harvest_start = harvest_second_start if harvest_start ==.  
gen growing_start_diff = abs(growing_start_dekad - growing_second_start_dekad)
replace growing_second_start =. if (growing_start_dekad == growing_second_start_dekad) | (harvest_start_dekad == harvest_second_start_dekad) | ( growing_start_diff  < 7) 
replace harvest_second_start =. if  growing_second_start ==.
drop growing_start_diff

sort asap0_id asap1_id
joinby asap0_id asap1_id using "./Processed_Data/Country/`country_name'/Remote_Sensed/`country_initial'_crop_calendar_mapping"
drop asap0_id asap1_id
drop if uniqid ==""
drop if harvest_start_dekad ==. 

local stage "growing harvest growing_second harvest_second"
  foreach s of local stage {
preserve
gen dekad = floor(`s'_start_dekad)
keep uniqid dekad  
duplicates drop uniqid, force
sort uniqid
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/`s'_start.dta", replace
restore
  }
   
end