* Outputs a pdf maps of Hazard anomalies by admin level and interview year (current gadm level 1)
* Please read the intructions just above where this program is used in the main do file (HH_Survey_Hazard_Integration)

cap program define hazard_map
args main_directory_name country_name country_initial hazard admin_level int_year

**********
* Convert shapefiles to stata files
cd "`c(pwd)'/Input_Data/Remote_Sensed/Country/`country_name'"
spshape2dta gadm36_`country_initial'_1, replace
cd `main_directory_name'/Drought_Welfare_SSA
* Merge with hazard anomalies using admin level
use "./Input_Data/Remote_Sensed/Country/`country_name'/gadm36_`country_initial'_1", clear
rename GID_*, lower
merge 1:m gid_1 using "./Processed_Data/Country/`country_name'/Merged_HH_Hazard/merged_hh_hazard"
drop _m
collapse anomaly_`hazard'_`admin_level' _CX _CY  `admin_level', by(`int_year' _ID  NAME_*)
drop if _ID ==. 

save "`c(pwd)'/Input_Data/Remote_Sensed/Country/`country_name'/`hazard'_anomaly_merge_map",replace
cd "`c(pwd)'/Input_Data/Remote_Sensed/Country/`country_name'"

grmap, activate
use `hazard'_anomaly_merge_map, clear

* Graph Style
grstyle init
grstyle set plain

local maps_`hazard'_anomaly ""

levelsof `int_year', local(yr)
 foreach y of local yr {
local maps_`hazard'_anomaly "`maps_`hazard'_anomaly' `hazard'_anomaly_`y'.gph"
preserve
keep if `int_year' == `y'
xtset, clear
spset, modify shpfile(gadm36_`country_initial'_1_shp)

if ("`hazard'" == "wrsi") {
* Map the anomaly by admin level over year 
 grmap anomaly_`hazard'_`admin_level' if `int_year' == `y', nodraw  ///      
	   clnumber(4)       ///  
       clmethod(custom) ///
       clbreaks(70 90 100 110 130)    ///
       title("`y'") ///
	   fcolor(RdYlGn) /// 
	   osize(vvthin) 
	   *label(label(NAME_1) xcoord(_CX) ycoord(_CY) )  
 graph save `hazard'_anomaly_`y',  replace
}
 if  ("`hazard'" == "ndvi" | "`hazard'" == "chirps") {
* Map the anomaly by admin level over year 
 grmap anomaly_`hazard'_`admin_level' if `int_year' == `y', nodraw  ///      
	   clnumber(4)       ///  
       clmethod(custom) ///
       clbreaks(-3 -2 -1 0 3)    ///
       title("`y'") ///
	   fcolor(RdYlGn) /// 
	   osize(vvthin) 
	   *label(label(NAME_1) xcoord(_CX) ycoord(_CY) )  
 graph save `hazard'_anomaly_`y',  replace
}
 restore
 }
  
grc1leg `maps_`hazard'_anomaly', col(3) xsize(8) ysize(8) title("Exposure to Hazard: `hazard' standardized anomaly") scale(*0.75) 
graph export maps_`hazard'_anomaly.pdf,  replace
 
cd `main_directory_name'/Drought_Welfare_SSA	   
end