* Do File version

* Inputs: 
* Spatially averaged chirps measure time series for every hh
 
* Outputs: 
* 1) single time series of the spatially averaged hazard measure constructed as an event for every household 

cap program define hh_chirps_rs_time_series 
* The arguments are the country_name and the name of a spatially averaged hazard data set
args country_name spatial_scale chirps_available rainy_season_available radius

if "`chirps_available'" == "Yes"  & "`rainy_season_available'" == "Yes" {

local poor_threshold= -0.5


* This should be a Do file with a list of mkdir commands to create the folder structure

cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/chirps/chirps_final/" 

use   "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/chirps/averaged_`spatial_scale'_chirps.dta", clear

quietly {
reshape long yd_, i(`spatial_scale') j(time) string
}

rename yd_ y

* separate the time variable into year month dekad and radius
gen year1 = substr(time,1,4) 
gen year = real(year1)
gen dekad1 = substr(time,5,2) 
gen dekad = real(dekad1)
gen month = ceil(dekad/3)
drop year1 time

* Merge year dekad dataset
merge 1:1 `spatial_scale' year dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/`spatial_scale'_year_dekad"
replace y = 0 if _m ==2
drop _m

* create a time index and set as panel data
sort `spatial_scale' year dekad
bysort `spatial_scale': gen time_index = _n

tsset `spatial_scale' time_index


merge m:1 `spatial_scale' using "./Processed_Data/Country/`country_name'/Remote_Sensed/rs_dates_`spatial_scale'"
drop _m

tsset


*****rainy season hazards

*identify dekads that are within the rainy season based on start and end dekads
gen rs_m=1 if dekad>= rs_start_dekad & dekad<= rs_end_dekad & rs_start_dekad<=rs_end_dekad
replace rs_m=1 if dekad>= rs_start_dekad & dekad<=36 & rs_start_dekad>rs_end_dekad
replace rs_m=1 if dekad<= rs_end_dekad & rs_start_dekad>rs_end_dekad

*identify dekads tjat are within the second rainy based on start and end dekads
gen rs2_m=1 if dekad>= rs2_start_dekad & dekad<= rs2_end_dekad & rs2_start_dekad<=rs2_end_dekad
replace rs2_m=1 if dekad>= rs2_start_dekad & dekad<=36 & rs2_start_dekad>rs2_end_dekad
replace rs2_m=1 if dekad<= rs2_end_dekad & rs2_start_dekad>rs2_end_dekad

*generate a index where 1 is the first dekad after the rainy season ends
gen rs_seq=dekad-rs_end_dekad if dekad>rs_end_dekad
replace rs_seq=36-(rs_end_dekad-dekad) if dekad<=rs_end_dekad

*generate a index where 1 is the first dekad after the second rainy season ends
gen rs2_seq=dekad-rs2_end_dekad if dekad>rs2_end_dekad
replace rs2_seq=36-(rs2_end_dekad-dekad) if dekad<=rs2_end_dekad

********************
**FIRST rainy season 

*generate variables to get the rainy season ndvi 
gen rs_length=rs_end_dekad-rs_start_dekad+1 if rs_end_dekad>rs_start_dekad
replace rs_length=36-rs_start_dekad+rs_end_dekad+1 if rs_end_dekad<rs_start_dekad

bysort `spatial_scale': egen first_yr=min(year)
bysort `spatial_scale': egen last_yr =max(year)
gen tot_yrs=last_yr-first_yr+1

gen rs_year=1 if rs_seq==1 & year==first_yr

replace rs_year=rs_year[_n-36]+1 if rs_seq==1 & `spatial_scale'==`spatial_scale'[_n-36]
bysort `spatial_scale' (time_index): carryforward rs_year, gen(rs_yr)

*total rf taking out rf for first seasons that are not complete
egen tot_chirps=total(y) if rs_m==1, by(`spatial_scale' rs_yr)
replace tot_chirps=. if rs_yr==. 		

gen tot2_chirps=tot_chirps[_n-1] if rs_seq==1 & `spatial_scale'==`spatial_scale'[_n-1]

* This is the standardized anomaly (Z-score) for the rainy season rf
bysort `spatial_scale': egen std_tot_rs_chirps=std(tot2_chirps) if rs_seq==1

bysort `spatial_scale': egen mean_tot_rs_chirps = mean(tot2_chirps) if rs_seq ==1
bysort `spatial_scale': egen sd_tot_rs_chirps = sd(tot2_chirps) if rs_seq ==1
bysort `spatial_scale': gen level_tot_rs_chirps = tot2_chirps if rs_seq ==1

* This zscore is used from one growing season until the next begins since all the values are missing and filled out 

bysort `spatial_scale' (time_index): carryforward std_tot_rs_chirps, gen(anomaly_rs_chirps)

bysort `spatial_scale' (time_index): carryforward mean_tot_rs_chirps, gen(mean_rs_chirps)
bysort `spatial_scale' (time_index): carryforward sd_tot_rs_chirps, gen(sd_rs_chirps)
bysort `spatial_scale' (time_index): carryforward level_tot_rs_chirps, gen(level_rs_chirps)

**********************
**SECOND rainy season 

*generate variables to get the rainy season rf 
gen rs2_length=rs2_end_dekad-rs2_start_dekad+1 if rs2_end_dekad>rs2_start_dekad
replace rs2_length=36-rs2_start_dekad+rs2_end_dekad+1 if rs2_end_dekad<rs2_start_dekad

gen rs2_year=1 if rs2_seq==1 & year==first_yr

replace rs2_year=rs2_year[_n-36]+1 if rs2_seq==1 & `spatial_scale'==`spatial_scale'[_n-36]
bysort `spatial_scale' (time_index): carryforward rs2_year, gen(rs2_yr)

*total rf taking out rf for first seasons that are not complete
egen tot_chirps2=total(y) if rs2_m==1, by(`spatial_scale' rs2_yr)
replace tot_chirps2=. if rs2_yr==. 		

gen tot2_chirps2=tot_chirps2[_n-1] if rs2_seq==1 & `spatial_scale'==`spatial_scale'[_n-1]

* This is the standardized anomaly (Z-score) for the rainy season chirps
bysort `spatial_scale': egen std_tot_rs2_chirps=std(tot2_chirps2) if rs2_seq==1

bysort `spatial_scale': egen mean_tot_rs2_chirps = mean(tot2_chirps2) if rs2_seq ==1
bysort `spatial_scale': egen sd_tot_rs2_chirps = sd(tot2_chirps2) if rs2_seq ==1
bysort `spatial_scale': gen level_tot_rs2_chirps = tot2_chirps2 if rs2_seq ==1

* This zscore is used from one growing season until the next begins since all the values are missing and filled out 

bysort `spatial_scale' (time_index): carryforward std_tot_rs2_chirps, gen(anomaly_rs2_chirps)

bysort `spatial_scale' (time_index): carryforward mean_tot_rs2_chirps, gen(mean_rs2_chirps)
bysort `spatial_scale' (time_index): carryforward sd_tot_rs2_chirps, gen(sd_rs2_chirps)
bysort `spatial_scale' (time_index): carryforward level_tot_rs2_chirps, gen(level_rs2_chirps)


**************************
*****national - need to check if works****
if "`spatial_scale'" =="national" {
	preserve
	keep if  rs_seq ==1
	keep anomaly_rs_chirps year 
	sort year
	save "./Processed_Data/Country/`country_name'/National_Estimates/chirps_rs_national_series.dta", replace
	restore
	
	preserve
	keep if  rs2_seq ==1
	keep anomaly_rs2_chirps year 
	sort year
	save "./Processed_Data/Country/`country_name'/National_Estimates/chirps_rs2_national_series.dta", replace
	restore	
}

**** generate the final dataset with both RS anomalies and end season dekads.

keep `spatial_scale' year month anomaly_rs_chirps mean_rs_chirps level_rs_chirps sd_rs_chirps anomaly_rs2_chirps mean_rs2_chirps level_rs2_chirps sd_rs2_chirps rs_end_dekad rs2_end_dekad rs_start_dekad rs2_start_dekad

local shock "anomaly_rs_chirps mean_rs_chirps level_rs_chirps sd_rs_chirps  anomaly_rs2_chirps mean_rs2_chirps level_rs2_chirps sd_rs2_chirps"
foreach s of local shock {
       rename `s' `s'_`spatial_scale'
        }

rename month int_month
rename year int_year
duplicates drop `spatial_scale'  int_month int_year, force

sort `spatial_scale' int_year int_month

merge 1:1 `spatial_scale' int_year int_month using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_`spatial_scale'_merge.dta"


preserve
keep if int_month==1 
keep `spatial_scale' anomaly_rs_chirps_`spatial_scale' int_year int_month `hh_lat' `hh_lon'
save "./Processed_Data/Country/Pooled/`country_name'_rs_chirps`radius'.dta", replace
restore

keep if _m ==3
drop _m 

* save file in folder 
duplicates drop `spatial_scale'  int_month int_year, force
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/chirps/chirps_final/merged_`spatial_scale'_rs_chirps.dta", replace

}
 
end





