* Do File version

* Inputs: 
* Spatially averaged chirps measure time series for every hh
 
* Outputs: 
* 1) single time series of the spatially averaged hazard measure constructed as an event for every household 

cap program define hh_chirps_time_series 
* The arguments are the country_name and the name of a spatially averaged hazard data set
*args country_name spatial_scale chirps_available rainy_season_hazards radius hh_lat hh_lon
args country_name spatial_scale chirps_available radius hh_lat hh_lon

if "`chirps_available'" == "Yes" {

local poor_threshold= -0.5


* This should be a Do file with a list of mkdir commands to create the folder structure

cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/chirps/chirps_final/" 

use   "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/chirps/averaged_`spatial_scale'_chirps.dta", clear

quietly {
reshape long yd_, i(`spatial_scale') j(time) string
}

rename yd_ y

* separate the time variable into year month dekad and radius
gen year1 = substr(time,1,4) 
gen year = real(year1)
gen dekad1 = substr(time,5,2) 
gen dekad = real(dekad1)
gen month = ceil(dekad/3)
drop year1 time

* Save dataset with year dekad to be used by NDVI and WRSI
preserve
keep `spatial_scale' year dekad
sort `spatial_scale' year dekad
merge 1:1 `spatial_scale' year dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/`spatial_scale'_year_dekad"
restore

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/harvest_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/growing_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/harvest_second_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/growing_second_start_`spatial_scale'"
drop _m

if "`rainy_season_hazards'" == "Yes"  {
merge m:1 `spatial_scale' month using  "./Processed_Data/Country/`country_name'/Remote_Sensed/`spatial_scale'_rainy_season_months"
drop _m
}

* create a time index and set as panel data
sort `spatial_scale' year dekad
bysort `spatial_scale': gen time_index = _n

tsset `spatial_scale' time_index

**** rainy season hazards
if "`rainy_season_hazards'" == "Yes"  {
bysort `spatial_scale': 

}


*****growing season and annual hazards

gen previous_month_rf = L.y + L2.y + L3.y
gen previous_3month_rf = L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y
gen previous_6month_rf = L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y + L10.y + L11.y + L12.y + L13.y + L14.y + ///
L15.y + L16.y + L17.y + L18.y
gen previous_year_rf = L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y + L10.y + L11.y + L12.y + L13.y + L14.y + ///
L15.y + L16.y + L17.y + L18.y + L19.y + L20.y + L21.y + L22.y + L23.y + L24.y + L25.y + L26.y + L27.y + L28.y + L29.y + L30.y + L31.y + L32.y + L33.y + L34.y + L35.y + L36.y

gen prev_m4to6_rf= L10.y + L11.y + L12.y + L13.y + L14.y + L15.y + L16.y + L17.y + L18.y

gen prev_m7to9_rf= L19.y + L20.y + L21.y + L22.y + L23.y + L24.y + L25.y + L26.y + L27.y

* Cumulative 3 month Rainfall Anomaly (Last 9 dekads)
bysort `spatial_scale' dekad: egen previous_3month_a_rf = std(previous_3month_rf)

* Cumulative 6 monthl Rainfall Anomaly (Last 18 dekads)
bysort `spatial_scale' dekad: egen previous_6month_a_rf = std(previous_6month_rf)

* Cumulative Annual Rainfall Anomaly (Last 36 dekads)
bysort `spatial_scale' dekad: egen previous_year_a_rf = std(previous_year_rf)

*Cumulative 3 month rainfall lagged (-2) quarter
bysort `spatial_scale' dekad: egen prev_m4to6_a_rf = std(prev_m4to6_rf) 

*Cumulative 3 month rainfall lagged (-3) quarter
bysort `spatial_scale' dekad: egen prev_m7to9_a_rf = std(prev_m7to9_rf)

* Generate a dummy that is one for the growing season, zero otherwise 
tsset
gen growing_season = (growing_start ==1 | L.growing_start == 1 | L2.growing_start == 1 | L3.growing_start ==1 | L4.growing_start == 1 | L5.growing_start == 1 | L6.growing_start == 1 | L7.growing_start == 1 | L8.growing_start == 1)
gen growing_second_season = (growing_second_start ==1 | L.growing_second_start == 1 | L2.growing_second_start == 1 | L3.growing_second_start ==1 | L4.growing_second_start == 1 | L5.growing_second_start == 1)

* Generate a standardized anomaly for each dekad in the growing season 
bysort `spatial_scale' dekad: egen std_rf = std(y) if growing_season ==1
replace std_rf = 0 if std_rf ==.

* Generate a standardized anomaly for each dekad in the second growing season 
bysort `spatial_scale' dekad: egen std_second_rf = std(y) if growing_second_season ==1
replace std_second_rf = 0 if std_second_rf ==.

tsset 
gen dry_spell = (std_rf<`poor_threshold' & L.std_rf<`poor_threshold' & L2.std_rf<`poor_threshold') 
gen gs_dry_spell = (dry_spell ==1 | F.dry_spell ==1 | F2.dry_spell ==1 | F3.dry_spell ==1 | F4.dry_spell ==1  | F5.dry_spell ==1 | F6.dry_spell ==1 | F7.dry_spell ==1 | F8.dry_spell ==1 ) & growing_start==1
replace gs_dry_spell = . if growing_start !=1
bysort `spatial_scale' (time_index): carryforward gs_dry_spell, gen(growing_dry_spell)
gen gs_dry = growing_dry_spell if harvest_start ==1
bysort `spatial_scale' year month: egen dry_spell_growing = max(gs_dry)

tsset 
gen dry_second_spell = (std_second_rf<`poor_threshold' & L.std_second_rf<`poor_threshold' & L2.std_second_rf<`poor_threshold') 
gen gs_dry_second_spell = (dry_second_spell ==1 | F.dry_second_spell ==1 | F2.dry_second_spell ==1 | F3.dry_second_spell ==1 | F4.dry_second_spell ==1  | F5.dry_second_spell ==1) & growing_second_start==1
replace gs_dry_second_spell = . if growing_second_start !=1
bysort `spatial_scale' (time_index): carryforward gs_dry_second_spell, gen(growing_dry_second_spell)
gen gs_second_dry = growing_dry_second_spell if harvest_second_start ==1
bysort `spatial_scale' year month: egen dry_spell_second_growing = max(gs_second_dry)

* construct the hazard event 
* sum of the present and the following 8 dekads (current and following 5 dekads for the short rains)
tsset
gen tot_9_rf =  y + F.y + F2.y + F3.y + F4.y + F5.y + F6.y + F7.y + F8.y if growing_start ==1

tsset
gen tot_6_second_rf =  y + F.y + F2.y + F3.y + F4.y + F5.y if growing_second_start ==1

* This is the standardized anomaly (Z-score) for the cumulative growing season rainfall
bysort `spatial_scale': egen std_tot_9_rf = std(tot_9_rf) if growing_start ==1
bysort `spatial_scale': egen std_tot_6_second_rf = std(tot_6_second_rf) if growing_second_start ==1

* This is the mean for the cumulative growing season rainfall
bysort `spatial_scale':  egen mean_tot_9_rf = mean(tot_9_rf) if growing_start ==1
bysort `spatial_scale':  egen mean_tot_6_second_rf = mean(tot_6_second_rf) if growing_second_start ==1

* This is the sd for the cumulative growing season rainfall
bysort `spatial_scale':  egen sd_tot_9_rf = sd(tot_9_rf) if growing_start ==1
bysort `spatial_scale':  egen sd_tot_6_second_rf = sd(tot_6_second_rf) if growing_second_start ==1

* This is the level for the cumulative growing season rainfall
bysort `spatial_scale': gen level_tot_9_rf = tot_9_rf if growing_start ==1
bysort `spatial_scale':  gen level_tot_6_second_rf = tot_6_second_rf if growing_second_start ==1

* This zscore is used from one growing season until the next begins since all the values are missing and filled out 
bysort `spatial_scale' (time_index): carryforward std_tot_9_rf, gen(a_tot_9_rf)
bysort `spatial_scale' (time_index): carryforward std_tot_6_second_rf, gen(a_tot_6_second_rf)

* Same for level, sd and mean
bysort `spatial_scale' (time_index): carryforward mean_tot_9_rf, gen(a_mean_tot_9_rf)
bysort `spatial_scale' (time_index): carryforward mean_tot_6_second_rf, gen(a_mean_tot_6_second_rf)

bysort `spatial_scale' (time_index): carryforward level_tot_9_rf, gen(a_level_tot_9_rf)
bysort `spatial_scale' (time_index): carryforward level_tot_6_second_rf, gen(a_level_tot_6_second_rf)

bysort `spatial_scale' (time_index): carryforward sd_tot_9_rf, gen(a_sd_tot_9_rf)
bysort `spatial_scale' (time_index): carryforward sd_tot_6_second_rf, gen(a_sd_tot_6_second_rf)

* The harvest anomaly is defined at the harvest and missing for all other dekads
gen gs_anomaly = a_tot_9_rf if harvest_start ==1
gen gs_second_anomaly = a_tot_6_second_rf if harvest_second_start ==1

* Same for level, mean and sd
gen gs_mean = a_mean_tot_9_rf if harvest_start ==1
gen gs_mean_second = a_mean_tot_6_second_rf if harvest_second_start ==1

gen gs_level = a_level_tot_9_rf if harvest_start ==1
gen gs_level_second = a_level_tot_6_second_rf if harvest_second_start ==1

gen gs_sd = a_sd_tot_9_rf if harvest_start ==1
gen gs_sd_second = a_sd_tot_6_second_rf if harvest_second_start ==1

* This lets every dekad in the harvest month have the harvest anomaly
bysort `spatial_scale' year month: egen a_chirps = max(gs_anomaly) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_second_chirps = max(gs_second_anomaly) // max ignores the missing but sets all missing to missing 

bysort `spatial_scale' year month: egen a_mean_chirps = max(gs_mean) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_mean_second_chirps = max(gs_mean_second) // max ignores the missing but sets all missing to missing 

bysort `spatial_scale' year month: egen a_level_chirps = max(gs_level) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_level_second_chirps = max(gs_level_second) // max ignores the missing but sets all missing to missing 

bysort `spatial_scale' year month: egen a_sd_chirps = max(gs_sd) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_sd_second_chirps = max(gs_sd_second) // max ignores the missing but sets all missing to missing 

gen month_harvest = (a_chirps !=.)
gen month_second_harvest = (a_second_chirps !=.)
 
duplicates drop `spatial_scale' year month, force
gen month_index = ym(year, month)
drop year month dekad

tsset `spatial_scale' time_index

tsfill
sort `spatial_scale' month_index
 
* Fill the harvest value of the chirps anomaly for all months until the next harvest
bysort `spatial_scale' (month_index): carryforward a_chirps, gen(anomaly_chirps)
bysort `spatial_scale' (month_index): carryforward a_second_chirps, gen(anomaly_second_chirps)

bysort `spatial_scale' (month_index): carryforward a_mean_chirps, gen(mean_chirps)
bysort `spatial_scale' (month_index): carryforward a_mean_second_chirps, gen(mean_second_chirps)

bysort `spatial_scale' (month_index): carryforward a_level_chirps, gen(level_chirps)
bysort `spatial_scale' (month_index): carryforward a_level_second_chirps, gen(level_second_chirps)

bysort `spatial_scale' (month_index): carryforward a_sd_chirps, gen(sd_chirps)
bysort `spatial_scale' (month_index): carryforward a_sd_second_chirps, gen(sd_second_chirps)

bysort `spatial_scale' (month_index): carryforward dry_spell_growing, gen(dry_spell_chirps)
bysort `spatial_scale' (month_index): carryforward dry_spell_second_growing, gen(dry_spell_second_chirps)

gen month_year = dofm(month_index)
gen month = month(month_year)
gen year = year(month_year)
 
if "`spatial_scale'" =="national" {
	preserve
	keep if  month_harvest ==1
	keep anomaly_chirps dry_spell_chirps year 
	sort year
	save "./Processed_Data/Country/`country_name'/National_Estimates/chirps_national_series.dta", replace
	restore
}

keep `spatial_scale' year month anomaly_chirps anomaly_second_chirps mean_chirps mean_second_chirps level_chirps level_second_chirps sd_chirps sd_second_chirps dry_spell_chirps dry_spell_second_chirps previous_* month_harvest month_second_harvest prev_*

local shock "anomaly_chirps anomaly_second_chirps mean_chirps mean_second_chirps level_chirps level_second_chirps sd_chirps sd_second_chirps  dry_spell_chirps dry_spell_second_chirps previous_month_rf previous_3month_rf previous_3month_a_rf previous_6month_rf previous_6month_a_rf previous_year_rf previous_year_a_rf month_harvest month_second_harvest prev_m4to6_rf prev_m4to6_a_rf prev_m7to9_rf prev_m7to9_a_rf"
foreach s of local shock {
       rename `s' `s'_`spatial_scale'
        }
				
rename month int_month
rename year int_year

duplicates drop `spatial_scale'  int_month int_year, force

sort `spatial_scale' int_year int_month
merge 1:1 `spatial_scale' int_year int_month using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_`spatial_scale'_merge.dta"

preserve
keep if int_month==1 
keep `spatial_scale' anomaly_chirps_`spatial_scale' dry_spell_chirps int_year int_month `hh_lat' `hh_lon'
save "./Processed_Data/Country/Pooled/`country_name'_chirps`radius'.dta", replace
restore

keep if _m ==3
drop _m 

* save file in folder 
duplicates drop `spatial_scale'  int_month int_year, force
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/chirps/chirps_final/merged_`spatial_scale'_chirps.dta", replace

} 
end





