* Do File version

* Inputs: 
* a) For a given country, household survey data (ideally for multiple rounds)
* b) For a given country remote sensed data (grids with location coordinations)

* Outputs: 
* 1) Distance matrix 
	 
cap program define hh_distance
args country_name survey hh_lat hh_lon maximum_distance hazard1 hazard2 hazard3 hazard4 hazard5 hazard6 hazard7 ndvi_available wrsi_available wrsi2_available   spei3_available chirps_available swi_available temper_available rainy_season_available

local hazard "`hazard1' `hazard2' `hazard3' `hazard4' `hazard5' `hazard6' `hazard7'"

cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard/" 
cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard/distance_matrix/" 

* Load the location id for the given country
use "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_location_merge", clear
  
* save temp file for hh location
sort location
tempfile hh_loc
save "`hh_loc'"

* use the remote-sensed gridded data 
use "./Processed_Data/Country/`country_name'/Remote_Sensed/remote_gridded_location"

* * save temp file for grid location
tempfile grid_loc
save "`grid_loc'"

* Use geonear to identify all grids with centroids within a `maximum distance' km radius from a hh
use "`hh_loc'", clear
geonear location `hh_lat' `hh_lon' using "`grid_loc'", n(uniqid lat lon) within(`maximum_distance') near(0) long ellipsoid  

* save the distance matrix 
sort uniqid
save "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard/distance_matrix/distance_matrix", replace

local stage "growing harvest growing_second harvest_second"
foreach s of local stage {
preserve	
merge m:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/`s'_start.dta" 
drop _m
collapse (median) dekad, by(location) 
replace dekad = floor(dekad)
gen `s'_start = 1
gen month = ceil(dekad/3)
sort location dekad
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/`s'_start_location.dta", replace
restore
}

if "`ndvi_available'" == "Yes" & "`rainy_season_available'" == "Yes" {
 
preserve	
merge m:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/rs_dates.dta" 
drop _m
collapse (median) rs_* rs2_*, by(location) 

local rs_vars "rs_start_dekad rs_end_dekad rs2_start_dekad rs2_end_dekad rs_start_month rs_end_month rs2_start_month rs2_end_month"
foreach var of local rs_vars{
replace `var' = floor(`var')
}
sort location
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/rs_dates_location.dta", replace
 
/*
local stage "rs_start rs_end rs2_start rs2_end"
foreach s of local stage {
preserve	
merge m:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/`s'.dta" 
drop _m
collapse (median) dekad, by(location) 
replace dekad = floor(dekad)
gen `s'_start = 1
gen month = ceil(dekad/3)
sort location dekad
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/`s'_location.dta", replace
*/
restore
}


preserve
merge m:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/aez.dta" 
drop _m

replace aez_c = "missing" if aez_c ==""
replace aez_b = 100 if aez_b ==.
bysort location: egen mode_aez_b = mode(aez_b), missing minmode
collapse (median) mode_aez_b , by(location)
rename mode_aez_b aez_band 
drop if location ==.
merge 1:m location using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_location_merge"
drop _m
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/aez_location.dta", replace
restore

preserve
merge m:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/livelihood.dta" 
drop _m

replace lev1 = "missing" if lev1 ==""
replace lev_1 = 100 if lev_1 ==.
bysort location: egen mode_lev_1 = mode(lev_1), missing minmode
collapse (median) mode_lev_1 , by(location)
rename mode_lev_1 lev_1_2016
drop if location ==.
merge 1:m location using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_location_merge"
drop _m
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/livelihood_location.dta", replace
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/livelihood_location_`maximum_distance'.dta", replace
restore
 
preserve
merge m:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/ttm.dta" 
drop _m

collapse (median) ttm* , by(location)
drop if location ==.
merge 1:m location using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_location_merge"
drop _m
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/ttm_location.dta", replace
restore

foreach h of local hazard {
   if ("``h'_available'" == "Yes" )  {  
preserve
cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard/`h'/" 
* Merge with hazards
sort uniqid
merge m:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/`h'"
keep if _m ==3
drop _m 
save "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard/`h'/hh_location_`h'", replace 
restore
}
}

use "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_location_merge", clear
duplicates drop location `hh_lat' `hh_lon', force
sort location 
save "./Processed_Data/Country/`country_name'/Remote_Sensed/location_lat_lon.dta", replace
save "./Processed_Data/Country/`country_name'/Remote_Sensed/location_lat_lon_`maximum_distance'.dta", replace

use  "./Processed_Data/Country/`country_name'/Remote_Sensed/growing_start_location.dta", clear
sort location
drop growing_start
rename dekad sos
merge 1:1 location using "./Processed_Data/Country/`country_name'/Remote_Sensed/location_lat_lon.dta"
drop _merge
save "./Processed_Data/Country/`country_name'/Remote_Sensed/sos.dta", replace
save "./Processed_Data/Country/`country_name'/Remote_Sensed/sos_`maximum_distance'.dta", replace

use  "./Processed_Data/Country/`country_name'/Remote_Sensed/harvest_start_location.dta", clear
sort location
rename dekad soh
merge 1:1 location using "./Processed_Data/Country/`country_name'/Remote_Sensed/location_lat_lon.dta"
drop _merge
save "./Processed_Data/Country/`country_name'/Remote_Sensed/soh.dta", replace
save "./Processed_Data/Country/`country_name'/Remote_Sensed/soh_`maximum_distance'.dta", replace

use "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard/distance_matrix/distance_matrix", clear
bysort location: egen dist_rank = rank(km_to_uniqid), track
keep if dist_rank==1
keep location uniqid 
duplicates drop location, force
merge 1:1 location using "./Processed_Data/Country/`country_name'/Remote_Sensed/location_lat_lon.dta"
drop _merge
save "./Processed_Data/Country/`country_name'/Remote_Sensed/loc_uniqid_rank.dta", replace
save "./Processed_Data/Country/`country_name'/Remote_Sensed/loc_uniqid_rank_`maximum_distance'.dta", replace

end