* Do File version

* Inputs: 
* a) For a given country, household survey data (ideally for multiple rounds)
* b) For a given country remote sensed data (grids with location coordinations)

* Outputs: 
* 1) Distance matrix for every admin 1 area (this is to lower the computational burden by dividing the data)
	 
cap program define hh_distance
args country_name survey hh_lat hh_lon maximum_distance hazard1 hazard2 hazard3 hazard4 hazard5 hazard6 hazard7 ndvi_available wrsi_available wrsi2_available   spei3_available chirps_available swi_available  temper_available

local hazard "`hazard1' `hazard2' `hazard3' `hazard4' `hazard5' `hazard6' `hazard7'"

cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard/" 
cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard/distance_matrix/" 

* Load the location id for the given country
use "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_location_merge", clear
  
* save temp file for hh location
sort location
tempfile hh_loc
save "`hh_loc'"

* use the remote-sensed gridded data 
use "./Processed_Data/Country/`country_name'/Remote_Sensed/remote_gridded_location"

* * save temp file for grid location
tempfile grid_loc
save "`grid_loc'"

* Use geonear to identify all grids with centroids within a `maximum distance' km radius from a hh
use "`hh_loc'", clear
geonear location `hh_lat' `hh_lon' using "`grid_loc'", n(uniqid lat lon) within(`maximum_distance') near(0) long ellipsoid  

* save the distance matrix 
sort uniqid
save "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard/distance_matrix/distance_matrix", replace

local stage "growing harvest growing_second harvest_second"
foreach s of local stage {
preserve	
merge m:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/`s'_start.dta" 
drop _m
collapse (median) dekad, by(location)
gen `s'_start = 1
gen month = ceil(dekad/3)
sort location dekad
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/`s'_start_location.dta", replace
restore
}

preserve
merge m:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/aez.dta" 
drop _m

replace aez_c = "missing" if aez_c ==""
replace aez_b = 100 if aez_b ==.
bysort location: egen mode_aez_b = mode(aez_b), missing minmode
collapse (median) mode_aez_b , by(location)
rename mode_aez_b aez_band 
drop if location ==.
merge 1:m location using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_location_merge"
drop _m
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/aez_location.dta", replace
restore

preserve
merge m:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/livelihood.dta" 
drop _m

replace lev1 = "missing" if lev1 ==""
replace lev_1 = 100 if lev_1 ==.
bysort location: egen mode_lev_1 = mode(lev_1), missing minmode
collapse (median) mode_lev_1 , by(location)
rename mode_lev_1 lev_1_2016
drop if location ==.
merge 1:m location using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_location_merge"
drop _m
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/livelihood_location.dta", replace
restore
 
preserve
merge m:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/ttm.dta" 
drop _m

collapse (median) ttm* , by(location)
drop if location ==.
merge 1:m location using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_location_merge"
drop _m
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/ttm_location.dta", replace
restore

foreach h of local hazard {
   if ("``h'_available'" == "Yes" )  {  
preserve
cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard/`h'/" 
* Merge with hazards
sort uniqid
merge m:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/`h'"
keep if _m ==3
drop _m 
save "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard/`h'/hh_location_`h'", replace 
restore
}
}

end