* Do File version

* Inputs: 
* Spatially averaged ndvi measure time series for every hh
 
* Outputs: 
* 1) single time series of the spatially averaged hazard measure constructed as an event for every household 

cap program define hh_ndvi_time_series 
args country_name spatial_scale ndvi_available radius hh_lat hh_lon

if "`ndvi_available'" == "Yes" {

* This should be a Do file with a list of mkdir commands to create the folder structure
cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/ndvi/ndvi_final/" 

use   "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/ndvi/averaged_`spatial_scale'_ndvi.dta", clear

quietly {
reshape long yd_, i(`spatial_scale') j(time) string
}

rename yd_ y

* separate the time variable into year month dekad  
gen year1 = substr(time,1,4) 
gen year = real(year1)
gen dekad1 = substr(time,5,2) 
gen dekad = real(dekad1)

* Merge year dekad dataset
merge 1:1 `spatial_scale' year dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/`spatial_scale'_year_dekad"
replace y = 0 if _m ==2
drop _m

* create a time index and set as panel data
sort `spatial_scale' year dekad
bysort `spatial_scale': gen time_index = _n


tsset `spatial_scale' time_index
gen previous_month_ndvi = L.y + L2.y + L3.y
gen previous_3month_ndvi = L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y
gen previous_5month_ndvi = L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y + L10.y + L11.y + L12.y + L13.y + L14.y + L15.y 
gen prev_5month_lag_ndvi = L37.y + L38.y + L39.y + L40.y + L41.y + L42.y + L43.y + L44.y + L45.y + L46.y + L47.y + L48.y + L49.y + L50.y + L51.y 
gen previous_6month_ndvi = L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y + L10.y + L11.y + L12.y + L13.y + L14.y + ///
L15.y + L16.y + L17.y + L18.y
gen previous_7month_ndvi = L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y + L10.y + L11.y + L12.y + L13.y + L14.y + ///
L15.y + L16.y + L17.y + L18.y + L19.y + L20.y + L21.y
gen previous_year_ndvi = L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y + L10.y + L11.y + L12.y + L13.y + L14.y + ///
L15.y + L16.y + L17.y + L18.y + L19.y + L20.y + L21.y + L22.y + L23.y + L24.y + L25.y + L26.y + L27.y + L28.y + L29.y + L30.y + L31.y + L32.y + L33.y + L34.y + L35.y + L36.y

gen prev_m4to6_ndvi= L10.y + L11.y + L12.y + L13.y + L14.y + L15.y + L16.y + L17.y + L18.y

gen prev_m7to9_ndvi= L19.y + L20.y + L21.y + L22.y + L23.y + L24.y + L25.y + L26.y + L27.y

* Cumulative 3 month NDVI Anomaly (Last 9 dekads)
bysort `spatial_scale' dekad: egen previous_3month_a_ndvi = std(previous_3month_ndvi)

* Cumulative 5 month NDVI Anomaly (Last 15 dekads)
bysort `spatial_scale' dekad: egen previous_5month_a_ndvi = std(previous_5month_ndvi)

* Cumulative 5 month NDVI Anomaly (Prior 15 dekads one year ago)
bysort `spatial_scale' dekad: egen prev_5month_lag_a_ndvi = std(prev_5month_lag_ndvi)

* Cumulative 6 month NDVI Anomaly (Last 18 dekads)
bysort `spatial_scale' dekad: egen previous_6month_a_ndvi = std(previous_6month_ndvi)

* Cumulative 6 month NDVI Anomaly (Last 21 dekads)
bysort `spatial_scale' dekad: egen previous_7month_a_ndvi = std(previous_7month_ndvi)

* Cumulative Annual NDVI Anomaly (Last 36 dekads)
bysort `spatial_scale' dekad: egen previous_year_a_ndvi = std(previous_year_ndvi)

*Cumulative 3 month rainfall lagged (-2) quarter
bysort `spatial_scale' dekad: egen prev_m4to6_a_ndvi = std(prev_m4to6_ndvi) 

*Cumulative 3 month rainfall lagged (-3) quarter
bysort `spatial_scale' dekad: egen prev_m7to9_a_ndvi = std(prev_m7to9_ndvi)
	
gen month = ceil(dekad/3)
drop year1 time

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/harvest_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/growing_start_`spatial_scale'"
drop _m

tsset
* Generate a dummy that is one for the growing season, zero otherwise (this should be 6 dekads for a short rainy season)
gen growing_season = (growing_start ==1 | L.growing_start == 1 | L2.growing_start == 1 | L3.growing_start ==1 | L4.growing_start == 1 | L5.growing_start == 1 | L6.growing_start == 1 | L7.growing_start == 1 | L8.growing_start == 1)

* sum of the first 3 months of the growing season
* construct the hazard event 
* sum of the present and the following 8 dekads (could be the present and 5 dekads for the short rains)
tsset
gen tot_9_ndvi =  y + F.y + F2.y + F3.y + F4.y + F5.y + F6.y + F7.y + F8.y if growing_start ==1

* This is the standardized anomaly (Z-score) for the cumulative growing season ndvi
bysort `spatial_scale' dekad: egen std_tot_9_ndvi = std(tot_9_ndvi) if growing_start ==1

bysort `spatial_scale' dekad: egen mean_tot_9_ndvi = mean(tot_9_ndvi) if growing_start ==1
bysort `spatial_scale' dekad: egen sd_tot_9_ndvi = sd(tot_9_ndvi) if growing_start ==1
bysort `spatial_scale' dekad: gen level_tot_9_ndvi = tot_9_ndvi if growing_start ==1

* This zscore is used from one growing season until the next begins since all the values are missing and filled out 
bysort `spatial_scale' (time_index): carryforward std_tot_9_ndvi, gen(a_tot_9_ndvi)

bysort `spatial_scale' (time_index): carryforward mean_tot_9_ndvi, gen(a_mean_tot_9_ndvi)
bysort `spatial_scale' (time_index): carryforward sd_tot_9_ndvi, gen(a_sd_tot_9_ndvi)
bysort `spatial_scale' (time_index): carryforward level_tot_9_ndvi, gen(a_level_tot_9_ndvi)

* The harvest anomaly is defined at the harvest and missing for all other dekads
gen gs_ndvi_anomaly = a_tot_9_ndvi if harvest_start ==1

gen gs_ndvi_mean = a_mean_tot_9_ndvi if harvest_start ==1
gen gs_ndvi_sd = a_sd_tot_9_ndvi if harvest_start ==1
gen gs_ndvi_level = a_level_tot_9_ndvi if harvest_start ==1

* This lets every dekad in the harvest month have the harvest anomaly
bysort `spatial_scale' year month: egen a_ndvi = max(gs_ndvi_anomaly) // max ignores the missing but sets all missing to missing 

bysort `spatial_scale' year month: egen a_mean_ndvi = max(gs_ndvi_mean) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_sd_ndvi = max(gs_ndvi_sd) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_level_ndvi = max(gs_ndvi_level) // max ignores the missing but sets all missing to missing 

gen month_harvest = (a_ndvi !=.)

duplicates drop `spatial_scale' year month, force
gen month_index = ym(year, month)
drop year month dekad

tsset `spatial_scale' time_index

tsfill
sort `spatial_scale' month_index
 
* Fill the harvest value of the ndvi anomaly for all months until the next harvest
bysort `spatial_scale' (month_index): carryforward a_ndvi, gen(anomaly_ndvi)

bysort `spatial_scale' (month_index): carryforward a_mean_ndvi, gen(mean_ndvi)
bysort `spatial_scale' (month_index): carryforward a_level_ndvi, gen(level_ndvi)
bysort `spatial_scale' (month_index): carryforward a_sd_ndvi, gen(sd_ndvi)

gen month_year = dofm(month_index)
gen month = month(month_year)
gen year = year(month_year)

if "`spatial_scale'" =="national" {
	preserve
	keep if  month_harvest ==1
	keep anomaly_ndvi year 
	sort year
	save "./Processed_Data/Country/`country_name'/National_Estimates/ndvi_national_series.dta", replace
	restore
}


keep `spatial_scale' year month anomaly_ndvi mean_ndvi level_ndvi sd_ndvi previous* prev_*

local shock "anomaly_ndvi mean_ndvi sd_ndvi level_ndvi  previous_month_ndvi previous_3month_ndvi previous_3month_a_ndvi previous_6month_ndvi previous_6month_a_ndvi previous_5month_ndvi previous_5month_a_ndvi prev_5month_lag_ndvi prev_5month_lag_a_ndvi previous_7month_ndvi previous_7month_a_ndvi previous_year_ndvi previous_year_a_ndvi prev_m4to6_ndvi prev_m4to6_a_ndvi prev_m7to9_ndvi prev_m7to9_a_ndvi"
foreach s of local shock {
       rename `s' `s'_`spatial_scale'
        }

rename month int_month
rename year int_year
duplicates drop `spatial_scale'  int_month int_year, force
sort `spatial_scale' int_year int_month

sort `spatial_scale' int_year int_month

save "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/ndvi/ndvi_final/all_`spatial_scale'_ndvi.dta", replace

merge 1:1 `spatial_scale' int_year int_month using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_`spatial_scale'_merge.dta"

preserve
keep if int_month==1 
keep `spatial_scale' anomaly_ndvi_`spatial_scale' int_year int_month `hh_lat' `hh_lon'
save "./Processed_Data/Country/Pooled/`country_name'_ndvi`radius'.dta", replace
restore

keep if _m ==3
drop _m 

* save file in folder 
duplicates drop `spatial_scale'  int_month int_year, force
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/ndvi/ndvi_final/merged_`spatial_scale'_ndvi.dta", replace

}
 
end





