* Do File version

* Inputs: 
* Spatially averaged spei3 measure time series for every hh
 
* Outputs: 
* 1) single time series of the spatially averaged hazard measure constructed as an event for every household 

cap program define hh_spei3_time_series 
args country_name spatial_scale spei3_available radius hh_lat hh_lon

if "`spei3_available'" == "Yes" {

* This should be a Do file with a list of mkdir commands to create the folder structure
cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/spei3/spei3_final/" 

use   "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/spei3/averaged_`spatial_scale'_spei3.dta", clear

quietly {
reshape long yd_, i(`spatial_scale') j(time) string
}

rename yd_ y

* separate the time variable into year month dekad  
gen year1 = substr(time,1,4) 
gen year = real(year1)
gen dekad1 = substr(time,5,2) 
gen dekad = real(dekad1)

* Merge year dekad dataset
merge 1:1 `spatial_scale' year dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/`spatial_scale'_year_dekad"
replace y = 0 if _m ==2
drop _m

* create a time index and set as panel data
sort `spatial_scale' year dekad
bysort `spatial_scale': gen time_index = _n

tsset `spatial_scale' time_index

gen month = ceil(dekad/3)
drop year1 time

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/harvest_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/growing_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/harvest_second_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/growing_second_start_`spatial_scale'"
drop _m

tsset
* Generate a dummy that is one for the growing season, zero otherwise (this should be 6 dekads for a short rainy season)
gen growing_season = (growing_start ==1 | L.growing_start == 1 | L2.growing_start == 1 | L3.growing_start ==1 | L4.growing_start == 1 | L5.growing_start == 1 | L6.growing_start == 1 | L7.growing_start == 1 | L8.growing_start == 1)
gen growing_second_season = (growing_second_start ==1 | L.growing_second_start == 1 | L2.growing_second_start == 1 | L3.growing_second_start ==1 | L4.growing_second_start == 1 | L5.growing_second_start == 1)

* sum of the first 3 months of the growing season
* construct the hazard event 
* sum of the present and the following 8 dekads (could be the present and 5 dekads for the short rains)
tsset
* This will select the value that is 8, 9 or 10 dekads ahead (the data ensures it is only one)
gen tot_9_spei3 =   F7.y + F8.y + F9.y if growing_start ==1
* This will select the value that is 4, 5 or 6 dekads ahead (the data ensures it is only one)
gen tot_9_spei3_second =   F4.y + F5.y + F6.y if growing_second_start ==1

* This is the standardized anomaly (Z-score) for the cumulative growing season rainfall

bysort `spatial_scale' dekad : egen std_tot_9_spei3 =  std(tot_9_spei3) if growing_start ==1
bysort `spatial_scale' dekad : egen std_tot_9_spei3_second =  std(tot_9_spei3_second)  if growing_second_start ==1

* This zscore is used from one growing season until the next begins since all the values are missing and filled out 
bysort `spatial_scale' (time_index): carryforward std_tot_9_spei3, gen(a_tot_9_spei3)
bysort `spatial_scale' (time_index): carryforward std_tot_9_spei3_second, gen(a_tot_9_spei3_second)

* The harvest anomaly is defined at the harvest and missing for all other dekads
gen gs_spei3_anomaly = a_tot_9_spei3 if harvest_start ==1
gen gs_spei3_anomaly_second = a_tot_9_spei3_second if harvest_second_start ==1

* This lets every dekad in the harvest month have the harvest anomaly
bysort `spatial_scale' year month: egen a_spei3 = max(gs_spei3_anomaly) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_spei3_second = max(gs_spei3_anomaly_second) // max ignores the missing but sets all missing to missing 


gen month_harvest = (a_spei3 !=.)

duplicates drop `spatial_scale' year month, force
gen month_index = ym(year, month)
drop year month dekad

tsset `spatial_scale' time_index

tsfill
sort `spatial_scale' month_index
 
* Fill the harvest value of the spei3 anomaly for all months until the next harvest
bysort `spatial_scale' (month_index): carryforward a_spei3, gen(anomaly_spei3)
bysort `spatial_scale' (month_index): carryforward a_spei3_second, gen(anomaly_spei3_second)

gen month_year = dofm(month_index)
gen month = month(month_year)
gen year = year(month_year)

if "`spatial_scale'" =="national" {
	preserve
	keep if  month_harvest ==1
	keep anomaly_spei3 year 
	sort year
	save "./Processed_Data/Country/`country_name'/National_Estimates/spei3_national_series.dta", replace
	restore
}


keep `spatial_scale' year month anomaly_spei3  anomaly_spei3_second
rename anomaly_spei3 anomaly_spei3_`spatial_scale'
rename anomaly_spei3_second anomaly_spei3_second_`spatial_scale'

rename month int_month
rename year int_year
duplicates drop `spatial_scale'  int_month int_year, force
sort `spatial_scale' int_year int_month
merge 1:1 `spatial_scale' int_year int_month using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_`spatial_scale'_merge.dta"

preserve
keep if int_month==1 
keep `spatial_scale' anomaly_spei3_`spatial_scale' int_year int_month `hh_lat' `hh_lon'
save "./Processed_Data/Country/Pooled/`country_name'_spei3`radius'.dta", replace
restore

keep if _m ==3
drop _m 

* save file in folder 
duplicates drop `spatial_scale'  int_month int_year, force
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/spei3/spei3_final/merged_`spatial_scale'_spei3.dta", replace

}
 
end





