* Do File version

* Inputs: 
* Spatially averaged swi measure time series for every hh
 
* Outputs: 
* 1) single time series of the spatially averaged hazard measure constructed as an event for every household 

cap program define hh_swi_time_series 
* The arguments are the country_name and the name of a spatially averaged hazard data set
args country_name spatial_scale swi_available radius hh_lat hh_lon

if "`swi_available'" == "Yes" {

* This should be a Do file with a list of mkdir commands to create the folder structure

cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/swi/swi_final/" 

use   "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/swi/averaged_`spatial_scale'_swi.dta", clear

quietly {
reshape long yd_, i(`spatial_scale') j(time) string
}

rename yd_ y

* separate the time variable into year month dekad and radius
gen year1 = substr(time,1,4) 
gen year = real(year1)
gen dekad1 = substr(time,5,2) 
gen dekad = real(dekad1)
gen month = ceil(dekad/3)
drop year1 time

* Save dataset with year dekad to be used by NDVI and WRSI
preserve
keep `spatial_scale' year dekad
sort `spatial_scale' year dekad
merge 1:1 `spatial_scale' year dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/`spatial_scale'_year_dekad"
restore

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/harvest_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/growing_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/harvest_second_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/growing_second_start_`spatial_scale'"
drop _m

* create a time index and set as panel data
sort `spatial_scale' year dekad
bysort `spatial_scale': gen time_index = _n

tsset `spatial_scale' time_index


gen previous_month_swi = L.y + L2.y + L3.y
gen previous_3month_swi = L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y
gen previous_5month_swi = L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y + L10.y + L11.y + L12.y + L13.y + L14.y + L15.y 
gen previous_6month_swi = L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y + L10.y + L11.y + L12.y + L13.y + L14.y + ///
L15.y + L16.y + L17.y + L18.y
gen previous_year_swi = L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y + L10.y + L11.y + L12.y + L13.y + L14.y + ///
L15.y + L16.y + L17.y + L18.y + L19.y + L20.y + L21.y + L22.y + L23.y + L24.y + L25.y + L26.y + L27.y + L28.y + L29.y + L30.y + L31.y + L32.y + L33.y + L34.y + L35.y + L36.y

* Cumulative 3 month Soil Moisture Anomaly (Last 9 dekads)
bysort `spatial_scale' dekad: egen previous_3month_a_swi = std(previous_3month_swi)

* Cumulative 5 monthl Soil Moisture Anomaly (Last 18 dekads)
bysort `spatial_scale' dekad: egen previous_5month_a_swi = std(previous_5month_swi)

* Cumulative 6 monthl Soil Moisture Anomaly (Last 18 dekads)
bysort `spatial_scale' dekad: egen previous_6month_a_swi = std(previous_6month_swi)

* Cumulative Annual Soil Moisture Anomaly (Last 36 dekads)
bysort `spatial_scale' dekad: egen previous_year_a_swi = std(previous_year_swi)

* Generate a dummy that is one for the growing season, zero otherwise 
tsset
gen growing_season = (growing_start ==1 | L.growing_start == 1 | L2.growing_start == 1 | L3.growing_start ==1 | L4.growing_start == 1 | L5.growing_start == 1 | L6.growing_start == 1 | L7.growing_start == 1 | L8.growing_start == 1)
gen growing_second_season = (growing_second_start ==1 | L.growing_second_start == 1 | L2.growing_second_start == 1 | L3.growing_second_start ==1 | L4.growing_second_start == 1 | L5.growing_second_start == 1)

* construct the hazard event 
* sum of the present and the following 8 dekads (current and following 5 dekads for the short rains)
tsset
gen tot_9_swi =  y + F.y + F2.y + F3.y + F4.y + F5.y + F6.y + F7.y + F8.y if growing_start ==1

tsset
gen dek_9_swi = F8.y if growing_start ==1

tsset
gen tot_6_second_swi =  y + F.y + F2.y + F3.y + F4.y + F5.y if growing_second_start ==1

* This is the standardized anomaly (Z-score) for the cumulative growing season Soil Moisture
bysort `spatial_scale': egen std_tot_9_swi = std(tot_9_swi) if growing_start ==1
bysort `spatial_scale': egen std_tot_6_second_swi = std(tot_6_second_swi) if growing_second_start ==1
bysort `spatial_scale': egen std_dek_9_swi = std(dek_9_swi) if growing_start ==1

* This is the mean for the cumulative growing season Soil Moisture
bysort `spatial_scale':  egen mean_tot_9_swi = mean(tot_9_swi) if growing_start ==1
bysort `spatial_scale':  egen mean_tot_6_second_swi = mean(tot_6_second_swi) if growing_second_start ==1
bysort `spatial_scale':  egen mean_dek_9_swi = mean(dek_9_swi) if growing_start ==1

* This is the sd for the cumulative growing season Soil Moisture
bysort `spatial_scale':  egen sd_tot_9_swi = sd(tot_9_swi) if growing_start ==1
bysort `spatial_scale':  egen sd_tot_6_second_swi = sd(tot_6_second_swi) if growing_second_start ==1
bysort `spatial_scale':  egen sd_dek_9_swi = sd(dek_9_swi) if growing_start ==1

* This is the level for the cumulative growing season Soil Moisture
bysort `spatial_scale': gen level_tot_9_swi = tot_9_swi if growing_start ==1
bysort `spatial_scale':  gen level_tot_6_second_swi = tot_6_second_swi if growing_second_start ==1
bysort `spatial_scale': gen level_dek_9_swi = dek_9_swi if growing_start ==1

* This zscore is used from one growing season until the next begins since all the values are missing and filled out 
bysort `spatial_scale' (time_index): carryforward std_tot_9_swi, gen(a_tot_9_swi)
bysort `spatial_scale' (time_index): carryforward std_tot_6_second_swi, gen(a_tot_6_second_swi)
bysort `spatial_scale' (time_index): carryforward std_dek_9_swi, gen(a_dek_9_swi)

* Same for level, sd and mean
bysort `spatial_scale' (time_index): carryforward mean_tot_9_swi, gen(a_mean_tot_9_swi)
bysort `spatial_scale' (time_index): carryforward mean_tot_6_second_swi, gen(a_mean_tot_6_second_swi)
bysort `spatial_scale' (time_index): carryforward mean_dek_9_swi, gen(a_mean_dek_9_swi)

bysort `spatial_scale' (time_index): carryforward level_tot_9_swi, gen(a_level_tot_9_swi)
bysort `spatial_scale' (time_index): carryforward level_tot_6_second_swi, gen(a_level_tot_6_second_swi)
bysort `spatial_scale' (time_index): carryforward level_dek_9_swi, gen(a_level_dek_9_swi)

bysort `spatial_scale' (time_index): carryforward sd_tot_9_swi, gen(a_sd_tot_9_swi)
bysort `spatial_scale' (time_index): carryforward sd_tot_6_second_swi, gen(a_sd_tot_6_second_swi)
bysort `spatial_scale' (time_index): carryforward sd_dek_9_swi, gen(a_sd_dek_9_swi)

* The harvest anomaly is defined at the harvest and missing for all other dekads
gen gs_anomaly = a_tot_9_swi if harvest_start ==1
gen gs_second_anomaly = a_tot_6_second_swi if harvest_second_start ==1
gen dek9_anomaly = a_dek_9_swi if harvest_start ==1

* Same for level, mean and sd
gen gs_mean = a_mean_tot_9_swi if harvest_start ==1
gen gs_mean_second = a_mean_tot_6_second_swi if harvest_second_start ==1
gen dek9_mean = a_mean_dek_9_swi if harvest_start ==1

gen gs_level = a_level_tot_9_swi if harvest_start ==1
gen gs_level_second = a_level_tot_6_second_swi if harvest_second_start ==1
gen dek9_level = a_level_dek_9_swi if harvest_start ==1

gen gs_sd = a_sd_tot_9_swi if harvest_start ==1
gen gs_sd_second = a_sd_tot_6_second_swi if harvest_second_start ==1
gen dek9_sd = a_sd_dek_9_swi if harvest_start ==1

* This lets every dekad in the harvest month have the harvest anomaly
bysort `spatial_scale' year month: egen a_swi = max(gs_anomaly) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_second_swi = max(gs_second_anomaly) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_d9_swi = max(dek9_anomaly) // max ignores the missing but sets all missing to missing 

bysort `spatial_scale' year month: egen a_mean_swi = max(gs_mean) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_mean_second_swi = max(gs_mean_second) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_mean_d9_swi = max(dek9_mean) // max ignores the missing but sets all missing to missing

bysort `spatial_scale' year month: egen a_level_swi = max(gs_level) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_level_second_swi = max(gs_level_second) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_level_d9_swi = max(dek9_level) // max ignores the missing but sets all missing to missing 

bysort `spatial_scale' year month: egen a_sd_swi = max(gs_sd) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_sd_second_swi = max(gs_sd_second) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_sd_d9_swi = max(dek9_sd) // max ignores the missing but sets all missing to missing 

gen month_harvest = (a_swi !=.)
 
duplicates drop `spatial_scale' year month, force
gen month_index = ym(year, month)
drop year month dekad

tsset `spatial_scale' time_index

tsfill
sort `spatial_scale' month_index
 
* Fill the harvest value of the swi anomaly for all months until the next harvest
bysort `spatial_scale' (month_index): carryforward a_swi, gen(anomaly_swi)
bysort `spatial_scale' (month_index): carryforward a_second_swi, gen(anomaly_second_swi)
bysort `spatial_scale' (month_index): carryforward a_d9_swi, gen(anomaly_dek9_swi)

bysort `spatial_scale' (month_index): carryforward a_mean_swi, gen(mean_swi)
bysort `spatial_scale' (month_index): carryforward a_mean_second_swi, gen(mean_second_swi)
bysort `spatial_scale' (month_index): carryforward a_mean_d9_swi, gen(mean_dek9_swi)

bysort `spatial_scale' (month_index): carryforward a_level_swi, gen(level_swi)
bysort `spatial_scale' (month_index): carryforward a_level_second_swi, gen(level_second_swi)
bysort `spatial_scale' (month_index): carryforward a_level_d9_swi, gen(level_dek9_swi)

bysort `spatial_scale' (month_index): carryforward a_sd_swi, gen(sd_swi)
bysort `spatial_scale' (month_index): carryforward a_sd_second_swi, gen(sd_second_swi)
bysort `spatial_scale' (month_index): carryforward a_sd_d9_swi, gen(sd_dek9_swi)

gen month_year = dofm(month_index)
gen month = month(month_year)
gen year = year(month_year)
 
if "`spatial_scale'" =="national" {
	preserve
	keep if  month_harvest ==1
	keep anomaly_swi level_swi anomaly_dek9_swi year 
	sort year
	save "./Processed_Data/Country/`country_name'/National_Estimates/swi_national_series.dta", replace
	restore
}

keep `spatial_scale' year month anomaly_swi anomaly_second_swi anomaly_dek9_swi mean_swi mean_second_swi mean_dek9_swi level_swi level_second_swi level_dek9_swi sd_swi sd_second_swi sd_dek9_swi previous_* 

local shock "anomaly_swi anomaly_second_swi mean_swi anomaly_dek9_swi mean_second_swi level_swi level_second_swi level_dek9_swi sd_swi sd_second_swi sd_dek9_swi  previous_month_swi previous_3month_swi previous_3month_a_swi previous_6month_swi previous_6month_a_swi previous_5month_swi previous_5month_a_swi previous_year_swi previous_year_a_swi"
foreach s of local shock {
       rename `s' `s'_`spatial_scale'
        }
				
rename month int_month
rename year int_year

duplicates drop `spatial_scale'  int_month int_year, force

sort `spatial_scale' int_year int_month

save "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/swi/swi_final/all_`spatial_scale'_swi.dta", replace

merge 1:1 `spatial_scale' int_year int_month using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_`spatial_scale'_merge.dta"

preserve
keep if int_month==1 
keep `spatial_scale' anomaly_swi_`spatial_scale' int_year int_month `hh_lat' `hh_lon'
save "./Processed_Data/Country/Pooled/`country_name'_swi`radius'.dta", replace
restore

keep if _m ==3
drop _m 

* save file in folder 
duplicates drop `spatial_scale'  int_month int_year, force
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/swi/swi_final/merged_`spatial_scale'_swi.dta", replace

} 
end





