* Do File version

* Inputs: 
* Spatially averaged temperature measure time series for every hh
 
* Outputs: 
* 1) single time series of the spatially averaged hazard measure constructed as an event for every household 

cap program define hh_temper_time_series 
args country_name spatial_scale temper_available

if "`temper_available'" == "Yes" {

* This should be a Do file with a list of mkdir commands to create the folder structure
cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/temper/" 
cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/temper/temper_final/" 

use   "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/temper/averaged_`spatial_scale'_temper.dta", clear

quietly {
reshape long yd_, i(`spatial_scale') j(time) string
}

rename yd_ y

* separate the time variable into year month dekad  
gen year1 = substr(time,1,4) 
gen year = real(year1)
gen dekad1 = substr(time,5,2) 
gen dekad = real(dekad1)

* Merge year dekad dataset
merge 1:1 `spatial_scale' year dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/`spatial_scale'_year_dekad"
replace y = 0 if _m ==2
drop _m

* create a time index and set as panel data
sort `spatial_scale' year dekad
bysort `spatial_scale': gen time_index = _n


tsset `spatial_scale' time_index
gen prev_month_temp = L.y + L2.y + L3.y
gen prev_3month_av_temp = (L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y)/3
gen prev_6month_av_temp = (L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y + L10.y + L11.y + L12.y + L13.y + L14.y + ///
L15.y + L16.y + L17.y + L18.y)/6
gen prev_year_av_temp = (L.y + L2.y + L3.y + L4.y + L5.y + L6.y + L7.y + L8.y + L9.y + L10.y + L11.y + L12.y + L13.y + L14.y + ///
L15.y + L16.y + L17.y + L18.y + L19.y + L20.y + L21.y + L22.y + L23.y + L24.y + L25.y + L26.y + L27.y + L28.y + L29.y + L30.y + L31.y + L32.y + L33.y + L34.y + L35.y + L36.y)/12

gen prev_m4to6_temp= (L10.y + L11.y + L12.y + L13.y + L14.y + L15.y + L16.y + L17.y + L18.y)/3

gen prev_m7to9_temp= (L19.y + L20.y + L21.y + L22.y + L23.y + L24.y + L25.y + L26.y + L27.y)/3

* Cumulative 3 month Temperature Anomaly (Last 9 dekads)
bysort `spatial_scale' dekad: egen prev_3month_a_temp = std(prev_3month_av_temp)

* Cumulative 6 month Temperature Anomaly (Last 18 dekads)
bysort `spatial_scale' dekad: egen prev_6month_a_temp = std(prev_6month_av_temp)

* Cumulative Annual Temperature Anomaly (Last 36 dekads)
bysort `spatial_scale' dekad: egen prev_year_a_temp = std(prev_year_av_temp)

*Cumulative 3 month rainfall lagged (-2) quarter
bysort `spatial_scale' dekad: egen prev_m4to6_a_temp = std(prev_m4to6_temp) 

*Cumulative 3 month rainfall lagged (-3) quarter
bysort `spatial_scale' dekad: egen prev_m7to9_a_temp = std(prev_m7to9_temp)
	
gen month = ceil(dekad/3)
drop year1 time

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/harvest_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/growing_start_`spatial_scale'"
drop _m

tsset
* Generate a dummy that is one for the growing season, zero otherwise (this should be 6 dekads for a short rainy season)
gen growing_season = (growing_start ==1 | L.growing_start == 1 | L2.growing_start == 1 | L3.growing_start ==1 | L4.growing_start == 1 | L5.growing_start == 1 | L6.growing_start == 1 | L7.growing_start == 1 | L8.growing_start == 1)

* sum of the first 3 months of the growing season
* construct the hazard event 
* sum of the present and the following 8 dekads (could be the present and 5 dekads for the short rains)
tsset
gen av_9_temp =  (y + F.y + F2.y + F3.y + F4.y + F5.y + F6.y + F7.y + F8.y)/3 if growing_start ==1

* This is the standardized anomaly (Z-score) for the cumulative growing season rainfall
bysort `spatial_scale' dekad: egen std_av_9_temp = std(av_9_temp) if growing_start ==1

bysort `spatial_scale' dekad: egen mean_av_9_temp = mean(av_9_temp) if growing_start ==1
bysort `spatial_scale' dekad: egen sd_av_9_temp = sd(av_9_temp) if growing_start ==1
bysort `spatial_scale' dekad: gen level_av_9_temp = av_9_temp if growing_start ==1

* This zscore is used from one growing season until the next begins since all the values are missing and filled out 
bysort `spatial_scale' (time_index): carryforward std_av_9_temp, gen(a_av_9_temp)

bysort `spatial_scale' (time_index): carryforward mean_av_9_temp, gen(a_mean_av_9_temp)
bysort `spatial_scale' (time_index): carryforward sd_av_9_temp, gen(a_sd_av_9_temp)
bysort `spatial_scale' (time_index): carryforward level_av_9_temp, gen(a_level_av_9_temp)

* The harvest anomaly is defined at the harvest and missing for all other dekads
gen gs_temp_anomaly = a_av_9_temp if harvest_start ==1

gen gs_temp_mean = a_mean_av_9_temp if harvest_start ==1
gen gs_temp_sd = a_sd_av_9_temp if harvest_start ==1
gen gs_temp_level = a_level_av_9_temp if harvest_start ==1

* This lets every dekad in the harvest month have the harvest anomaly
bysort `spatial_scale' year month: egen a_temp = max(gs_temp_anomaly) // max ignores the missing but sets all missing to missing 

bysort `spatial_scale' year month: egen a_mean_temp = max(gs_temp_mean) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_sd_temp = max(gs_temp_sd) // max ignores the missing but sets all missing to missing 
bysort `spatial_scale' year month: egen a_level_temp = max(gs_temp_level) // max ignores the missing but sets all missing to missing 

gen month_harvest = (a_temp !=.)

duplicates drop `spatial_scale' year month, force
gen month_index = ym(year, month)
drop year month dekad

tsset `spatial_scale' time_index

tsfill
sort `spatial_scale' month_index
 
* Fill the harvest value of the temperature anomaly for all months until the next harvest
bysort `spatial_scale' (month_index): carryforward a_temp, gen(anomaly_temp)

bysort `spatial_scale' (month_index): carryforward a_mean_temp, gen(mean_temp)
bysort `spatial_scale' (month_index): carryforward a_level_temp, gen(level_temp)
bysort `spatial_scale' (month_index): carryforward a_sd_temp, gen(sd_temp)

gen month_year = dofm(month_index)
gen month = month(month_year)
gen year = year(month_year)

if "`spatial_scale'" =="national" {
	preserve
	keep if  month_harvest ==1
	keep anomaly_temp year 
	sort year
	save "./Processed_Data/Country/`country_name'/National_Estimates/temper_national_series.dta", replace
	restore
}


keep `spatial_scale' year month anomaly_temp mean_temp level_temp sd_temp prev*

local shock "anomaly_temp mean_temp sd_temp level_temp  prev_month_temp prev_3month_av_temp prev_3month_a_temp prev_6month_av_temp prev_6month_a_temp prev_year_av_temp prev_year_a_temp prev_m4to6_temp prev_m4to6_a_temp prev_m7to9_temp prev_m7to9_a_temp"
foreach s of local shock {
       rename `s' `s'_`spatial_scale'
        }
		
rename month int_month
rename year int_year
duplicates drop `spatial_scale'  int_month int_year, force
sort `spatial_scale' int_year int_month

sort `spatial_scale' int_year int_month
merge 1:1 `spatial_scale' int_year int_month using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_`spatial_scale'_merge.dta"
keep if _m ==3
drop _m 

* save file in folder 
duplicates drop `spatial_scale'  int_month int_year, force
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/temper/temper_final/merged_`spatial_scale'_temper.dta", replace

}
 
end





