* Do File version

* Inputs: 
* Spatially averaged wrsi2 measure time series for every hh
 
* Outputs: 
* 1) single time series of the spatially averaged hazard measure constructed as an event for every household 

cap program define hh_wrsi2_time_series 
args country_name spatial_scale wrsi2_available 

if "`wrsi2_available'" == "Yes" {

	
* This should be a Do file with a list of mkdir commands to create the folder structure
cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/wrsi2/wrsi2_final/" 

use   "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/wrsi2/averaged_`spatial_scale'_wrsi2.dta", clear

quietly {
reshape long yd_, i(`spatial_scale') j(time) string
}

rename yd_  y

* separate the time variable into year month dekad and radius
gen year1 = substr(time,1,4) 
gen year = real(year1)
gen dekad = real(substr(time,5,2)) 

* Merge year dekad dataset
merge 1:1 `spatial_scale' year dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/`spatial_scale'_year_dekad"
drop _m
drop if year ==2000

gen month = ceil(dekad/3)
drop year1 time

* create a time index and set as panel data
sort `spatial_scale' year dekad
bysort `spatial_scale': gen time_index = _n

tsset `spatial_scale' time_index
	
merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/harvest_second_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/growing_second_start_`spatial_scale'"
drop _m

tsset
gen wrsi2 = y if F.harvest_second_start ==1
replace wrsi2 = y if harvest_second_start ==1 & L.wrsi2==.
replace wrsi2 = y if F2.harvest_second_start ==1 & F.wrsi2 ==.
replace wrsi2 = y if F3.harvest_second_start ==1 & F2.wrsi2 ==.
replace wrsi2 = y if F4.harvest_second_start ==1 & F3.wrsi2 ==.
replace wrsi2 = y if L.harvest_second_start ==1 & (L5.wrsi2==. & L4.wrsi2 ==. & L3.wrsi2 ==. & L2.wrsi2 ==. & L.wrsi2==.)

* construct the hazard event 
bysort `spatial_scale' dekad: egen median_wrsi2 = median(wrsi2) if wrsi2 !=.

gen awrsi2 = wrsi2*100/median_wrsi2 

* This lets every dekad in the harvest_second month have the harvest_second anomaly
bysort `spatial_scale' year month: egen month_wrsi2 = max(wrsi2)
bysort `spatial_scale' year month: egen month_awrsi2 = max(awrsi2)

duplicates drop `spatial_scale' year month, force
gen month_index = ym(year, month)
drop year month dekad

tsset `spatial_scale' time_index
	
tsfill
sort `spatial_scale' month_index
 
* Fill the harvest_second value of the wrsi2 anomaly for all months until the next harvest_second
bysort `spatial_scale' (month_index): carryforward month_awrsi2, gen(anomaly_wrsi2)
bysort `spatial_scale' (month_index): carryforward month_wrsi2, gen(level_wrsi2)

tsset
gen last_cycle_wrsi2 = L12.level_wrsi2

gen month_year = dofm(month_index)
gen month = month(month_year)
gen year = year(month_year)

keep `spatial_scale' year month anomaly_wrsi2 level_wrsi2 last_cycle_wrsi2
rename anomaly_wrsi2 anomaly_wrsi2_`spatial_scale'
rename  level_wrsi2 level_wrsi2_`spatial_scale'
rename last_cycle_wrsi2 last_cycle_wrsi2_`spatial_scale'

rename month int_month
rename year int_year
duplicates drop `spatial_scale' int_year int_month,force

sort `spatial_scale' int_year int_month
merge 1:1 `spatial_scale' int_year int_month using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_`spatial_scale'_merge.dta"
keep if _m ==3
drop _m 

* save file in folder 
duplicates drop `spatial_scale'  int_month int_year, force
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/wrsi2/wrsi2_final/merged_`spatial_scale'_wrsi2.dta", replace

}

end





