* Do File version

* Inputs: 
* Spatially averaged wrsi measure time series for every hh
 
* Outputs: 
* 1) single time series of the spatially averaged hazard measure constructed as an event for every household 

cap program define hh_wrsi_time_series 
args country_name  spatial_scale wrsi_available  radius hh_lat hh_lon

if "`wrsi_available'" == "Yes" {

	
* This should be a Do file with a list of mkdir commands to create the folder structure
cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/wrsi/wrsi_final/" 

use   "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/wrsi/averaged_`spatial_scale'_wrsi.dta", clear

quietly {
reshape long yd_, i(`spatial_scale') j(time) string
}

rename yd_  y

* separate the time variable into year month dekad and radius
gen year1 = substr(time,1,4) 
gen year = real(year1)
gen dekad = real(substr(time,5,2)) 

* Merge year dekad dataset
merge 1:1 `spatial_scale' year dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/`spatial_scale'_year_dekad"
drop _m
drop if year ==2000

gen month = ceil(dekad/3)
drop year1 time

* create a time index and set as panel data
sort `spatial_scale' year dekad
bysort `spatial_scale': gen time_index = _n

tsset `spatial_scale' time_index

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/harvest_start_`spatial_scale'"
drop _m

merge m:1 `spatial_scale' dekad using "./Processed_Data/Country/`country_name'/Remote_Sensed/growing_start_`spatial_scale'"
drop _m

tsset
gen wrsi = y if F.harvest_start ==1
replace wrsi = y if harvest_start ==1 & L.wrsi==.
replace wrsi = y if F2.harvest_start ==1 & F.wrsi ==.
replace wrsi = y if F3.harvest_start ==1 & F2.wrsi ==.
replace wrsi = y if F4.harvest_start ==1 & F3.wrsi ==.
replace wrsi = y if L.harvest_start ==1 & (L5.wrsi==. & L4.wrsi ==. & L3.wrsi ==. & L2.wrsi ==. & L.wrsi==.)

* construct the hazard event 
bysort `spatial_scale' dekad: egen median_wrsi = median(wrsi) 

gen awrsi = wrsi*100/median_wrsi 

* This lets every dekad in the harvest month have the harvest anomaly
bysort `spatial_scale' year month: egen month_wrsi = max(wrsi)
bysort `spatial_scale' year month: egen month_awrsi = max(awrsi)

gen month_harvest = (month_awrsi !=.)

duplicates drop `spatial_scale' year month, force
gen month_index = ym(year, month)
drop year month dekad

tsset `spatial_scale' time_index
	
tsfill
sort `spatial_scale' month_index
 
* Fill the harvest value of the wrsi anomaly for all months until the next harvest
bysort `spatial_scale' (month_index): carryforward month_awrsi, gen(anomaly_wrsi)
bysort `spatial_scale' (month_index): carryforward month_wrsi, gen(level_wrsi)

tsset
gen last_cycle_wrsi = L12.level_wrsi

gen month_year = dofm(month_index)
gen month = month(month_year)
gen year = year(month_year)

if "`spatial_scale'" =="national" {
	preserve
	keep if  month_harvest ==1
	keep anomaly_wrsi year 
	sort year
	save "./Processed_Data/Country/`country_name'/National_Estimates/wrsi_national_series.dta", replace
	restore
}

keep `spatial_scale' year month anomaly_wrsi level_wrsi last_cycle_wrsi
rename anomaly_wrsi anomaly_wrsi_`spatial_scale'
rename  level_wrsi level_wrsi_`spatial_scale'
rename last_cycle_wrsi last_cycle_wrsi_`spatial_scale'

rename month int_month
rename year int_year
duplicates drop `spatial_scale' int_year int_month,force

sort `spatial_scale' int_year int_month
merge 1:1 `spatial_scale' int_year int_month using "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_`spatial_scale'_merge.dta"

preserve
keep if int_month==1 
keep `spatial_scale' anomaly_wrsi_`spatial_scale' int_year int_month `hh_lat' `hh_lon'
save "./Processed_Data/Country/Pooled/`country_name'_wrsi`radius'.dta", replace
restore

keep if _m ==3
drop _m 

* save file in folder 
duplicates drop `spatial_scale'  int_month int_year, force
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/HH_Hazard_Final/wrsi/wrsi_final/merged_`spatial_scale'_wrsi.dta", replace

}

end





