* Do File version

* Inputs: 
* a) Gridded CSV file with remote-sensed data
* b) CSV file with information on the grids (uniqid, lat,long)
* Outputs: 
* 1) Sorted (by uniqid) stata datasets for the gridded location and hazard variables 

cap program define load_data
args country_name country_initial survey_data hhid int_month int_year crop_cover_filter hh_lat hh_lon hh_loc_available hh_admin_available admin_level remote_merge_admin survey_merge   ndvi_available wrsi_available wrsi2_available spei3_available chirps_available swi_available temper_available rainy_season_available

cap mkdir  "./Processed_Data/Country/" 
cap mkdir  "./Processed_Data/Country/`country_name'/" 
cap mkdir  "./Processed_Data/Country/`country_name'/Remote_Sensed/" 
cap mkdir  "./Processed_Data/Country/`country_name'/National_Estimates/" 
cap mkdir  "./Processed_Data/Country/Pooled/"
****** Load gridded coordinates and other information ***
* use the remote-sensed gridded data to extract uniqueid
insheet using "./Input_Data/Remote_Sensed/SSA/gadm_admin_urg005_mapping/`country_initial'_gadm_admin_urg005_mapping.csv", clear

keep uniqid lon lat uid 
sort uid
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/`country_initial'_gadm_admin_urg005", replace

insheet using "./Input_Data/Remote_Sensed/SSA/country_mapping/`country_initial'_gaul1_asap_urg005_mapping.csv", clear
drop if uniqid ==""
duplicates drop uniqid,force
sort  asap0_id asap1_id 
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/`country_initial'_crop_calendar_mapping", replace

country_crop_cycles `country_name' `country_initial'

if  ("`rainy_season_available'" == "Yes")  {
country_rainy_season `country_name' `country_initial'
}

insheet using "./Input_Data/Remote_Sensed/SSA/merge_variable_data/gadm_admin_geodata.csv", clear
sort uid 
joinby uid using "./Processed_Data/Country/`country_name'/Remote_Sensed/`country_initial'_gadm_admin_urg005"
duplicates drop uniqid,force
keep uniqid lon lat uid gid_1 gid_2 gid_3 `remote_merge_admin' 
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/`country_initial'_gadm_admin", replace

* Load AEZ data
insheet using "./Input_Data/Remote_Sensed/SSA/agro_ecological_zone/country_mapping/`country_initial'_aez_urg005_mapping.csv", clear
merge 1:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/`country_initial'_gadm_admin"
duplicates drop uniqid,force
keep uniqid aez* 
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/aez", replace
duplicates drop aez_b,force
keep aez_b aez_c
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/aez_classication", replace

* Load Livelihood Zone data
insheet using "./Input_Data/Remote_Sensed/SSA/livelihood_zone/country_mapping/`country_initial'_livelihood_urg005_db.csv", clear
merge 1:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/`country_initial'_gadm_admin"
duplicates drop uniqid,force
keep uniqid lev* 
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/livelihood", replace
duplicates drop lev_1,force
keep lev_1 lev1
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/livelihood_classication", replace

* Load time to market dataset
insheet using "./Input_Data/Remote_Sensed/SSA/time_to_market/country_mapping/`country_initial'_ttm_urg005_mapping.csv", clear
merge 1:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/`country_initial'_gadm_admin"
duplicates drop uniqid,force
keep uniqid ttm* 
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/ttm", replace
 

insheet using "./Input_Data/Remote_Sensed/SSA/crop_coverage/country_mapping/`country_initial'_CROPCOV19_mapping.csv", clear
merge 1:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/`country_initial'_gadm_admin"
drop _merge

***** Select Pixels for the national average based on aez and area under crop cultivation
preserve
merge 1:1 uniqid using "./Processed_Data/Country/`country_name'/Remote_Sensed/aez"
drop _merge
gen gid_initial = substr(gid_1,1,3) 
gen national_prod_pixel = ((aez_b == 9 | aez_b ==10 | aez_b == 12 | aez_b == 13 | aez_b == 16) & (gid_initial =="`country_initial'" & cropcov_19 > 20 & cropcov_19 !=.)) 
keep if national_prod_pixel ==1
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/national_pixels", replace
restore

keep if cropcov_19 > `crop_cover_filter' & cropcov_19 !=.

preserve
* keep only the UNIQID and location coordinates LON and LAT
keep uniqid lat lon
cap mkdir "./Processed_Data/Country/`country_name'"
cap mkdir "./Processed_Data/Country/`country_name'/Remote_Sensed"
* save the remote-sensed gridded data id and coordinates
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/remote_gridded_location", replace
restore 

if ("`hh_admin_available'" == "Yes")  {
* save the remote-sensed gridded data id and admin level 
keep uniqid `remote_merge_admin'
drop if `remote_merge_admin' ==""
sort `remote_merge_admin'
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/admin_gridded_location", replace
 
*** Merge Survey-Remote Sensed admin variables 
insheet using "./Input_Data/Data_Integration/Country/`country_name'/`survey_merge'.csv", clear
drop if `remote_merge_admin' ==""
sort `remote_merge_admin'
joinby `remote_merge_admin' using "./Processed_Data/Country/`country_name'/Remote_Sensed/admin_gridded_location"
duplicates drop `remote_merge_admin' uniqid,force
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/`admin_level'_merge_id", replace
}

*************** Load CHIRPS *****
if "`chirps_available'" == "Yes" { 
insheet using "./Input_Data/Remote_Sensed/SSA/CHIRPS/CHIRPS_country_dekadal_xy_output/`country_initial'_CHIRPS_dekad.csv", clear

foreach var of varlist _all {
cap replace `var' = . if `var' < -900
}

* save the remote-sensed gridded data id and drop the coordinates
drop lon lat
sort uniqid
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/chirps", replace
}

*************** Load Soil Moisture *****

if "`swi_available'" == "Yes" { 
insheet using "./Input_Data/Remote_Sensed/SSA/SWI/`country_initial'_SWI10_040_dekad.csv", clear

* save the remote-sensed gridded data id and drop the coordinates
drop lon lat
sort uniqid
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/swi", replace
}

*************** Load WRSI *****
if "`wrsi_available'" == "Yes" { 

insheet using "./Input_Data/Remote_Sensed/SSA/WRSI/`country_initial'_wrsi_do_dekad_ALL.csv", clear
drop if uniqid ==""
foreach var of varlist _all {
cap replace `var' = . if `var' ==254 | `var' ==253 | `var' ==0
}

* save the remote-sensed gridded data id, but drop the coordinates
drop lon lat
sort uniqid
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/wrsi", replace

}
*********************
*************** Load WRSI 2 *****
if "`wrsi2_available'" == "Yes" { 

insheet using "./Input_Data/Remote_Sensed/SSA/WRSI/Second_Season/`country_initial'_wrsi2_do_dekad_ALL.csv", clear
drop if uniqid ==""
foreach var of varlist _all {
cap replace `var' = . if `var' ==254 | `var' ==253 | `var' ==0
}

* save the remote-sensed gridded data id, but drop the coordinates
drop lon lat
sort uniqid
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/wrsi2", replace

}
*********************


*************** Load NDVI *****
if "`ndvi_available'" == "Yes" { 
insheet using "./Input_Data/Remote_Sensed/SSA/NDVI/MODIS13C2_output_xyz/`country_initial'_NDVI_monthly.csv", clear

foreach var of varlist _all {
cap replace `var' = . if `var' < 0
}

* save the remote-sensed gridded data id, but drop the coordinates
drop lon lat
sort uniqid
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/ndvi", replace
}
*********************
*************** Load SPEI 3 (3 month SPEI) *****
if "`spei3_available'" == "Yes" { 
insheet using "./Input_Data/Remote_Sensed/SSA/SPEI3/`country_initial'_SPEI03_dekad.csv", clear

* save the remote-sensed gridded data id, but drop the coordinates
drop lon lat
sort uniqid
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/spei3", replace
}
*********************

*************** Load TEMPERATURE *****
if "`temper_available'" == "Yes" { 
insheet using "./Input_Data/Remote_Sensed/SSA/temper/`country_initial'_ERA5_monthly_temp.csv", clear

* save the remote-sensed gridded data id, but drop the coordinates
drop lon lat
sort uniqid
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/temper", replace
}
*********************


****** If HH coordinates are available *****************************************************************************************************
****** Create a unique location id and do the relevant part of analysis with this variable to make the program run faster (prevent analysis of duplicates) ****
******** Sort survey by hhid interview month year **************
* Load the combined survey data for the given country
use "./Input_Data/Data_Integration/Country/`country_name'/`survey_data'.dta", clear

* Keep the location and time variables from the survey 
if ("`hh_loc_available'" == "Yes")  {
preserve	
egen long location =group(`hh_lat' `hh_lon')
rename `int_month' int_month
rename `int_year' int_year

drop if location ==.
duplicates drop location  int_month int_year, force
keep location int_month int_year `hh_lat' `hh_lon'
sort location int_month int_year
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_location_merge", replace

duplicates drop location,force
keep location
cross  using "./Input_Data/Data_Integration/SSA/year_dekad_2000_2020.dta"
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/location_year_dekad", replace

restore
}

if ("`hh_admin_available'" == "Yes")  {

preserve

duplicates drop `admin_level'  `int_month' `int_year', force
sort `admin_level'
joinby `admin_level' using "./Processed_Data/Country/`country_name'/Remote_Sensed/`admin_level'_merge_id"

rename `int_month' int_month
rename `int_year' int_year
drop if `admin_level' ==.

duplicates drop `admin_level' uniqid int_month int_year, force
keep `admin_level' uniqid int_month int_year 
sort `admin_level' uniqid int_month int_year
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_`admin_level'_first_merge", replace

keep `admin_level' int_month int_year 
duplicates drop `admin_level' int_month int_year,force
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_`admin_level'_merge", replace

duplicates drop `admin_level',force
keep `admin_level'
cross  using "./Input_Data/Data_Integration/SSA/year_dekad_2000_2020.dta"
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/`admin_level'_year_dekad", replace

restore

}

duplicates drop `int_month' `int_year', force

rename `int_month' int_month
rename `int_year' int_year
gen national = 1
keep national int_month int_year
sort national int_month int_year
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/hh_survey_for_national_merge", replace
cap drop _m
keep national
cross  using "./Input_Data/Data_Integration/SSA/year_dekad_2000_2020.dta"
duplicates drop national year dekad, force
save  "./Processed_Data/Country/`country_name'/Remote_Sensed/national_year_dekad", replace


end

