**  PREABMLE from: Master file to run analysis in "The Welfare Costs of Drought in Sub-Saharan Africa" by Gascoigne et al. (2023)
clear all
set more off
program drop _all


***** create Figures 1 and 2 in the note using the poverty rate and poverty gap across the different countries

use ".\Results\Ethiopia\ETH_simulated_pov_r20.dta", clear 
append using ".\Results\Lesotho\LSO_simulated_pov_r20.dta" 
append using ".\Results\Malawi\MWI_simulated_pov_r20.dta" 
append using ".\Results\Mozambique\MOZ_simulated_pov_r20.dta" 
append using ".\Results\Nigeria\NGA_simulated_pov_r20.dta" 
append using ".\Results\Zambia\ZMB_simulated_pov_r20.dta" 
append using ".\Results\Zimbabwe\ZWE_simulated_pov_r20.dta" 

sort country poverty_rate_change
bysort country: gen n1=_n 
bysort country: egen max_n=max(n1)
gen rel_n=n1/max_n

#delimit ;

graph twoway lowess poverty_rate_change rel_n if country=="ETH", bwidth(0.5) || lowess poverty_rate_change rel_n if country=="LSO", bwidth(0.5) || lowess poverty_rate_change rel_n if country=="MWI", bwidth(0.5) || lowess poverty_rate_change rel_n if country=="MOZ", bwidth(0.5)  || lowess poverty_rate_change rel_n if country=="NGA", bwidth(0.5)  || lowess poverty_rate_change rel_n if country=="ZMB", bwidth(0.5)  || lowess poverty_rate_change rel_n if country=="ZWE", bwidth(0.5) ,
	ytitle("Percentage point change in poverty rate")
	xtitle(" ")
	legend(label(1 "Ethiopia") label(2 "Lesotho") label(3 "Malawi") label(4 "Mozambique") label(5 "Nigeria") label(6 "Zambia") label(7 "Zimbabwe"))
	xlabel(, nolabel)
	xlabel(, notick)
	ylabel(-8(2)6)
	xsc(range(0.5 1))
	text(-8.9 0.2 "Good rainfall", size(medlarge)) text(-8.9 0.55 "Average rainfall", size(medlarge)) text(-8.9 0.9 "Bad rainfall", size(medlarge)) 
	legend(position(6) col(4)) 
	legend(symxsize(*0.5));
	
	graph export ".\Figures\Policy_note\Figure_1.jpg", replace as(jpg) width(4000);
	graph export ".\Figures\Policy_note\Figure_1.eps", replace as(eps);

	
#delimit cr

cap drop n1
cap drop max_n
cap drop rel_n
sort country pov_gap_change_m
bysort country: gen n1=_n 
bysort country: egen max_n=max(n1)
gen rel_n=n1/max_n

#delimit ;
	
graph twoway lowess pov_gap_change_m rel_n if country=="ETH", bwidth(0.5) || lowess pov_gap_change_m rel_n if country=="LSO", bwidth(0.5) || lowess pov_gap_change_m rel_n if country=="MWI", bwidth(0.5) || lowess pov_gap_change_m rel_n if country=="MOZ", bwidth(0.5)  || lowess pov_gap_change_m rel_n if country=="ZMB", bwidth(0.5)  || lowess pov_gap_change_m rel_n if country=="ZWE", bwidth(0.5) ,
	ytitle("Change in poverty gap US$million")
	xtitle(" ")
	legend(label(1 "Ethiopia") label(2 "Lesotho") label(3 "Malawi") label(4 "Mozambique") label(5 "Zambia") label(6 "Zimbabwe"))
	xlabel(, nolabel)
	xlabel(, notick)
	ylabel(-300(100)300)
	xsc(range(0.5 1))
	text(-340 0.2 "Good rainfall", size(medlarge)) text(-340 0.55 "Average rainfall", size(medlarge)) text(-340 0.9 "Bad rainfall", size(medlarge)) 
	legend(position(6) col(4)) 
	legend(symxsize(*0.5));
	
	graph export ".\Figures\Policy_note\Figure_2a.jpg", replace as(jpg) width(4000);
	graph export ".\Figures\Policy_note\Figure_2a.eps", replace as(eps);

	
graph twoway lowess pov_gap_change_m rel_n if country=="NGA", bwidth(0.5)
	ytitle("Change in poverty gap US$million")
	xtitle(" ")
	legend(label(1 "Nigeria"))
	xlabel(, nolabel)
	xlabel(, notick)
	ylabel(-1500(500)1000)
	xsc(range(0.5 1))
	text(-1650 0.2 "Good rainfall", size(medlarge)) text(-1650 0.55 "Average rainfall", size(medlarge)) text(-1650 0.9 "Bad rainfall", size(medlarge)) 
	legend(position(6) col(4)) 
	legend(symxsize(*0.5));
	graph export ".\Figures\Policy_note\Figure_2b.jpg", replace as(jpg) width(4000);
	graph export ".\Figures\Policy_note\Figure_2b.eps", replace as(eps);

#delimit cr