***  Ethiopia simulations using pastoral coefficients from W.Africa
clear all
set more off
program drop _all


local country_name_2		Ethiopia
local country_abr			ETH

local radii					0

local shock1 	anomaly_rsboth_ndvi_p		//hazard to be used  (this is generated in this code as average of the two rainy seasons, each is contributing half to the total)

local out		pcexpln_ppp

local lz3_l1_1	.0687284					//rs ndvi coefficient estimate (linear specification) for tlu_cat=1 from W.Africa pastorals
local lz3_l2_1	.08703719					//rs ndvi coefficient estimate (linear specification) for tlu_cat=2 from W.Africa pastorals
local lz3_l3_1 	.02024419					//rs ndvi coefficient estimate (linear specification) for tlu_cat=3 from W.Africa pastorals

/*
. scalar list
  lz3_l3_1 =  .02024419
  lz3_l2_1 =  .08703719
  lz3_l1_1 =   .0687284
*/

local out		pcexpln_ppp			//welfare measure used


*use "./Input_Data/Household_Survey/Pooled\pooled_cons_all_r`radii'.dta", clear
********************
*******************
**********************
*using the country specific hazard household/hazard file but need to get it to the same format as in the pooled data.  using country specific as  bringing in the 2nd rainy season;

use "./Input_Data/Household_Survey/Ethiopia/Ethiopia_cons_merged_hazard_year_0r_filter-1.dta"
drop if cq11==.

gen pc_cons_nat=adtexp
gen pc_cons_nat_yr=2015

gen pcexp_ppp=(adtexp)/8.820229

gen pcexpln_ppp=ln(pcexp_ppp)

gen pc_cons_f_nat=adfexp
gen pcexp_f_ppp=adfexp/8.820229
gen pcexp_f_ln_ppp=ln(pcexp_f_ppp)

gen pc_cons_nf_nat=adnfexp
gen pcexp_nf_ppp=adnfexp/8.820229
gen pcexp_nf_ln_ppp=ln(pcexp_nf_ppp)

gen country="Ethiopia"

gen admin=district
gen admin_alt=cq13

gen latitude=.
gen longitude=.

recode int_year (2010/2011=2011) (2015/2016=2016), gen(surv_year)

recode ur (2=1) (1=0), gen(rural)
recode rural (1=0) (0=1) if surv_year==2005  //rural miscoded in 2005

egen cluster=group(cq11 cq12 cq14 cq15 cq16 cq17)

gen hh_wt_con=wgt
gen pop_wt_con=popweight

replace hh_livestock=0 if hh_livestock==.

gen nat_pl_insurvey=7183

rename anomaly_rsboth_ndvi anomaly_rsboth_ndvi_p
rename mean_rsboth_ndvi mean_rsboth_ndvi_p
rename sd_rsboth_ndvi_district sd_rsboth_ndvi_p

gen anomaly_rsav_ndvi_p=(anomaly_rs_ndvi+anomaly_rs2_ndvi)/2

gen remote=.  
gen harvest_start_mo_district=.  //only have rainy season variables so no start/end harvest
*aez_band_ag_class 

keep country cq11 hhid int_year int_month pc_cons_nat pc_cons_nat_yr pcexp_ppp pcexpln_ppp pcexp_f_ln_ppp pcexp_nf_ln_ppp primitive_roof head_literate district admin admin_alt hhsize ttm_* aez_band_* lev_1_20* lev1_desc* remote* anomaly_* mean_* sd_* head_female rural harvest_start_mo_district cluster surv_year land_cat latitude longitude hh_wt_con pop_wt_con nat_pl_insurvey hh_livestock district rs_end_dekad rs_start_dekad rs2_end_dekad rs2_start_dekad

recode lev_1_2016 (1 = 1) (2 = 2) (8 = 3) (4/5 7 = 4) (3 6 = 5) (9/13=6), gen(livelihood)

gen hhsize_p=hhsize

gen pop_wt_p=pop_wt_con
replace pop_wt_p=hh_wt_con*hhsize_p if pop_wt_p==.



*************************
****************************  end of setting up dataset to mirror pooled data in main analysis
**********************


keep if country=="Ethiopia"
keep if surv_year==2016
keep if cq11==5

*********************
**sample **
********************
replace livelihood=3 if lev_1_2016 == 13

cap drop tlu_cat
sort hhid
set seed 98034
generate u1 = runiform() if livelihood==3 & cq11==5 & rural==1 & hh_livestock~=0 //rural pastorals in Somali region that have livestock
egen med_u1=median(u1)
gen tlu_cat=.
replace tlu_cat=2 if u1<=med_u1
replace tlu_cat=3 if u1>med_u1 & u1~=.

replace tlu_cat=1 if hh_livestock==0 & livelihood==3 & cq11==5 & rural==1

gen coef_`shock1'=.
gen ln_base_consumption=.

foreach lz of numlist 3{
		
di "*******************************"
di "LZ: `lz', land category: `land'"
di "*******************************"

replace coef_`shock1'=`lz`lz'_l1_1' if livelihood==`lz' & tlu_cat==1
replace coef_`shock1'=`lz`lz'_l2_1' if livelihood==`lz' & tlu_cat==2
replace coef_`shock1'=`lz`lz'_l3_1' if livelihood==`lz' & tlu_cat==3

cap drop ln_base_consumption_`lz'

gen ln_base_consumption_`lz'=`out'- (`lz`lz'_l1_1'*`shock1') if livelihood==`lz' & tlu_cat==1
replace ln_base_consumption_`lz'=`out'- (`lz`lz'_l2_1'*`shock1') if livelihood==`lz' & tlu_cat==2
replace ln_base_consumption_`lz'=`out'- (`lz`lz'_l3_1'*`shock1') if livelihood==`lz' & tlu_cat==3

replace ln_base_consumption=ln_base_consumption_`lz' if livelihood==`lz'

}

gen base_consumption_ppp=exp(ln_base_consumption)


***************

*pl is for each survey not deflated but only need 2019 to which all consumptions are keyed to

gen pl_ppp=nat_pl_insurvey /8.820229

gen ln_pl_ppp=ln(pl_ppp)

gen ln_pl_19ppp=ln(1.9*365)

summ pcexpln_ppp, detail
scalar define sc_cons_p1=r(p1)
scalar define sc_cons_p99=r(p99)

gen ln_cons_ppp_p1=sc_cons_p1
gen ln_cons_ppp_p99=sc_cons_p99

keep if surv_year==2016

count

cap drop _merge

order district

keep if tlu_cat~=.


keep hhid hhsize hh_wt_con pop_wt_p district int_month int_year anomaly_rsboth_ndvi ln_pl_ppp ln_pl_19ppp coef_* pcexpln_ppp  ln_base_consumption land_cat ln_cons_ppp_p1 ln_cons_ppp_p99 livelihood land_cat hh_livestock tlu_cat

sort hhid

order hhid hhsize hh_wt_con pop_wt_p district int_month int_year ln_cons_ppp_p1 ln_cons_ppp_p99 livelihood anomaly_rsboth_ndvi_p land_cat ln_pl_ppp ln_pl_19ppp coef_* pcexpln_ppp ln_base_consumption hh_livestock tlu_cat

rename anomaly_rsboth_ndvi_p anomaly_swi
rename pcexpln_ppp ln_consumption_observed
rename pop_wt_p pop_wt
rename district admin

label var anomaly_swi "NDVI based on average of short and long rains"


save "./Input_Data/Household_Survey/`country_name_2'/Base_consumption_p_`shock1'_`radii'km_somali_v2.dta", replace

