***  Ethiopia simulations using pastoral coefficients from W.Africa
clear all
set more off
program drop _all


local country_name_2		Malawi
local country_abr			MWI

local radius				20
local filter				-1

local shock1 	anomaly_swi		//hazard to be used  

local out		pcexpln_ppp

local lz1_l1_1	.0429244 					//swi coefficient estimate (linear specification) for land_cat==0 
local lz1_l1_2	.0546012 				    //swi coefficient estimate (linear specification) for land_cat==1 


local out		pcexpln_ppp			//welfare measure used


*use "./Input_Data/Household_Survey/Pooled\pooled_cons_all_r`radii'.dta", clear
********************
*******************
**********************
*using the country specific hazard household/hazard file but need to get it to the same format as in the pooled data;


use "./Input_Data/Household_Survey/Malawi/Malawi_cons_merged_hazard_int_year_20r_filter-1.dta", clear

*rexpagg_pc_r19 is in 2019 KW - need to convert to 2011 PPP

gen pc_cons_nat=rexpagg_pc_r19
gen pc_cons_nat_yr=2019

gen pcexp_ppp=(.7286996 * rexpagg_pc_r19)/272.0685

gen pcexpln_ppp=ln(pcexp_ppp)

gen pc_cons_f_nat=rexpfood_pc_r19
gen pcexp_f_ppp=(.7286996 * rexpfood_pc_r19)/272.0685
gen pcexp_f_ln_ppp=ln(pcexp_f_ppp)

gen pc_cons_nf_nat=pc_cons_nat-pc_cons_f_nat
gen pcexp_nf_ppp=(.7286996 * pc_cons_nf_nat)/272.0685
gen pcexp_nf_ln_ppp=ln(pcexp_nf_ppp)

gen country="Malawi"

gen admin=district

gen latitude=lat_modified
gen longitude=lon_modified

egen cluster=group(ea_id)

recode int_year (2004/2005=2004) (2010/2011=2010) (2016/2017=2016) (2019/2020=2019), gen (surv_year)

gen hh_wt_con=hh_wgt

gen nat_pl_insurvey=pline_2016

/*
cap drop hhid
destring `hhid', gen(hhid)
*/
drop if surv_year==2004

recode lev_1_2016 (1 = 1) (2 = 2) (8 = 3) (4/5 7 = 4) (3 6 = 5) (9/13=6), gen(livelihood)


cap drop hhid
destring HHID, gen(hhid)

rename harvest_start_month_location harvest_start_mo_location

keep country location hhid int_year int_month pc_cons_nat pc_cons_nat_yr pcexp_ppp pcexpln_ppp pcexp_f_ln_ppp pcexp_nf_ln_ppp primitive_roof  district admin ttm_* lev_1_20* lev1_desc* anomaly_swi_location head_age head_female hhsize dratio rural harvest_start_mo_location cluster surv_year land_cat latitude longitude Prel_hh_weight hh_wt_con pline_2016 nat_pl_insurvey livelihood hh_wt_con 
 
gen pop_wt_p=hh_wt_con*hhsize
rename anomaly_swi_location anomaly_swi_p

keep if surv_year==2019
keep if rural==1


*************************
****************************  end of setting up dataset to mirror pooled data in main analysis
**********************


*********************
**sample **
********************


gen coef_`shock1'=.
gen ln_base_consumption=.

replace land_cat=2 if land_cat==3

foreach lz of numlist 1{
		
di "*******************************"
di "LZ: `lz', land category: `land'"
di "*******************************"

replace coef_`shock1'=`lz1_l1_1' if livelihood==`lz' & land_cat==1
replace coef_`shock1'=`lz1_l1_2' if livelihood==`lz' & land_cat==2

cap drop ln_base_consumption_`lz'

gen ln_base_consumption_`lz'=`out'- (`lz1_l1_1'*`shock1') if livelihood==`lz' & land_cat==1
replace ln_base_consumption_`lz'=`out'- (`lz1_l1_2'*`shock1') if livelihood==`lz' & (land_cat==2 | land_cat==3)

replace ln_base_consumption=ln_base_consumption_`lz' if livelihood==`lz'

}

gen base_consumption_ppp=exp(ln_base_consumption)

*pl is for each survey not deflated but only need 2019 to which all consumptions are keyed to

gen pl19=137428*405.86/295.75

gen pl_ppp=pl19/272.0685*.7286996

gen ln_pl_ppp=ln(pl_ppp)

gen ln_pl_19ppp=ln(1.9*365)

summ pcexpln_ppp, detail
scalar define sc_cons_p1=r(p1)
scalar define sc_cons_p99=r(p99)

gen ln_cons_ppp_p1=sc_cons_p1
gen ln_cons_ppp_p99=sc_cons_p99

keep if surv_year==2019

count

gen lat_modified=latitude
gen lon_modified=longitude

cap drop _merge

order lat_modified lon_modified

merge m:1 lat_modified lon_modified using "./Processed_Data/Country/`country_name_2'/Remote_Sensed/sos_`radius'.dta"

drop if _merge==2
drop _merge

merge m:1 lat_modified lon_modified  using "./Processed_Data/Country/`country_name_2'/Remote_Sensed/soh_`radius'.dta"

drop if _merge==2
drop _merge

merge m:1 lat_modified lon_modified using"./Processed_Data/Country/`country_name_2'/Remote_Sensed/loc_uniqid_rank_`radius'.dta"

drop if _merge==2
drop _merge

keep hhid admin hhsize hh_wt_con pop_wt_p  uniqid lat_modified lon_modified int_month int_year sos soh anomaly_swi_p ln_pl_ppp ln_pl_19ppp coef_* pcexpln_ppp  ln_base_consumption land_cat ln_cons_ppp_p1 ln_cons_ppp_p99 livelihood land_cat 

sort hhid

order hhid admin hhsize hh_wt_con pop_wt_p uniqid lat_modified lon_modified int_month int_year ln_cons_ppp_p1 ln_cons_ppp_p99 sos soh livelihood  anomaly_swi_p land_cat ln_pl_ppp ln_pl_19ppp coef_* pcexpln_ppp ln_base_consumption

rename anomaly_swi_p anomaly_swi
rename pcexpln_ppp ln_consumption_observed
rename lat_modified lat
rename lon_modified lon

label var anomaly_swi "SWI anomaly"


save "./Input_Data/Household_Survey/Malawi/Base_consumption_p_`shock1'_`radius'km_policy.dta", replace
